@@ -28,11 +28,9 @@ class BigVector {
     shared_buffer_ = false;
   }
 
-  BigVector(const BigVector<Item> &other) {
-    CopyFrom(other);
-  }
+  BigVector(const BigVector<Item> &other) { CopyFrom(other); }
 
-  BigVector<Item> &operator= (const BigVector<Item> &other) {
+  BigVector<Item> &operator=(const BigVector<Item> &other) {
     if (&other == this)
       return *this;
 
@@ -69,9 +67,7 @@ class BigVector {
     buffer_[index] = item;
   }
 
-  bool IsEmpty() const {
-    return size_ == 0;
-  }
+  bool IsEmpty() const { return size_ == 0; }
 
   void Clear() {
     Dealloc();
@@ -86,7 +82,7 @@ class BigVector {
 
   void DoubleCapacity() {
     Item *old_buffer = buffer_;
-    bool old_large_alloc = large_alloc_;
+    const bool old_large_alloc = large_alloc_;
 
     assert(capacity_ > 0);
     buffer_ = Alloc(capacity_ * 2);
@@ -123,11 +119,11 @@ class BigVector {
 
  private:
   static const size_t kNumInit = 16;
-  static const size_t kMmapThreshold = 128*1024;
+  static const size_t kMmapThreshold = 128 * 1024;
 
   Item *Alloc(const size_t num_elements) {
     Item *result;
-    size_t num_bytes = sizeof(Item) * num_elements;
+    const size_t num_bytes = sizeof(Item) * num_elements;
     if (num_bytes >= kMmapThreshold) {
       result = static_cast<Item *>(smmap(num_bytes));
       large_alloc_ = true;
