@@ -37,8 +37,8 @@ void SessionCtx::CleanupInstance() {
 
 SessionCtx::SessionCtx() {
   lock_tls_blocks_ = reinterpret_cast<pthread_mutex_t *>(
-    smalloc(sizeof(pthread_mutex_t)));
-  int retval = pthread_mutex_init(lock_tls_blocks_, NULL);
+      smalloc(sizeof(pthread_mutex_t)));
+  const int retval = pthread_mutex_init(lock_tls_blocks_, NULL);
   assert(retval == 0);
 }
 
@@ -51,7 +51,7 @@ SessionCtx::~SessionCtx() {
     delete tls_blocks_[i];
   }
 
-  int retval = pthread_key_delete(thread_local_storage_);
+  const int retval = pthread_key_delete(thread_local_storage_);
   assert(retval == 0);
 }
 
@@ -59,8 +59,8 @@ SessionCtx::~SessionCtx() {
 SessionCtx *SessionCtx::GetInstance() {
   if (instance_ == NULL) {
     instance_ = new SessionCtx();
-    int retval =
-      pthread_key_create(&instance_->thread_local_storage_, TlsDestructor);
+    const int retval = pthread_key_create(&instance_->thread_local_storage_,
+                                          TlsDestructor);
     assert(retval == 0);
   }
 
@@ -70,7 +70,7 @@ SessionCtx *SessionCtx::GetInstance() {
 
 void SessionCtx::Get(uint64_t *id, char **reponame, char **client_instance) {
   ThreadLocalStorage *tls = static_cast<ThreadLocalStorage *>(
-    pthread_getspecific(thread_local_storage_));
+      pthread_getspecific(thread_local_storage_));
   if ((tls == NULL) || !tls->is_set) {
     *id = 0;
     *reponame = NULL;
@@ -85,7 +85,7 @@ void SessionCtx::Get(uint64_t *id, char **reponame, char **client_instance) {
 
 bool SessionCtx::IsSet() {
   ThreadLocalStorage *tls = static_cast<ThreadLocalStorage *>(
-    pthread_getspecific(thread_local_storage_));
+      pthread_getspecific(thread_local_storage_));
   if (tls == NULL)
     return false;
 
@@ -95,13 +95,13 @@ bool SessionCtx::IsSet() {
 
 void SessionCtx::Set(uint64_t id, char *reponame, char *client_instance) {
   ThreadLocalStorage *tls = static_cast<ThreadLocalStorage *>(
-    pthread_getspecific(thread_local_storage_));
+      pthread_getspecific(thread_local_storage_));
 
   if (tls == NULL) {
     tls = new ThreadLocalStorage(id, reponame, client_instance);
-    int retval = pthread_setspecific(thread_local_storage_, tls);
+    const int retval = pthread_setspecific(thread_local_storage_, tls);
     assert(retval == 0);
-    MutexLockGuard lock_guard(lock_tls_blocks_);
+    const MutexLockGuard lock_guard(lock_tls_blocks_);
     tls_blocks_.push_back(tls);
   } else {
     tls->id = id;
@@ -117,11 +117,12 @@ void SessionCtx::TlsDestructor(void *data) {
   delete tls;
 
   assert(instance_);
-  MutexLockGuard lock_guard(instance_->lock_tls_blocks_);
-  for (vector<ThreadLocalStorage *>::iterator i =
-       instance_->tls_blocks_.begin(), iEnd = instance_->tls_blocks_.end();
-       i != iEnd; ++i)
-  {
+  const MutexLockGuard lock_guard(instance_->lock_tls_blocks_);
+  for (vector<ThreadLocalStorage *>::iterator
+           i = instance_->tls_blocks_.begin(),
+           iEnd = instance_->tls_blocks_.end();
+       i != iEnd;
+       ++i) {
     if ((*i) == tls) {
       instance_->tls_blocks_.erase(i);
       break;
@@ -132,7 +133,7 @@ void SessionCtx::TlsDestructor(void *data) {
 
 void SessionCtx::Unset() {
   ThreadLocalStorage *tls = static_cast<ThreadLocalStorage *>(
-    pthread_getspecific(thread_local_storage_));
+      pthread_getspecific(thread_local_storage_));
   if (tls != NULL) {
     tls->is_set = false;
     tls->id = 0;
@@ -146,9 +147,7 @@ void SessionCtx::Unset() {
 
 
 CachePlugin::SessionInfo::SessionInfo(uint64_t id, const std::string &name)
-  : id(id)
-  , name(name)
-{
+    : id(id), name(name) {
   vector<string> tokens = SplitString(name, ':');
   reponame = strdup(tokens[0].c_str());
   if (tokens.size() > 1)
@@ -167,15 +166,14 @@ void CachePlugin::AskToDetach() {
 
 
 CachePlugin::CachePlugin(uint64_t capabilities)
-  : is_local_(false)
-  , capabilities_(capabilities)
-  , fd_socket_(-1)
-  , fd_socket_lock_(-1)
-  , running_(0)
-  , num_workers_(0)
-  , max_object_size_(kDefaultMaxObjectSize)
-  , num_inlimbo_clients_(0)
-{
+    : is_local_(false)
+    , capabilities_(capabilities)
+    , fd_socket_(-1)
+    , fd_socket_lock_(-1)
+    , running_(0)
+    , num_workers_(0)
+    , max_object_size_(kDefaultMaxObjectSize)
+    , num_inlimbo_clients_(0) {
   atomic_init64(&next_session_id_);
   atomic_init64(&next_txn_id_);
   atomic_init64(&next_lst_id_);
@@ -197,18 +195,16 @@ CachePlugin::~CachePlugin() {
 }
 
 
-void CachePlugin::HandleBreadcrumbStore(
-  cvmfs::MsgBreadcrumbStoreReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleBreadcrumbStore(cvmfs::MsgBreadcrumbStoreReq *msg_req,
+                                        CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgBreadcrumbReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
   msg_reply.set_req_id(msg_req->req_id());
   manifest::Breadcrumb breadcrumb;
-  bool retval = transport->ParseMsgHash(msg_req->breadcrumb().hash(),
-                                        &breadcrumb.catalog_hash);
+  const bool retval = transport->ParseMsgHash(msg_req->breadcrumb().hash(),
+                                              &breadcrumb.catalog_hash);
   if (!retval) {
     LogSessionError(msg_req->session_id(), cvmfs::STATUS_MALFORMED,
                     "malformed hash received from client");
@@ -220,26 +216,23 @@ void CachePlugin::HandleBreadcrumbStore(
     } else {
       breadcrumb.revision = 0;
     }
-    cvmfs::EnumStatus status =
-      StoreBreadcrumb(msg_req->breadcrumb().fqrn(), breadcrumb);
+    const cvmfs::EnumStatus status = StoreBreadcrumb(
+        msg_req->breadcrumb().fqrn(), breadcrumb);
     msg_reply.set_status(status);
   }
   transport->SendFrame(&frame_send);
 }
 
 
-void CachePlugin::HandleBreadcrumbLoad(
-  cvmfs::MsgBreadcrumbLoadReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleBreadcrumbLoad(cvmfs::MsgBreadcrumbLoadReq *msg_req,
+                                       CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgBreadcrumbReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
   msg_reply.set_req_id(msg_req->req_id());
   manifest::Breadcrumb breadcrumb;
-  cvmfs::EnumStatus status =
-    LoadBreadcrumb(msg_req->fqrn(), &breadcrumb);
+  const cvmfs::EnumStatus status = LoadBreadcrumb(msg_req->fqrn(), &breadcrumb);
   msg_reply.set_status(status);
   if (status == cvmfs::STATUS_OK) {
     assert(breadcrumb.IsValid());
@@ -256,16 +249,14 @@ void CachePlugin::HandleBreadcrumbLoad(
 }
 
 
-void CachePlugin::HandleHandshake(
-  cvmfs::MsgHandshake *msg_req,
-  CacheTransport *transport)
-{
-  uint64_t session_id = NextSessionId();
+void CachePlugin::HandleHandshake(cvmfs::MsgHandshake *msg_req,
+                                  CacheTransport *transport) {
+  const uint64_t session_id = NextSessionId();
   if (msg_req->has_name()) {
     sessions_[session_id] = SessionInfo(session_id, msg_req->name());
   } else {
-    sessions_[session_id] = SessionInfo(session_id,
-      "anonymous client (" + StringifyInt(session_id) + ")");
+    sessions_[session_id] = SessionInfo(
+        session_id, "anonymous client (" + StringifyInt(session_id) + ")");
   }
   cvmfs::MsgHandshakeAck msg_ack;
   CacheTransport::Frame frame_send(&msg_ack);
@@ -282,17 +273,15 @@ void CachePlugin::HandleHandshake(
 }
 
 
-void CachePlugin::HandleInfo(
-  cvmfs::MsgInfoReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleInfo(cvmfs::MsgInfoReq *msg_req,
+                             CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgInfoReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
   msg_reply.set_req_id(msg_req->req_id());
   Info info;
-  cvmfs::EnumStatus status = GetInfo(&info);
+  const cvmfs::EnumStatus status = GetInfo(&info);
   if (status != cvmfs::STATUS_OK) {
     LogSessionError(msg_req->session_id(), status,
                     "failed to query cache status");
@@ -309,7 +298,7 @@ void CachePlugin::HandleInfo(
 void CachePlugin::HandleIoctl(cvmfs::MsgIoctl *msg_req) {
   if (!msg_req->has_conncnt_change_by())
     return;
-  int32_t conncnt_change_by = msg_req->conncnt_change_by();
+  const int32_t conncnt_change_by = msg_req->conncnt_change_by();
   if ((static_cast<int32_t>(num_inlimbo_clients_) + conncnt_change_by) < 0) {
     LogSessionError(msg_req->session_id(), cvmfs::STATUS_MALFORMED,
                     "invalid request to drop connection counter below zero");
@@ -324,11 +313,9 @@ void CachePlugin::HandleIoctl(cvmfs::MsgIoctl *msg_req) {
 }
 
 
-void CachePlugin::HandleList(
-  cvmfs::MsgListReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleList(cvmfs::MsgListReq *msg_req,
+                             CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgListReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
@@ -380,24 +367,22 @@ void CachePlugin::HandleList(
 }
 
 
-void CachePlugin::HandleObjectInfo(
-  cvmfs::MsgObjectInfoReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleObjectInfo(cvmfs::MsgObjectInfoReq *msg_req,
+                                   CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgObjectInfoReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
   msg_reply.set_req_id(msg_req->req_id());
   shash::Any object_id;
-  bool retval = transport->ParseMsgHash(msg_req->object_id(), &object_id);
+  const bool retval = transport->ParseMsgHash(msg_req->object_id(), &object_id);
   if (!retval) {
     LogSessionError(msg_req->session_id(), cvmfs::STATUS_MALFORMED,
                     "malformed hash received from client");
     msg_reply.set_status(cvmfs::STATUS_MALFORMED);
   } else {
     ObjectInfo info;
-    cvmfs::EnumStatus status = GetObjectInfo(object_id, &info);
+    const cvmfs::EnumStatus status = GetObjectInfo(object_id, &info);
     msg_reply.set_status(status);
     if (status == cvmfs::STATUS_OK) {
       msg_reply.set_object_type(info.object_type);
@@ -411,17 +396,15 @@ void CachePlugin::HandleObjectInfo(
 }
 
 
-void CachePlugin::HandleRead(
-  cvmfs::MsgReadReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleRead(cvmfs::MsgReadReq *msg_req,
+                             CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgReadReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
   msg_reply.set_req_id(msg_req->req_id());
   shash::Any object_id;
-  bool retval = transport->ParseMsgHash(msg_req->object_id(), &object_id);
+  const bool retval = transport->ParseMsgHash(msg_req->object_id(), &object_id);
   if (!retval || (msg_req->size() > max_object_size_)) {
     LogSessionError(msg_req->session_id(), cvmfs::STATUS_MALFORMED,
                     "malformed hash received from client");
@@ -435,7 +418,8 @@ void CachePlugin::HandleRead(
 #else
   unsigned char buffer[size];
 #endif
-  cvmfs::EnumStatus status = Pread(object_id, msg_req->offset(), &size, buffer);
+  const cvmfs::EnumStatus status = Pread(object_id, msg_req->offset(), &size,
+                                         buffer);
   msg_reply.set_status(status);
   if (status == cvmfs::STATUS_OK) {
     frame_send.set_attachment(buffer, size);
@@ -450,23 +434,22 @@ void CachePlugin::HandleRead(
 }
 
 
-void CachePlugin::HandleRefcount(
-  cvmfs::MsgRefcountReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleRefcount(cvmfs::MsgRefcountReq *msg_req,
+                                 CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgRefcountReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
   msg_reply.set_req_id(msg_req->req_id());
   shash::Any object_id;
-  bool retval = transport->ParseMsgHash(msg_req->object_id(), &object_id);
+  const bool retval = transport->ParseMsgHash(msg_req->object_id(), &object_id);
   if (!retval) {
     LogSessionError(msg_req->session_id(), cvmfs::STATUS_MALFORMED,
                     "malformed hash received from client");
     msg_reply.set_status(cvmfs::STATUS_MALFORMED);
   } else {
-    cvmfs::EnumStatus status = ChangeRefcount(object_id, msg_req->change_by());
+    const cvmfs::EnumStatus status = ChangeRefcount(object_id,
+                                                    msg_req->change_by());
     msg_reply.set_status(status);
     if ((status != cvmfs::STATUS_OK) && (status != cvmfs::STATUS_NOENTRY)) {
       LogSessionError(msg_req->session_id(), status,
@@ -482,7 +465,7 @@ bool CachePlugin::HandleRequest(int fd_con) {
   char buffer[max_object_size_];
   CacheTransport::Frame frame_recv;
   frame_recv.set_attachment(buffer, max_object_size_);
-  bool retval = transport.RecvFrame(&frame_recv);
+  const bool retval = transport.RecvFrame(&frame_recv);
   if (!retval) {
     LogCvmfs(kLogCache, kLogSyslogErr | kLogDebug,
              "failed to receive request from connection (%d)", errno);
@@ -492,13 +475,13 @@ bool CachePlugin::HandleRequest(int fd_con) {
   google::protobuf::MessageLite *msg_typed = frame_recv.GetMsgTyped();
 
   if (msg_typed->GetTypeName() == "cvmfs.MsgHandshake") {
-    cvmfs::MsgHandshake *msg_req =
-      reinterpret_cast<cvmfs::MsgHandshake *>(msg_typed);
+    cvmfs::MsgHandshake *msg_req = reinterpret_cast<cvmfs::MsgHandshake *>(
+        msg_typed);
     HandleHandshake(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgQuit") {
     cvmfs::MsgQuit *msg_req = reinterpret_cast<cvmfs::MsgQuit *>(msg_typed);
-    map<uint64_t, SessionInfo>::const_iterator iter =
-      sessions_.find(msg_req->session_id());
+    const map<uint64_t, SessionInfo>::const_iterator iter = sessions_.find(
+        msg_req->session_id());
     if (iter != sessions_.end()) {
       free(iter->second.reponame);
       free(iter->second.client_instance);
@@ -508,44 +491,44 @@ bool CachePlugin::HandleRequest(int fd_con) {
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgIoctl") {
     HandleIoctl(reinterpret_cast<cvmfs::MsgIoctl *>(msg_typed));
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgRefcountReq") {
-    cvmfs::MsgRefcountReq *msg_req =
-      reinterpret_cast<cvmfs::MsgRefcountReq *>(msg_typed);
+    cvmfs::MsgRefcountReq *msg_req = reinterpret_cast<cvmfs::MsgRefcountReq *>(
+        msg_typed);
     HandleRefcount(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgObjectInfoReq") {
-    cvmfs::MsgObjectInfoReq *msg_req =
-      reinterpret_cast<cvmfs::MsgObjectInfoReq *>(msg_typed);
+    cvmfs::MsgObjectInfoReq
+        *msg_req = reinterpret_cast<cvmfs::MsgObjectInfoReq *>(msg_typed);
     HandleObjectInfo(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgReadReq") {
-    cvmfs::MsgReadReq *msg_req =
-      reinterpret_cast<cvmfs::MsgReadReq *>(msg_typed);
+    cvmfs::MsgReadReq *msg_req = reinterpret_cast<cvmfs::MsgReadReq *>(
+        msg_typed);
     HandleRead(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgStoreReq") {
-    cvmfs::MsgStoreReq *msg_req =
-      reinterpret_cast<cvmfs::MsgStoreReq *>(msg_typed);
+    cvmfs::MsgStoreReq *msg_req = reinterpret_cast<cvmfs::MsgStoreReq *>(
+        msg_typed);
     HandleStore(msg_req, &frame_recv, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgStoreAbortReq") {
-    cvmfs::MsgStoreAbortReq *msg_req =
-      reinterpret_cast<cvmfs::MsgStoreAbortReq *>(msg_typed);
+    cvmfs::MsgStoreAbortReq
+        *msg_req = reinterpret_cast<cvmfs::MsgStoreAbortReq *>(msg_typed);
     HandleStoreAbort(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgInfoReq") {
-    cvmfs::MsgInfoReq *msg_req =
-      reinterpret_cast<cvmfs::MsgInfoReq *>(msg_typed);
+    cvmfs::MsgInfoReq *msg_req = reinterpret_cast<cvmfs::MsgInfoReq *>(
+        msg_typed);
     HandleInfo(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgShrinkReq") {
-    cvmfs::MsgShrinkReq *msg_req =
-      reinterpret_cast<cvmfs::MsgShrinkReq *>(msg_typed);
+    cvmfs::MsgShrinkReq *msg_req = reinterpret_cast<cvmfs::MsgShrinkReq *>(
+        msg_typed);
     HandleShrink(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgListReq") {
-    cvmfs::MsgListReq *msg_req =
-      reinterpret_cast<cvmfs::MsgListReq *>(msg_typed);
+    cvmfs::MsgListReq *msg_req = reinterpret_cast<cvmfs::MsgListReq *>(
+        msg_typed);
     HandleList(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgBreadcrumbStoreReq") {
-    cvmfs::MsgBreadcrumbStoreReq *msg_req =
-      reinterpret_cast<cvmfs::MsgBreadcrumbStoreReq *>(msg_typed);
+    cvmfs::MsgBreadcrumbStoreReq
+        *msg_req = reinterpret_cast<cvmfs::MsgBreadcrumbStoreReq *>(msg_typed);
     HandleBreadcrumbStore(msg_req, &transport);
   } else if (msg_typed->GetTypeName() == "cvmfs.MsgBreadcrumbLoadReq") {
-    cvmfs::MsgBreadcrumbLoadReq *msg_req =
-      reinterpret_cast<cvmfs::MsgBreadcrumbLoadReq *>(msg_typed);
+    cvmfs::MsgBreadcrumbLoadReq
+        *msg_req = reinterpret_cast<cvmfs::MsgBreadcrumbLoadReq *>(msg_typed);
     HandleBreadcrumbLoad(msg_req, &transport);
   } else {
     LogCvmfs(kLogCache, kLogSyslogErr | kLogDebug,
@@ -558,17 +541,15 @@ bool CachePlugin::HandleRequest(int fd_con) {
 }
 
 
-void CachePlugin::HandleShrink(
-  cvmfs::MsgShrinkReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleShrink(cvmfs::MsgShrinkReq *msg_req,
+                               CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgShrinkReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
 
   msg_reply.set_req_id(msg_req->req_id());
   uint64_t used_bytes = 0;
-  cvmfs::EnumStatus status = Shrink(msg_req->shrink_to(), &used_bytes);
+  const cvmfs::EnumStatus status = Shrink(msg_req->shrink_to(), &used_bytes);
   msg_reply.set_used_bytes(used_bytes);
   msg_reply.set_status(status);
   if ((status != cvmfs::STATUS_OK) && (status != cvmfs::STATUS_PARTIAL)) {
@@ -578,24 +559,22 @@ void CachePlugin::HandleShrink(
 }
 
 
-void CachePlugin::HandleStoreAbort(
-  cvmfs::MsgStoreAbortReq *msg_req,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleStoreAbort(cvmfs::MsgStoreAbortReq *msg_req,
+                                   CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgStoreReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
   msg_reply.set_req_id(msg_req->req_id());
   msg_reply.set_part_nr(0);
   uint64_t txn_id;
-  UniqueRequest uniq_req(msg_req->session_id(), msg_req->req_id());
-  bool retval = txn_ids_.Lookup(uniq_req, &txn_id);
+  const UniqueRequest uniq_req(msg_req->session_id(), msg_req->req_id());
+  const bool retval = txn_ids_.Lookup(uniq_req, &txn_id);
   if (!retval) {
     LogSessionError(msg_req->session_id(), cvmfs::STATUS_MALFORMED,
                     "malformed transaction id received from client");
     msg_reply.set_status(cvmfs::STATUS_MALFORMED);
   } else {
-    cvmfs::EnumStatus status = AbortTxn(txn_id);
+    const cvmfs::EnumStatus status = AbortTxn(txn_id);
     msg_reply.set_status(status);
     if (status != cvmfs::STATUS_OK) {
       LogSessionError(msg_req->session_id(), status,
@@ -607,22 +586,18 @@ void CachePlugin::HandleStoreAbort(
 }
 
 
-void CachePlugin::HandleStore(
-  cvmfs::MsgStoreReq *msg_req,
-  CacheTransport::Frame *frame,
-  CacheTransport *transport)
-{
-  SessionCtxGuard session_guard(msg_req->session_id(), this);
+void CachePlugin::HandleStore(cvmfs::MsgStoreReq *msg_req,
+                              CacheTransport::Frame *frame,
+                              CacheTransport *transport) {
+  const SessionCtxGuard session_guard(msg_req->session_id(), this);
   cvmfs::MsgStoreReply msg_reply;
   CacheTransport::Frame frame_send(&msg_reply);
   msg_reply.set_req_id(msg_req->req_id());
   msg_reply.set_part_nr(msg_req->part_nr());
   shash::Any object_id;
   bool retval = transport->ParseMsgHash(msg_req->object_id(), &object_id);
-  if ( !retval ||
-       (frame->att_size() > max_object_size_) ||
-       ((frame->att_size() < max_object_size_) && !msg_req->last_part()) )
-  {
+  if (!retval || (frame->att_size() > max_object_size_)
+      || ((frame->att_size() < max_object_size_) && !msg_req->last_part())) {
     LogSessionError(msg_req->session_id(), cvmfs::STATUS_MALFORMED,
                     "malformed hash or bad object size received from client");
     msg_reply.set_status(cvmfs::STATUS_MALFORMED);
@@ -630,7 +605,7 @@ void CachePlugin::HandleStore(
     return;
   }
 
-  UniqueRequest uniq_req(msg_req->session_id(), msg_req->req_id());
+  const UniqueRequest uniq_req(msg_req->session_id(), msg_req->req_id());
   uint64_t txn_id;
   cvmfs::EnumStatus status = cvmfs::STATUS_OK;
   if (msg_req->part_nr() == 1) {
@@ -644,9 +619,15 @@ void CachePlugin::HandleStore(
     txn_id = NextTxnId();
     ObjectInfo info;
     info.id = object_id;
-    if (msg_req->has_expected_size()) {info.size = msg_req->expected_size();}
-    if (msg_req->has_object_type()) {info.object_type = msg_req->object_type();}
-    if (msg_req->has_description()) {info.description = msg_req->description();}
+    if (msg_req->has_expected_size()) {
+      info.size = msg_req->expected_size();
+    }
+    if (msg_req->has_object_type()) {
+      info.object_type = msg_req->object_type();
+    }
+    if (msg_req->has_description()) {
+      info.description = msg_req->description();
+    }
     status = StartTxn(object_id, txn_id, info);
     if (status != cvmfs::STATUS_OK) {
       LogSessionError(msg_req->session_id(), status,
@@ -693,15 +674,13 @@ void CachePlugin::HandleStore(
 }
 
 
-bool CachePlugin::IsRunning() {
-  return atomic_read32(&running_) != 0;
-}
+bool CachePlugin::IsRunning() { return atomic_read32(&running_) != 0; }
 
 
 bool CachePlugin::Listen(const string &locator) {
   vector<string> tokens = SplitString(locator, '=');
   if (tokens[0] == "unix") {
-    string lock_path = tokens[1] + ".lock";
+    const string lock_path = tokens[1] + ".lock";
     fd_socket_lock_ = TryLockFile(lock_path);
     if (fd_socket_lock_ == -1) {
       LogCvmfs(kLogCache, kLogSyslogErr | kLogDebug,
@@ -723,8 +702,8 @@ bool CachePlugin::Listen(const string &locator) {
   } else if (tokens[0] == "tcp") {
     vector<string> tcp_address = SplitString(tokens[1], ':');
     if (tcp_address.size() != 2) {
-      LogCvmfs(kLogCache, kLogSyslogErr | kLogDebug,
-               "invalid locator: %s", locator.c_str());
+      LogCvmfs(kLogCache, kLogSyslogErr | kLogDebug, "invalid locator: %s",
+               locator.c_str());
       NotifySupervisor(CacheTransport::kFailureNotification);
       return false;
     }
@@ -748,7 +727,7 @@ bool CachePlugin::Listen(const string &locator) {
     is_local_ = false;
     return false;
   }
-  int retval = listen(fd_socket_, 32);
+  const int retval = listen(fd_socket_, 32);
   assert(retval == 0);
 
   return true;
@@ -757,27 +736,26 @@ bool CachePlugin::Listen(const string &locator) {
 
 void CachePlugin::LogSessionInfo(uint64_t session_id, const string &msg) {
   string session_str("unidentified client (" + StringifyInt(session_id) + ")");
-  map<uint64_t, SessionInfo>::const_iterator iter = sessions_.find(session_id);
+  const map<uint64_t, SessionInfo>::const_iterator iter = sessions_.find(
+      session_id);
   if (iter != sessions_.end()) {
     session_str = iter->second.name;
   }
-  LogCvmfs(kLogCache, kLogDebug | kLogSyslog,
-           "session '%s': %s", session_str.c_str(), msg.c_str());
+  LogCvmfs(kLogCache, kLogDebug | kLogSyslog, "session '%s': %s",
+           session_str.c_str(), msg.c_str());
 }
 
 
-void CachePlugin::LogSessionError(
-  uint64_t session_id,
-  cvmfs::EnumStatus status,
-  const std::string &msg)
-{
+void CachePlugin::LogSessionError(uint64_t session_id,
+                                  cvmfs::EnumStatus status,
+                                  const std::string &msg) {
   string session_str("unidentified client (" + StringifyInt(session_id) + ")");
-  map<uint64_t, SessionInfo>::const_iterator iter = sessions_.find(session_id);
+  const map<uint64_t, SessionInfo>::const_iterator iter = sessions_.find(
+      session_id);
   if (iter != sessions_.end()) {
     session_str = iter->second.name;
   }
-  LogCvmfs(kLogCache, kLogDebug | kLogSyslogErr,
-           "session '%s': %s (%d - %s)",
+  LogCvmfs(kLogCache, kLogDebug | kLogSyslogErr, "session '%s': %s (%d - %s)",
            session_str.c_str(), msg.c_str(), status,
            CacheTransportCode2Ascii(status));
 }
@@ -803,7 +781,7 @@ void *CachePlugin::MainProcessRequests(void *data) {
   while (!terminated) {
     for (unsigned i = 0; i < watch_fds.size(); ++i)
       watch_fds[i].revents = 0;
-    int retval = poll(&watch_fds[0], watch_fds.size(), -1);
+    const int retval = poll(&watch_fds[0], watch_fds.size(), -1);
     if (retval < 0) {
       if (errno == EINTR)
         continue;
@@ -832,8 +810,8 @@ void *CachePlugin::MainProcessRequests(void *data) {
     if (watch_fds[1].revents) {
       struct sockaddr_un remote;
       socklen_t socket_size = sizeof(remote);
-      int fd_con =
-        accept(watch_fds[1].fd, (struct sockaddr *)&remote, &socket_size);
+      const int fd_con = accept(watch_fds[1].fd, (struct sockaddr *)&remote,
+                                &socket_size);
       if (fd_con < 0) {
         LogCvmfs(kLogCache, kLogSyslogWarn | kLogDebug,
                  "failed to establish connection (%d)", errno);
@@ -847,17 +825,16 @@ void *CachePlugin::MainProcessRequests(void *data) {
     }
 
     // New request
-    for (unsigned i = 2; i < watch_fds.size(); ) {
+    for (unsigned i = 2; i < watch_fds.size();) {
       if (watch_fds[i].revents) {
-        bool proceed = cache_plugin->HandleRequest(watch_fds[i].fd);
+        const bool proceed = cache_plugin->HandleRequest(watch_fds[i].fd);
         if (!proceed) {
           close(watch_fds[i].fd);
           cache_plugin->connections_.erase(watch_fds[i].fd);
           watch_fds.erase(watch_fds.begin() + i);
-          if ( (getenv(CacheTransport::kEnvReadyNotifyFd) != NULL) &&
-               (cache_plugin->connections_.empty()) &&
-               (cache_plugin->num_inlimbo_clients_ == 0) )
-          {
+          if ((getenv(CacheTransport::kEnvReadyNotifyFd) != NULL)
+              && (cache_plugin->connections_.empty())
+              && (cache_plugin->num_inlimbo_clients_ == 0)) {
             LogCvmfs(kLogCache, kLogSyslog,
                      "stopping cache plugin, no more active clients");
             terminated = true;
@@ -889,14 +866,15 @@ void CachePlugin::NotifySupervisor(char signal) {
   char *pipe_ready = getenv(CacheTransport::kEnvReadyNotifyFd);
   if (pipe_ready == NULL)
     return;
-  int fd_pipe_ready = String2Int64(pipe_ready);
+  const int fd_pipe_ready = String2Int64(pipe_ready);
   WritePipe(fd_pipe_ready, &signal, 1);
 }
 
 
 void CachePlugin::ProcessRequests(unsigned num_workers) {
   num_workers_ = num_workers;
-  int retval = pthread_create(&thread_io_, NULL, MainProcessRequests, this);
+  const int retval = pthread_create(&thread_io_, NULL, MainProcessRequests,
+                                    this);
   assert(retval == 0);
   NotifySupervisor(CacheTransport::kReadyNotification);
   atomic_cas32(&running_, 0, 1);
@@ -905,11 +883,11 @@ void CachePlugin::ProcessRequests(unsigned num_workers) {
 
 void CachePlugin::SendDetachRequests() {
   set<int>::const_iterator iter = connections_.begin();
-  set<int>::const_iterator iter_end = connections_.end();
+  const set<int>::const_iterator iter_end = connections_.end();
   for (; iter != iter_end; ++iter) {
     CacheTransport transport(*iter,
-      CacheTransport::kFlagSendIgnoreFailure |
-      CacheTransport::kFlagSendNonBlocking);
+                             CacheTransport::kFlagSendIgnoreFailure
+                                 | CacheTransport::kFlagSendNonBlocking);
     cvmfs::MsgDetach msg_detach;
     CacheTransport::Frame frame_send(&msg_detach);
     transport.SendFrame(&frame_send);
