@@ -55,9 +55,7 @@ static enum cvmcache_object_type ObjectType2CType(cvmfs::EnumObjectType type) {
 class ForwardCachePlugin : public CachePlugin {
  public:
   explicit ForwardCachePlugin(struct cvmcache_callbacks *callbacks)
-    : CachePlugin(callbacks->capabilities)
-    , callbacks_(*callbacks)
-  {
+      : CachePlugin(callbacks->capabilities), callbacks_(*callbacks) {
     assert(callbacks->cvmcache_chrefcnt != NULL);
     assert(callbacks->cvmcache_obj_info != NULL);
     assert(callbacks->cvmcache_pread != NULL);
@@ -86,24 +84,20 @@ class ForwardCachePlugin : public CachePlugin {
   virtual ~ForwardCachePlugin() { }
 
  protected:
-  virtual cvmfs::EnumStatus ChangeRefcount(
-    const shash::Any &id,
-    int32_t change_by)
-  {
+  virtual cvmfs::EnumStatus ChangeRefcount(const shash::Any &id,
+                                           int32_t change_by) {
     struct cvmcache_hash c_hash = Cpphash2Chash(id);
-    int result = callbacks_.cvmcache_chrefcnt(&c_hash, change_by);
+    const int result = callbacks_.cvmcache_chrefcnt(&c_hash, change_by);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
-  virtual cvmfs::EnumStatus GetObjectInfo(
-    const shash::Any &id,
-    ObjectInfo *info)
-  {
+  virtual cvmfs::EnumStatus GetObjectInfo(const shash::Any &id,
+                                          ObjectInfo *info) {
     struct cvmcache_hash c_hash = Cpphash2Chash(id);
     cvmcache_object_info c_info;
     memset(&c_info, 0, sizeof(c_info));
     c_info.size = CachePlugin::kSizeUnknown;
-    int result = callbacks_.cvmcache_obj_info(&c_hash, &c_info);
+    const int result = callbacks_.cvmcache_obj_info(&c_hash, &c_info);
     info->size = c_info.size;
     info->object_type = static_cast<cvmfs::EnumObjectType>(c_info.type);
     info->pinned = c_info.pinned;
@@ -114,22 +108,18 @@ class ForwardCachePlugin : public CachePlugin {
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
-  virtual cvmfs::EnumStatus Pread(
-    const shash::Any &id,
-    uint64_t offset,
-    uint32_t *size,
-    unsigned char *buffer)
-  {
+  virtual cvmfs::EnumStatus Pread(const shash::Any &id,
+                                  uint64_t offset,
+                                  uint32_t *size,
+                                  unsigned char *buffer) {
     struct cvmcache_hash c_hash = Cpphash2Chash(id);
-    int result = callbacks_.cvmcache_pread(&c_hash, offset, size, buffer);
+    const int result = callbacks_.cvmcache_pread(&c_hash, offset, size, buffer);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
-  virtual cvmfs::EnumStatus StartTxn(
-    const shash::Any &id,
-    const uint64_t txn_id,
-    const ObjectInfo &info)
-  {
+  virtual cvmfs::EnumStatus StartTxn(const shash::Any &id,
+                                     const uint64_t txn_id,
+                                     const ObjectInfo &info) {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_WRITE))
       return cvmfs::STATUS_NOSUPPORT;
 
@@ -143,20 +133,18 @@ class ForwardCachePlugin : public CachePlugin {
     } else {
       c_info.description = strdup(info.description.c_str());
     }
-    int result = callbacks_.cvmcache_start_txn(&c_hash, txn_id, &c_info);
+    const int result = callbacks_.cvmcache_start_txn(&c_hash, txn_id, &c_info);
     free(c_info.description);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
-  virtual cvmfs::EnumStatus WriteTxn(
-    const uint64_t txn_id,
-    unsigned char *buffer,
-    uint32_t size)
-  {
+  virtual cvmfs::EnumStatus WriteTxn(const uint64_t txn_id,
+                                     unsigned char *buffer,
+                                     uint32_t size) {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_WRITE))
       return cvmfs::STATUS_NOSUPPORT;
 
-    int result = callbacks_.cvmcache_write_txn(txn_id, buffer, size);
+    const int result = callbacks_.cvmcache_write_txn(txn_id, buffer, size);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
@@ -164,7 +152,7 @@ class ForwardCachePlugin : public CachePlugin {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_WRITE))
       return cvmfs::STATUS_NOSUPPORT;
 
-    int result = callbacks_.cvmcache_commit_txn(txn_id);
+    const int result = callbacks_.cvmcache_commit_txn(txn_id);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
@@ -172,7 +160,7 @@ class ForwardCachePlugin : public CachePlugin {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_WRITE))
       return cvmfs::STATUS_NOSUPPORT;
 
-    int result = callbacks_.cvmcache_abort_txn(txn_id);
+    const int result = callbacks_.cvmcache_abort_txn(txn_id);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
@@ -185,7 +173,7 @@ class ForwardCachePlugin : public CachePlugin {
     c_info.used_bytes = info->used_bytes;
     c_info.pinned_bytes = info->pinned_bytes;
     c_info.no_shrink = info->no_shrink;
-    int result = callbacks_.cvmcache_info(&c_info);
+    const int result = callbacks_.cvmcache_info(&c_info);
     if (result == CVMCACHE_STATUS_OK) {
       info->size_bytes = c_info.size_bytes;
       info->used_bytes = c_info.used_bytes;
@@ -199,32 +187,27 @@ class ForwardCachePlugin : public CachePlugin {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_SHRINK))
       return cvmfs::STATUS_NOSUPPORT;
 
-    int result = callbacks_.cvmcache_shrink(shrink_to, used);
+    const int result = callbacks_.cvmcache_shrink(shrink_to, used);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
-  virtual cvmfs::EnumStatus ListingBegin(
-    uint64_t lst_id,
-    cvmfs::EnumObjectType type)
-  {
+  virtual cvmfs::EnumStatus ListingBegin(uint64_t lst_id,
+                                         cvmfs::EnumObjectType type) {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_LIST))
       return cvmfs::STATUS_NOSUPPORT;
 
-    int result =
-      callbacks_.cvmcache_listing_begin(lst_id, ObjectType2CType(type));
+    const int result = callbacks_.cvmcache_listing_begin(
+        lst_id, ObjectType2CType(type));
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
-  virtual cvmfs::EnumStatus ListingNext(
-    int64_t lst_id,
-    ObjectInfo *item)
-  {
+  virtual cvmfs::EnumStatus ListingNext(int64_t lst_id, ObjectInfo *item) {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_LIST))
       return cvmfs::STATUS_NOSUPPORT;
 
     struct cvmcache_object_info c_item;
     memset(&c_item, 0, sizeof(c_item));
-    int result = callbacks_.cvmcache_listing_next(lst_id, &c_item);
+    const int result = callbacks_.cvmcache_listing_next(lst_id, &c_item);
     if (result == CVMCACHE_STATUS_OK) {
       item->id = Chash2Cpphash(&c_item.id);
       item->size = c_item.size;
@@ -242,19 +225,18 @@ class ForwardCachePlugin : public CachePlugin {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_LIST))
       return cvmfs::STATUS_NOSUPPORT;
 
-    int result = callbacks_.cvmcache_listing_end(lst_id);
+    const int result = callbacks_.cvmcache_listing_end(lst_id);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
-  virtual cvmfs::EnumStatus LoadBreadcrumb(
-    const std::string &fqrn, manifest::Breadcrumb *breadcrumb)
-  {
+  virtual cvmfs::EnumStatus LoadBreadcrumb(const std::string &fqrn,
+                                           manifest::Breadcrumb *breadcrumb) {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_BREADCRUMB))
       return cvmfs::STATUS_NOSUPPORT;
 
     cvmcache_breadcrumb c_breadcrumb;
-    int result =
-      callbacks_.cvmcache_breadcrumb_load(fqrn.c_str(), &c_breadcrumb);
+    const int result = callbacks_.cvmcache_breadcrumb_load(fqrn.c_str(),
+                                                           &c_breadcrumb);
     if (result == CVMCACHE_STATUS_OK) {
       breadcrumb->catalog_hash = Chash2Cpphash(&c_breadcrumb.catalog_hash);
       breadcrumb->timestamp = c_breadcrumb.timestamp;
@@ -264,8 +246,7 @@ class ForwardCachePlugin : public CachePlugin {
   }
 
   virtual cvmfs::EnumStatus StoreBreadcrumb(
-    const std::string &fqrn, const manifest::Breadcrumb &breadcrumb)
-  {
+      const std::string &fqrn, const manifest::Breadcrumb &breadcrumb) {
     if (!(callbacks_.capabilities & CVMCACHE_CAP_BREADCRUMB))
       return cvmfs::STATUS_NOSUPPORT;
 
@@ -273,8 +254,8 @@ class ForwardCachePlugin : public CachePlugin {
     c_breadcrumb.catalog_hash = Cpphash2Chash(breadcrumb.catalog_hash);
     c_breadcrumb.timestamp = breadcrumb.timestamp;
     c_breadcrumb.revision = breadcrumb.revision;
-    int result =
-      callbacks_.cvmcache_breadcrumb_store(fqrn.c_str(), &c_breadcrumb);
+    const int result = callbacks_.cvmcache_breadcrumb_store(fqrn.c_str(),
+                                                            &c_breadcrumb);
     return static_cast<cvmfs::EnumStatus>(result);
   }
 
@@ -327,8 +308,8 @@ int cvmcache_listen(struct cvmcache_context *ctx, char *locator) {
   return ctx->plugin->Listen(locator);
 }
 
-void cvmcache_process_requests(struct cvmcache_context *ctx, unsigned nworkers)
-{
+void cvmcache_process_requests(struct cvmcache_context *ctx,
+                               unsigned nworkers) {
   ctx->plugin->ProcessRequests(nworkers);
 }
 
@@ -353,9 +334,8 @@ void cvmcache_get_session(cvmcache_session *session) {
   assert(session != NULL);
   SessionCtx *session_ctx = SessionCtx::GetInstance();
   assert(session_ctx);
-  session_ctx->Get(&(session->id),
-                   &(session->repository_name),
-                   &(session->client_instance));
+  session_ctx->Get(
+      &(session->id), &(session->repository_name), &(session->client_instance));
 }
 
 void cvmcache_spawn_watchdog(const char *crash_dump_file) {
