@@ -16,8 +16,8 @@
 
 std::string TieredCacheManager::Describe() {
   return "Tiered Cache\n"
-    "  - upper layer: " + upper_->Describe() +
-    "  - lower layer: " + lower_->Describe();
+         "  - upper layer: "
+         + upper_->Describe() + "  - lower layer: " + lower_->Describe();
 }
 
 
@@ -32,9 +32,9 @@ bool TieredCacheManager::DoFreeState(void *data) {
 
 int TieredCacheManager::DoRestoreState(void *data) {
   SavedState *state = reinterpret_cast<SavedState *>(data);
-  int new_root_fd = upper_->RestoreState(-1, state->state_upper);
+  const int new_root_fd = upper_->RestoreState(-1, state->state_upper);
   // The lower cache layer does not keep the root catalog open
-  int retval = lower_->RestoreState(-1, state->state_lower);
+  const int retval = lower_->RestoreState(-1, state->state_lower);
   assert(retval == -1);
   return new_root_fd;
 }
@@ -49,14 +49,18 @@ void *TieredCacheManager::DoSaveState() {
 
 
 int TieredCacheManager::Open(const LabeledObject &object) {
-  int fd = upper_->Open(object);
-  if ((fd >= 0) || (fd != -ENOENT)) {return fd;}
+  const int fd = upper_->Open(object);
+  if ((fd >= 0) || (fd != -ENOENT)) {
+    return fd;
+  }
 
-  int fd2 = lower_->Open(object);
-  if (fd2 < 0) {return fd;}  // NOTE: use error code from upper.
+  const int fd2 = lower_->Open(object);
+  if (fd2 < 0) {
+    return fd;
+  }  // NOTE: use error code from upper.
 
   // Lower cache hit; upper cache miss.  Copy object into the upper cache.
-  int64_t size = lower_->GetSize(fd2);
+  const int64_t size = lower_->GetSize(fd2);
   if (size < 0) {
     lower_->Close(fd2);
     return fd;
@@ -74,7 +78,8 @@ int TieredCacheManager::Open(const LabeledObject &object) {
   uint64_t remaining = size;
   uint64_t offset = 0;
   while (remaining > 0) {
-    unsigned nbytes = remaining > kCopyBufferSize ? kCopyBufferSize : remaining;
+    const unsigned nbytes = remaining > kCopyBufferSize ? kCopyBufferSize
+                                                        : remaining;
     int64_t result = lower_->Pread(fd2, &m_buffer[0], nbytes, offset);
     // The file we are reading is supposed to be exactly `size` bytes.
     if ((result < 0) || (result != nbytes)) {
@@ -92,7 +97,7 @@ int TieredCacheManager::Open(const LabeledObject &object) {
     remaining -= nbytes;
   }
   lower_->Close(fd2);
-  int fd_return = upper_->OpenFromTxn(txn);
+  const int fd_return = upper_->OpenFromTxn(txn);
   if (fd_return < 0) {
     upper_->AbortTxn(txn);
     return fd;
@@ -105,15 +110,16 @@ int TieredCacheManager::Open(const LabeledObject &object) {
 }
 
 
-int TieredCacheManager::StartTxn(const shash::Any &id, uint64_t size, void *txn)
-{
-  int upper_result = upper_->StartTxn(id, size, txn);
+int TieredCacheManager::StartTxn(const shash::Any &id,
+                                 uint64_t size,
+                                 void *txn) {
+  const int upper_result = upper_->StartTxn(id, size, txn);
   if (lower_readonly_ || (upper_result < 0)) {
     return upper_result;
   }
 
   void *txn2 = static_cast<char *>(txn) + upper_->SizeOfTxn();
-  int lower_result = lower_->StartTxn(id, size, txn2);
+  const int lower_result = lower_->StartTxn(id, size, txn2);
   if (lower_result < 0) {
     upper_->AbortTxn(txn);
   }
@@ -121,12 +127,10 @@ int TieredCacheManager::StartTxn(const shash::Any &id, uint64_t size, void *txn)
 }
 
 
-CacheManager *TieredCacheManager::Create(
-  CacheManager *upper_cache,
-  CacheManager *lower_cache)
-{
-  TieredCacheManager *cache_mgr =
-    new TieredCacheManager(upper_cache, lower_cache);
+CacheManager *TieredCacheManager::Create(CacheManager *upper_cache,
+                                         CacheManager *lower_cache) {
+  TieredCacheManager *cache_mgr = new TieredCacheManager(upper_cache,
+                                                         lower_cache);
   delete cache_mgr->quota_mgr_;
   cache_mgr->quota_mgr_ = upper_cache->quota_mgr();
 
@@ -134,31 +138,34 @@ CacheManager *TieredCacheManager::Create(
 }
 
 
-void TieredCacheManager::CtrlTxn(const Label &label, const int flags, void *txn)
-{
+void TieredCacheManager::CtrlTxn(const Label &label,
+                                 const int flags,
+                                 void *txn) {
   upper_->CtrlTxn(label, flags, txn);
   if (!lower_readonly_) {
-    void *txn2 = static_cast<char*>(txn) + upper_->SizeOfTxn();
+    void *txn2 = static_cast<char *>(txn) + upper_->SizeOfTxn();
     lower_->CtrlTxn(label, flags, txn2);
   }
 }
 
 
 int64_t TieredCacheManager::Write(const void *buf, uint64_t size, void *txn) {
-  int upper_result = upper_->Write(buf, size, txn);
-  if (lower_readonly_ || (upper_result < 0)) { return upper_result; }
+  const int upper_result = upper_->Write(buf, size, txn);
+  if (lower_readonly_ || (upper_result < 0)) {
+    return upper_result;
+  }
 
-  void *txn2 = static_cast<char*>(txn) + upper_->SizeOfTxn();
+  void *txn2 = static_cast<char *>(txn) + upper_->SizeOfTxn();
   return lower_->Write(buf, size, txn2);
 }
 
 
 int TieredCacheManager::Reset(void *txn) {
-  int upper_result = upper_->Reset(txn);
+  const int upper_result = upper_->Reset(txn);
 
   int lower_result = upper_result;
   if (!lower_readonly_) {
-    void *txn2 = static_cast<char*>(txn) + upper_->SizeOfTxn();
+    void *txn2 = static_cast<char *>(txn) + upper_->SizeOfTxn();
     lower_result = lower_->Reset(txn2);
   }
 
@@ -167,11 +174,11 @@ int TieredCacheManager::Reset(void *txn) {
 
 
 int TieredCacheManager::AbortTxn(void *txn) {
-  int upper_result = upper_->AbortTxn(txn);
+  const int upper_result = upper_->AbortTxn(txn);
 
   int lower_result = upper_result;
   if (!lower_readonly_) {
-    void *txn2 = static_cast<char*>(txn) + upper_->SizeOfTxn();
+    void *txn2 = static_cast<char *>(txn) + upper_->SizeOfTxn();
     lower_result = lower_->AbortTxn(txn2);
   }
 
@@ -180,11 +187,11 @@ int TieredCacheManager::AbortTxn(void *txn) {
 
 
 int TieredCacheManager::CommitTxn(void *txn) {
-  int upper_result = upper_->CommitTxn(txn);
+  const int upper_result = upper_->CommitTxn(txn);
 
   int lower_result = upper_result;
   if (!lower_readonly_) {
-    void *txn2 = static_cast<char*>(txn) + upper_->SizeOfTxn();
+    void *txn2 = static_cast<char *>(txn) + upper_->SizeOfTxn();
     lower_result = lower_->CommitTxn(txn2);
   }
 
@@ -192,8 +199,8 @@ int TieredCacheManager::CommitTxn(void *txn) {
 }
 
 
-manifest::Breadcrumb TieredCacheManager::LoadBreadcrumb(const std::string &fqrn)
-{
+manifest::Breadcrumb TieredCacheManager::LoadBreadcrumb(
+    const std::string &fqrn) {
   manifest::Breadcrumb breadcrumb = upper_->LoadBreadcrumb(fqrn);
   if (!breadcrumb.IsValid())
     breadcrumb = lower_->LoadBreadcrumb(fqrn);
@@ -202,7 +209,7 @@ manifest::Breadcrumb TieredCacheManager::LoadBreadcrumb(const std::string &fqrn)
 
 
 bool TieredCacheManager::StoreBreadcrumb(const manifest::Manifest &manifest) {
-  bool upper_success = upper_->StoreBreadcrumb(manifest);
+  const bool upper_success = upper_->StoreBreadcrumb(manifest);
   bool lower_success = true;
   if (!lower_readonly_)
     lower_success = lower_->StoreBreadcrumb(manifest);
