@@ -24,8 +24,7 @@ FieldT TreeCountersBase<FieldT>::Get(const std::string &key) const {
 
 template<typename FieldT>
 typename TreeCountersBase<FieldT>::FieldsMap
-    TreeCountersBase<FieldT>::GetFieldsMap() const
-{
+TreeCountersBase<FieldT>::GetFieldsMap() const {
   FieldsMap map;
   self.FillFieldsMap("self_", &map);
   subtree.FillFieldsMap("subtree_", &map);
@@ -41,7 +40,7 @@ std::map<std::string, FieldT> TreeCountersBase<FieldT>::GetValues() const {
 
   std::map<std::string, FieldT> map_summed;
 
-  typename FieldsMap::const_iterator i    = map_self.begin();
+  typename FieldsMap::const_iterator i = map_self.begin();
   typename FieldsMap::const_iterator iend = map_self.end();
   for (; i != iend; ++i) {
     map_summed[i->first] = *(map_self[i->first]) + *(map_subtree[i->first]);
@@ -55,10 +54,9 @@ std::string TreeCountersBase<FieldT>::GetCsvMap() const {
   std::map<std::string, FieldT> map_summed = GetValues();
 
   std::string result;
-  typename std::map<std::string, FieldT>::const_iterator j    =
-    map_summed.begin();
-  typename std::map<std::string, FieldT>::const_iterator jend =
-    map_summed.end();
+  typename std::map<std::string, FieldT>::const_iterator j = map_summed.begin();
+  typename std::map<std::string, FieldT>::const_iterator jend = map_summed
+                                                                    .end();
   for (; j != jend; ++j) {
     result += j->first + "," + StringifyInt(j->second) + "\n";
   }
@@ -67,54 +65,52 @@ std::string TreeCountersBase<FieldT>::GetCsvMap() const {
 
 
 template<typename FieldT>
-bool TreeCountersBase<FieldT>::ReadFromDatabase(
-  const CatalogDatabase   &database,
-  const LegacyMode::Type   legacy)
-{
+bool TreeCountersBase<FieldT>::ReadFromDatabase(const CatalogDatabase &database,
+                                                const LegacyMode::Type legacy) {
   bool retval = true;
 
   FieldsMap map = GetFieldsMap();
   SqlGetCounter sql_counter(database);
 
-  typename FieldsMap::const_iterator i    = map.begin();
+  typename FieldsMap::const_iterator i = map.begin();
   typename FieldsMap::const_iterator iend = map.end();
   for (; i != iend; ++i) {
-    bool current_retval = sql_counter.BindCounter(i->first) &&
-                          sql_counter.FetchRow();
+    bool current_retval = sql_counter.BindCounter(i->first)
+                          && sql_counter.FetchRow();
 
     // TODO(jblomer): nicify this
     if (current_retval) {
-      *(const_cast<FieldT*>(i->second)) =
-        static_cast<FieldT>(sql_counter.GetCounter());
-    } else if ( (legacy == LegacyMode::kNoSpecials) &&
-                ((i->first == "self_special") ||
-                 (i->first == "subtree_special")) )
-    {  // NOLINT(bugprone-branch-clone)
-      *(const_cast<FieldT*>(i->second)) = FieldT(0);
+      *(const_cast<FieldT *>(i->second)) = static_cast<FieldT>(
+          sql_counter.GetCounter());
+    } else if (
+        (legacy == LegacyMode::kNoSpecials)
+        && ((i->first == "self_special")
+            || (i->first
+                == "subtree_special"))) {  // NOLINT(bugprone-branch-clone)
+      *(const_cast<FieldT *>(i->second)) = FieldT(0);
       current_retval = true;
-    } else if ( (legacy == LegacyMode::kNoExternals) &&
-                ((i->first == "self_special")
-                  || (i->first == "subtree_special") ||
-                 (i->first == "self_external")
-                  || (i->first == "subtree_external") ||
-                 (i->first == "self_external_file_size")
-                  || (i->first == "subtree_external_file_size")) )
-    {
-      *(const_cast<FieldT*>(i->second)) = FieldT(0);
+    } else if ((legacy == LegacyMode::kNoExternals)
+               && ((i->first == "self_special")
+                   || (i->first == "subtree_special")
+                   || (i->first == "self_external")
+                   || (i->first == "subtree_external")
+                   || (i->first == "self_external_file_size")
+                   || (i->first == "subtree_external_file_size"))) {
+      *(const_cast<FieldT *>(i->second)) = FieldT(0);
       current_retval = true;
-    } else if ( (legacy == LegacyMode::kNoXattrs) &&
-                ((i->first == "self_special")
-                  || (i->first == "subtree_special") ||
-                (i->first == "self_external")
-                 || (i->first == "subtree_external") ||
-                (i->first == "self_external_file_size")
-                 || (i->first == "subtree_external_file_size") ||
-                (i->first == "self_xattr") || (i->first == "subtree_xattr")) )
-    {
-      *(const_cast<FieldT*>(i->second)) = FieldT(0);
+    } else if ((legacy == LegacyMode::kNoXattrs)
+               && ((i->first == "self_special")
+                   || (i->first == "subtree_special")
+                   || (i->first == "self_external")
+                   || (i->first == "subtree_external")
+                   || (i->first == "self_external_file_size")
+                   || (i->first == "subtree_external_file_size")
+                   || (i->first == "self_xattr")
+                   || (i->first == "subtree_xattr"))) {
+      *(const_cast<FieldT *>(i->second)) = FieldT(0);
       current_retval = true;
     } else if (legacy == LegacyMode::kLegacy) {
-      *(const_cast<FieldT*>(i->second)) = FieldT(0);
+      *(const_cast<FieldT *>(i->second)) = FieldT(0);
       current_retval = true;
     }
 
@@ -128,20 +124,18 @@ bool TreeCountersBase<FieldT>::ReadFromDatabase(
 
 template<typename FieldT>
 bool TreeCountersBase<FieldT>::WriteToDatabase(
-  const CatalogDatabase &database) const
-{
+    const CatalogDatabase &database) const {
   bool retval = true;
 
   const FieldsMap map = GetFieldsMap();
   SqlUpdateCounter sql_counter(database);
 
-  typename FieldsMap::const_iterator i    = map.begin();
+  typename FieldsMap::const_iterator i = map.begin();
   typename FieldsMap::const_iterator iend = map.end();
   for (; i != iend; ++i) {
-    const bool current_retval =
-      sql_counter.BindCounter(i->first)   &&
-      sql_counter.BindDelta(*(i->second)) &&
-      sql_counter.Execute();
+    const bool current_retval = sql_counter.BindCounter(i->first)
+                                && sql_counter.BindDelta(*(i->second))
+                                && sql_counter.Execute();
     sql_counter.Reset();
 
     retval = (retval) ? current_retval : false;
@@ -153,20 +147,18 @@ bool TreeCountersBase<FieldT>::WriteToDatabase(
 
 template<typename FieldT>
 bool TreeCountersBase<FieldT>::InsertIntoDatabase(
-  const CatalogDatabase &database) const
-{
+    const CatalogDatabase &database) const {
   bool retval = true;
 
   const FieldsMap map = GetFieldsMap();
   SqlCreateCounter sql_counter(database);
 
-  typename FieldsMap::const_iterator i    = map.begin();
+  typename FieldsMap::const_iterator i = map.begin();
   typename FieldsMap::const_iterator iend = map.end();
   for (; i != iend; ++i) {
-    const bool current_retval =
-      sql_counter.BindCounter(i->first)   &&
-      sql_counter.BindInitialValue(*(i->second)) &&
-      sql_counter.Execute();
+    const bool current_retval = sql_counter.BindCounter(i->first)
+                                && sql_counter.BindInitialValue(*(i->second))
+                                && sql_counter.Execute();
     sql_counter.Reset();
 
     retval = (retval) ? current_retval : false;
