@@ -56,17 +56,16 @@ void MigrateAny(const Any *old_hash, shash::Any *new_hash) {
 namespace inode_tracker {
 
 bool InodeContainer::ConstructPath(const uint64_t inode, PathString *path) {
-  InodeMap::const_iterator needle = map_.find(inode);
+  const InodeMap::const_iterator needle = map_.find(inode);
   if (needle == map_.end())
     return false;
 
   if (needle->second.name.IsEmpty())
     return true;
 
-  bool retval = ConstructPath(needle->second.parent_inode, path);
+  const bool retval = ConstructPath(needle->second.parent_inode, path);
   path->Append("/", 1);
-  path->Append(needle->second.name.GetChars(),
-               needle->second.name.GetLength());
+  path->Append(needle->second.name.GetChars(), needle->second.name.GetLength());
   assert(retval);
   return retval;
 }
@@ -82,12 +81,12 @@ void Migrate(InodeTracker *old_tracker, glue::InodeTracker *new_tracker) {
   i = old_tracker->inode2path_.map_.begin();
   iEnd = old_tracker->inode2path_.map_.end();
   for (; i != iEnd; ++i) {
-    uint64_t inode = i->first;
-    uint32_t references = i->second.references;
+    const uint64_t inode = i->first;
+    const uint32_t references = i->second.references;
     PathString path;
     old_tracker->inode2path_.ConstructPath(inode, &path);
-    new_tracker->VfsGetBy(
-      glue::InodeEx(inode, glue::InodeEx::kUnknownType), references, path);
+    new_tracker->VfsGetBy(glue::InodeEx(inode, glue::InodeEx::kUnknownType),
+                          references, path);
   }
 }
 
@@ -100,7 +99,8 @@ void Migrate(InodeTracker *old_tracker, glue::InodeTracker *new_tracker) {
 namespace inode_tracker_v2 {
 
 static uint32_t hasher_md5(const shash_v1::Md5 &key) {
-  return (uint32_t) *((uint32_t *)key.digest + 1);  // NOLINT
+  return static_cast<uint32_t>(
+      *(reinterpret_cast<const uint32_t *>(key.digest + 1)));
 }
 
 static uint32_t hasher_inode(const uint64_t &inode) {
@@ -111,18 +111,19 @@ void Migrate(InodeTracker *old_tracker, glue::InodeTracker *new_tracker) {
   old_tracker->inode_map_.map_.hasher_ = hasher_inode;
   old_tracker->path_map_.map_.hasher_ = hasher_md5;
 
-  SmallHashDynamic<uint64_t, uint32_t> *old_inodes =
-    &old_tracker->inode_references_.map_;
+  SmallHashDynamic<uint64_t, uint32_t>
+      *old_inodes = &old_tracker->inode_references_.map_;
   for (unsigned i = 0; i < old_inodes->capacity_; ++i) {
     const uint64_t inode = old_inodes->keys_[i];
-    if (inode == 0) continue;
+    if (inode == 0)
+      continue;
 
     const uint32_t references = old_inodes->values_[i];
     PathString path;
-    bool retval = old_tracker->FindPath(inode, &path);
+    const bool retval = old_tracker->FindPath(inode, &path);
     assert(retval);
-    new_tracker->VfsGetBy(
-      glue::InodeEx(inode, glue::InodeEx::kUnknownType), references, path);
+    new_tracker->VfsGetBy(glue::InodeEx(inode, glue::InodeEx::kUnknownType),
+                          references, path);
   }
 }
 
@@ -135,7 +136,8 @@ void Migrate(InodeTracker *old_tracker, glue::InodeTracker *new_tracker) {
 namespace inode_tracker_v3 {
 
 static uint32_t hasher_md5(const shash_v1::Md5 &key) {
-  return (uint32_t) *((uint32_t *)key.digest + 1);  // NOLINT
+  return static_cast<uint32_t>(
+      *(reinterpret_cast<const uint32_t *>(key.digest + 1)));
 }
 
 static uint32_t hasher_inode(const uint64_t &inode) {
@@ -147,18 +149,19 @@ void Migrate(InodeTracker *old_tracker, glue::InodeTracker *new_tracker) {
   old_tracker->path_map_.map_.SetHasher(hasher_md5);
   old_tracker->path_map_.path_store_.map_.SetHasher(hasher_md5);
 
-  SmallHashDynamic<uint64_t, uint32_t> *old_inodes =
-    &old_tracker->inode_references_.map_;
+  SmallHashDynamic<uint64_t, uint32_t>
+      *old_inodes = &old_tracker->inode_references_.map_;
   for (unsigned i = 0; i < old_inodes->capacity(); ++i) {
     const uint64_t inode = old_inodes->keys()[i];
-    if (inode == 0) continue;
+    if (inode == 0)
+      continue;
 
     const uint32_t references = old_inodes->values()[i];
     PathString path;
-    bool retval = old_tracker->FindPath(inode, &path);
+    const bool retval = old_tracker->FindPath(inode, &path);
     assert(retval);
-    new_tracker->VfsGetBy(
-      glue::InodeEx(inode, glue::InodeEx::kUnknownType), references, path);
+    new_tracker->VfsGetBy(glue::InodeEx(inode, glue::InodeEx::kUnknownType),
+                          references, path);
   }
 }
 
@@ -184,26 +187,27 @@ void Migrate(ChunkTables *old_tables, ::ChunkTables *new_tables) {
   new_tables->handle2fd = old_tables->handle2fd;
   new_tables->inode2references = old_tables->inode2references;
 
-  SmallHashDynamic<uint64_t, FileChunkReflist> *old_inode2chunks =
-    &old_tables->inode2chunks;
+  SmallHashDynamic<uint64_t, FileChunkReflist>
+      *old_inode2chunks = &old_tables->inode2chunks;
   for (unsigned keyno = 0; keyno < old_inode2chunks->capacity(); ++keyno) {
     const uint64_t inode = old_inode2chunks->keys()[keyno];
-    if (inode == 0) continue;
+    if (inode == 0)
+      continue;
 
     FileChunkReflist *old_reflist = &old_inode2chunks->values()[keyno];
     BigVector<FileChunk> *old_list = old_reflist->list;
     FileChunkList *new_list = new FileChunkList();
     for (unsigned i = 0; i < old_list->size(); ++i) {
       const FileChunk *old_chunk = old_list->AtPtr(i);
-      off_t offset = old_chunk->offset();
-      size_t size = old_chunk->size();
+      const off_t offset = old_chunk->offset();
+      const size_t size = old_chunk->size();
       shash::Any hash;
       shash_v1::MigrateAny(&old_chunk->content_hash_, &hash);
       new_list->PushBack(::FileChunk(hash, offset, size));
     }
     delete old_list;
-    ::FileChunkReflist new_reflist(new_list, old_reflist->path,
-                                   zlib::kZlibDefault, false);
+    const ::FileChunkReflist new_reflist(new_list, old_reflist->path,
+                                         zlib::kZlibDefault, false);
     new_tables->inode2chunks.Insert(inode, new_reflist);
   }
 }
@@ -230,26 +234,27 @@ void Migrate(ChunkTables *old_tables, ::ChunkTables *new_tables) {
   new_tables->handle2fd = old_tables->handle2fd;
   new_tables->inode2references = old_tables->inode2references;
 
-  SmallHashDynamic<uint64_t, FileChunkReflist> *old_inode2chunks =
-    &old_tables->inode2chunks;
+  SmallHashDynamic<uint64_t, FileChunkReflist>
+      *old_inode2chunks = &old_tables->inode2chunks;
   for (unsigned keyno = 0; keyno < old_inode2chunks->capacity(); ++keyno) {
     const uint64_t inode = old_inode2chunks->keys()[keyno];
-    if (inode == 0) continue;
+    if (inode == 0)
+      continue;
 
     FileChunkReflist *old_reflist = &old_inode2chunks->values()[keyno];
     BigVector<FileChunk> *old_list = old_reflist->list;
     FileChunkList *new_list = new FileChunkList();
     for (unsigned i = 0; i < old_list->size(); ++i) {
       const FileChunk *old_chunk = old_list->AtPtr(i);
-      off_t offset = old_chunk->offset();
-      size_t size = old_chunk->size();
+      const off_t offset = old_chunk->offset();
+      const size_t size = old_chunk->size();
       shash::Any hash;
       shash_v2::MigrateAny(&old_chunk->content_hash_, &hash);
       new_list->PushBack(::FileChunk(hash, offset, size));
     }
     delete old_list;
-    ::FileChunkReflist new_reflist(new_list, old_reflist->path,
-                                   zlib::kZlibDefault, false);
+    const ::FileChunkReflist new_reflist(new_list, old_reflist->path,
+                                         zlib::kZlibDefault, false);
     new_tables->inode2chunks.Insert(inode, new_reflist);
   }
 }
