@@ -7,7 +7,9 @@
  * This binary does not use the cvmfs infrastructure code to stay lean.
  */
 
+// clang-format off
 #include <sys/xattr.h>  // NOLINT
+// clang-format on
 
 #include <dirent.h>
 #include <errno.h>
@@ -38,19 +40,17 @@ static void GetCredentials(uid_t *calling_uid, uid_t *effective_uid) {
   *effective_uid = geteuid();
 }
 
-static void ExecAsRoot(const char *binary,
-                       const char *arg1, const char *arg2, const char *arg3,
-                       const char *arg4)
-{
-  char *argv[] = { strdup(binary),
-                   arg1 ? strdup(arg1) : NULL,
-                   arg2 ? strdup(arg2) : NULL,
-                   arg3 ? strdup(arg3) : NULL,
-                   arg4 ? strdup(arg4) : NULL,
-                   NULL };
-  char *environ[] = { NULL };
+static void ExecAsRoot(const char *binary, const char *arg1, const char *arg2,
+                       const char *arg3, const char *arg4) {
+  char *argv[] = {strdup(binary),
+                  arg1 ? strdup(arg1) : NULL,
+                  arg2 ? strdup(arg2) : NULL,
+                  arg3 ? strdup(arg3) : NULL,
+                  arg4 ? strdup(arg4) : NULL,
+                  NULL};
+  char *environ[] = {NULL};
 
-  int retval = setuid(0);
+  const int retval = setuid(0);
   if (retval != 0) {
     fprintf(stderr, "failed to gain root privileges (%d)\n", errno);
     exit(1);
@@ -63,9 +63,8 @@ static void ExecAsRoot(const char *binary,
 
 static void ForkAndExecAsRoot(const char *binary, const char *arg1,
                               const char *arg2, const char *arg3,
-                              const char *arg4)
-{
-  pid_t child = fork();
+                              const char *arg4) {
+  const pid_t child = fork();
   if (child == -1) {
     fprintf(stderr, "failed to fork %s... (%d)\n", binary, errno);
     exit(1);
@@ -104,25 +103,24 @@ static void Remount(const string &path, const RemountType how) {
 
 static void Mount(const string &path) {
   platform_stat64 info;
-  int retval = platform_stat("/bin/systemctl", &info);
+  const int retval = platform_stat("/bin/systemctl", &info);
   if (retval == 0) {
     string systemd_unit = cvmfs_suid::EscapeSystemdUnit(path);
     // On newer versions of systemd, the mount unit is based on the fully
     // resolved path (discovered on Ubuntu 18.04, test 539)
-    if (!cvmfs_suid::PathExists(
-          string("/run/systemd/generator/") + systemd_unit))
-    {
-      string resolved_path = cvmfs_suid::ResolvePath(path);
+    if (!cvmfs_suid::PathExists(string("/run/systemd/generator/")
+                                + systemd_unit)) {
+      const string resolved_path = cvmfs_suid::ResolvePath(path);
       if (resolved_path.empty()) {
         fprintf(stderr, "cannot resolve %s\n", path.c_str());
         exit(1);
       }
       systemd_unit = cvmfs_suid::EscapeSystemdUnit(resolved_path);
     }
-    ForkAndExecAsRoot("/bin/systemctl", "restart", systemd_unit.c_str(),
-                      NULL, NULL);
-    ExecAsRoot("/bin/systemctl", "reset-failed", systemd_unit.c_str(),
-               NULL, NULL);
+    ForkAndExecAsRoot("/bin/systemctl", "restart", systemd_unit.c_str(), NULL,
+                      NULL);
+    ExecAsRoot("/bin/systemctl", "reset-failed", systemd_unit.c_str(), NULL,
+               NULL);
   } else {
     ExecAsRoot("/bin/mount", path.c_str(), NULL, NULL, NULL);
   }
@@ -147,7 +145,7 @@ static void KillCvmfs(const string &fqrn) {
   const bool retval = platform_getxattr(mountpoint.c_str(), "user.pid", &pid);
   if (!retval || pid.empty())
     exit(1);
-  sanitizer::PositiveIntegerSanitizer pid_sanitizer;
+  const sanitizer::PositiveIntegerSanitizer pid_sanitizer;
   if (!pid_sanitizer.IsValid(pid))
     exit(1);
   ExecAsRoot("/bin/kill", "-9", pid.c_str(), NULL, NULL);
@@ -156,9 +154,7 @@ static void KillCvmfs(const string &fqrn) {
 class ScopedWorkingDirectory {
  public:
   explicit ScopedWorkingDirectory(const string &path)
-    : previous_path_(GetCurrentWorkingDirectory())
-    , directory_handle_(NULL)
-  {
+      : previous_path_(GetCurrentWorkingDirectory()), directory_handle_(NULL) {
     ChangeDirectory(path);
     directory_handle_ = opendir(".");
   }
@@ -173,14 +169,15 @@ class ScopedWorkingDirectory {
   operator bool() const { return directory_handle_ != NULL; }
 
   struct DirectoryEntry {
-    bool   is_directory;
+    bool is_directory;
     string name;
   };
 
   bool NextDirectoryEntry(DirectoryEntry *entry) {
     platform_dirent64 *dirent;
-    while ((dirent = platform_readdir(directory_handle_)) != NULL &&
-           IsDotEntry(dirent)) {}
+    while ((dirent = platform_readdir(directory_handle_)) != NULL
+           && IsDotEntry(dirent)) {
+    }
     if (dirent == NULL) {
       return false;
     }
@@ -191,14 +188,14 @@ class ScopedWorkingDirectory {
     }
 
     entry->is_directory = S_ISDIR(info.st_mode);
-    entry->name         = dirent->d_name;
+    entry->name = dirent->d_name;
     return true;
   }
 
  protected:
   string GetCurrentWorkingDirectory() {
     char path[PATH_MAX];
-    const char* cwd = getcwd(path, PATH_MAX);
+    const char *cwd = getcwd(path, PATH_MAX);
     assert(cwd == path);
     return string(cwd);
   }
@@ -209,13 +206,13 @@ class ScopedWorkingDirectory {
   }
 
   bool IsDotEntry(const platform_dirent64 *dirent) {
-    return (strcmp(dirent->d_name, ".")  == 0) ||
-           (strcmp(dirent->d_name, "..") == 0);
+    return (strcmp(dirent->d_name, ".") == 0)
+           || (strcmp(dirent->d_name, "..") == 0);
   }
 
  private:
-  const string  previous_path_;
-        DIR    *directory_handle_;
+  const string previous_path_;
+  DIR *directory_handle_;
 };
 
 static bool ClearDirectory(const string &path) {
@@ -227,9 +224,9 @@ static bool ClearDirectory(const string &path) {
   bool success = true;
   ScopedWorkingDirectory::DirectoryEntry dirent;
   while (success && swd.NextDirectoryEntry(&dirent)) {
-    success = (dirent.is_directory)
-      ? ClearDirectory(dirent.name) && (rmdir(dirent.name.c_str()) == 0)
-      : (unlink(dirent.name.c_str()) == 0);
+    success = (dirent.is_directory) ? ClearDirectory(dirent.name)
+                                          && (rmdir(dirent.name.c_str()) == 0)
+                                    : (unlink(dirent.name.c_str()) == 0);
   }
 
   return success;
@@ -258,8 +255,8 @@ static int DoAsynchronousScratchCleanup(const string &fqrn) {
     int retval = setsid();
     assert(retval != -1);
     if ((pid = fork()) == 0) {
-      int null_read = open("/dev/null", O_RDONLY);
-      int null_write = open("/dev/null", O_WRONLY);
+      const int null_read = open("/dev/null", O_RDONLY);
+      const int null_write = open("/dev/null", O_WRONLY);
       assert((null_read >= 0) && (null_write >= 0));
       retval = dup2(null_read, 0);
       assert(retval == 0);
@@ -284,11 +281,11 @@ static int DoAsynchronousScratchCleanup(const string &fqrn) {
 
 static void Usage(const string &exe, FILE *output) {
   fprintf(output,
-    "Usage: %s lock|open|rw_mount|rw_umount|rdonly_mount|rdonly_umount|"
-      "clear_scratch|clear_scratch_async|kill_cvmfs <fqrn>\n"
-    "Example: %s rw_umount atlas.cern.ch\n"
-    "This binary is typically called by cvmfs_server.\n",
-    exe.c_str(), exe.c_str());
+          "Usage: %s lock|open|rw_mount|rw_umount|rdonly_mount|rdonly_umount|"
+          "clear_scratch|clear_scratch_async|kill_cvmfs <fqrn>\n"
+          "Example: %s rw_umount atlas.cern.ch\n"
+          "This binary is typically called by cvmfs_server.\n",
+          exe.c_str(), exe.c_str());
 }
 
 
@@ -323,8 +320,8 @@ int main(int argc, char *argv[]) {
 
   // Verify if caller uid matches
   if ((calling_uid != 0) && (calling_uid != repository_uid)) {
-    fprintf(stderr, "called as %d, repository owned by %d\n",
-            calling_uid, repository_uid);
+    fprintf(stderr, "called as %d, repository owned by %d\n", calling_uid,
+            repository_uid);
     return 1;
   }
 
