@@ -23,17 +23,18 @@ using namespace std;  // NOLINT
 namespace cvmfs {
 
 void TLSDestructor(void *data) {
-  Fetcher::ThreadLocalStorage *tls =
-    static_cast<Fetcher::ThreadLocalStorage *>(data);
-  std::vector<Fetcher::ThreadLocalStorage *> *tls_blocks =
-    &tls->fetcher->tls_blocks_;
+  Fetcher::ThreadLocalStorage *tls = static_cast<Fetcher::ThreadLocalStorage *>(
+      data);
+  std::vector<Fetcher::ThreadLocalStorage *> *tls_blocks = &tls->fetcher
+                                                                ->tls_blocks_;
 
   {
-    MutexLockGuard m(tls->fetcher->lock_tls_blocks_);
+    const MutexLockGuard m(tls->fetcher->lock_tls_blocks_);
     for (vector<Fetcher::ThreadLocalStorage *>::iterator
              i = tls_blocks->begin(),
              iEnd = tls_blocks->end();
-         i != iEnd; ++i) {
+         i != iEnd;
+         ++i) {
       if ((*i) == tls) {
         tls_blocks->erase(i);
         break;
@@ -59,7 +60,7 @@ void Fetcher::CleanupTls(ThreadLocalStorage *tls) {
  */
 Fetcher::ThreadLocalStorage *Fetcher::GetTls() {
   ThreadLocalStorage *tls = static_cast<ThreadLocalStorage *>(
-    pthread_getspecific(thread_local_storage_));
+      pthread_getspecific(thread_local_storage_));
   if (tls != NULL)
     return tls;
 
@@ -68,20 +69,18 @@ Fetcher::ThreadLocalStorage *Fetcher::GetTls() {
   MakePipe(tls->pipe_wait);
   tls->download_job.SetCompressed(true);
   tls->download_job.SetProbeHosts(true);
-  int retval = pthread_setspecific(thread_local_storage_, tls);
+  const int retval = pthread_setspecific(thread_local_storage_, tls);
   assert(retval == 0);
 
-  MutexLockGuard m(lock_tls_blocks_);
+  const MutexLockGuard m(lock_tls_blocks_);
   tls_blocks_.push_back(tls);
 
   return tls;
 }
 
 
-int Fetcher::Fetch(
-  const CacheManager::LabeledObject &object,
-  const std::string &alt_url)
-{
+int Fetcher::Fetch(const CacheManager::LabeledObject &object,
+                   const std::string &alt_url) {
   int fd_return;  // Read-only file descriptor that is returned
   int retval;
 
@@ -106,7 +105,8 @@ int Fetcher::Fetch(
   // Synchronization point: either act as a master thread for this object or
   // enqueue to the list of waiting threads.
   pthread_mutex_lock(lock_queues_download_);
-  ThreadQueues::iterator iDownloadQueue = queues_download_.find(object.id);
+  const ThreadQueues::iterator iDownloadQueue = queues_download_.find(
+      object.id);
   if (iDownloadQueue != queues_download_.end()) {
     LogCvmfs(kLogCache, kLogDebug, "waiting for download of %s",
              object.label.path.c_str());
@@ -151,8 +151,8 @@ int Fetcher::Fetch(
   }
   cache_mgr_->CtrlTxn(object.label, 0, txn);
 
-  LogCvmfs(kLogCache, kLogDebug, "miss: %s %s",
-           object.label.path.c_str(), url.c_str());
+  LogCvmfs(kLogCache, kLogDebug, "miss: %s %s", object.label.path.c_str(),
+           url.c_str());
   TransactionSink sink(cache_mgr_, txn);
   tls->download_job.SetUrl(&url);
   tls->download_job.SetSink(&sink);
@@ -164,9 +164,14 @@ int Fetcher::Fetch(
              tls->download_job.GetGidPtr(),
              tls->download_job.GetPidPtr(),
              tls->download_job.GetInterruptCuePtr());
+  } else {
+    *(tls->download_job.GetUidPtr()) = -1;
+    *(tls->download_job.GetGidPtr()) = -1;
+    *(tls->download_job.GetPidPtr()) = -1;
+    *(tls->download_job.GetInterruptCuePtr()) = NULL;
   }
-  tls->download_job.SetCompressed(
-                              object.label.zip_algorithm == zlib::kZlibDefault);
+  tls->download_job.SetCompressed(object.label.zip_algorithm
+                                  == zlib::kZlibDefault);
   tls->download_job.SetRangeOffset(object.label.range_offset);
   tls->download_job.SetRangeSize(static_cast<int64_t>(object.label.size));
   download_mgr_->Fetch(&tls->download_job);
@@ -194,8 +199,7 @@ int Fetcher::Fetch(
   // Download failed
   LogCvmfs(kLogCache, kLogDebug | kLogSyslogErr,
            "failed to fetch %s (hash: %s, error %d [%s])",
-           object.label.path.c_str(),
-           object.id.ToString().c_str(),
+           object.label.path.c_str(), object.id.ToString().c_str(),
            tls->download_job.error_code(),
            download::Code2Ascii(tls->download_job.error_code()));
   cache_mgr_->AbortTxn(txn);
@@ -205,32 +209,32 @@ int Fetcher::Fetch(
 }
 
 
-Fetcher::Fetcher(
-  CacheManager *cache_mgr,
-  download::DownloadManager *download_mgr,
-  BackoffThrottle *backoff_throttle,
-  perf::StatisticsTemplate statistics)
-  : lock_queues_download_(NULL)
-  , lock_tls_blocks_(NULL)
-  , cache_mgr_(cache_mgr)
-  , download_mgr_(download_mgr)
-  , backoff_throttle_(backoff_throttle)
-{
+Fetcher::Fetcher(CacheManager *cache_mgr,
+                 download::DownloadManager *download_mgr,
+                 BackoffThrottle *backoff_throttle,
+                 perf::StatisticsTemplate statistics)
+    : lock_queues_download_(NULL)
+    , lock_tls_blocks_(NULL)
+    , cache_mgr_(cache_mgr)
+    , download_mgr_(download_mgr)
+    , backoff_throttle_(backoff_throttle) {
   int retval;
   retval = pthread_key_create(&thread_local_storage_, TLSDestructor);
   assert(retval == 0);
   lock_queues_download_ = reinterpret_cast<pthread_mutex_t *>(
-    smalloc(sizeof(pthread_mutex_t)));
+      smalloc(sizeof(pthread_mutex_t)));
   retval = pthread_mutex_init(lock_queues_download_, NULL);
   assert(retval == 0);
   lock_tls_blocks_ = reinterpret_cast<pthread_mutex_t *>(
-    smalloc(sizeof(pthread_mutex_t)));
+      smalloc(sizeof(pthread_mutex_t)));
   retval = pthread_mutex_init(lock_tls_blocks_, NULL);
   assert(retval == 0);
-  n_downloads = statistics.RegisterTemplated("n_downloads",
-    "overall number of downloaded files (incl. catalogs, chunks)");
-  n_invocations = statistics.RegisterTemplated("n_invocations",
-    "overall number of object requests (incl. catalogs, chunks)");
+  n_downloads = statistics.RegisterTemplated(
+      "n_downloads",
+      "overall number of downloaded files (incl. catalogs, chunks)");
+  n_invocations = statistics.RegisterTemplated(
+      "n_invocations",
+      "overall number of object requests (incl. catalogs, chunks)");
 }
 
 
@@ -238,7 +242,7 @@ Fetcher::~Fetcher() {
   int retval;
 
   {
-    MutexLockGuard m(lock_tls_blocks_);
+    const MutexLockGuard m(lock_tls_blocks_);
     for (unsigned i = 0; i < tls_blocks_.size(); ++i)
       CleanupTls(tls_blocks_[i]);
   }
@@ -269,12 +273,10 @@ int Fetcher::OpenSelect(const CacheManager::LabeledObject &object) {
 }
 
 
-void Fetcher::SignalWaitingThreads(
-  const int fd,
-  const shash::Any &id,
-  ThreadLocalStorage *tls)
-{
-  MutexLockGuard m(lock_queues_download_);
+void Fetcher::SignalWaitingThreads(const int fd,
+                                   const shash::Any &id,
+                                   ThreadLocalStorage *tls) {
+  const MutexLockGuard m(lock_queues_download_);
   for (unsigned i = 0, s = tls->other_pipes_waiting.size(); i < s; ++i) {
     int fd_dup = (fd >= 0) ? cache_mgr_->Dup(fd) : fd;
     WritePipe(tls->other_pipes_waiting[i], &fd_dup, sizeof(int));
