@@ -31,7 +31,7 @@ FuseRemounter::Status FuseRemounter::ChangeRoot(const shash::Any &root_hash) {
   if (mountpoint_->catalog_mgr()->GetRootHash() == root_hash)
     return kStatusUp2Date;
 
-  FenceGuard fence_guard(&fence_maintenance_);
+  const FenceGuard fence_guard(&fence_maintenance_);
   if (IsInMaintenanceMode())
     return kStatusMaintenance;
 
@@ -68,22 +68,21 @@ FuseRemounter::Status FuseRemounter::ChangeRoot(const shash::Any &root_hash) {
  * drainout mode if a new catalog is available online.
  */
 FuseRemounter::Status FuseRemounter::Check() {
-  FenceGuard fence_guard(&fence_maintenance_);
+  const FenceGuard fence_guard(&fence_maintenance_);
   if (IsInMaintenanceMode())
     return kStatusMaintenance;
 
   LogCvmfs(kLogCvmfs, kLogDebug,
            "catalog TTL expired, checking revision against blacklists");
-  if (mountpoint_->ReloadBlacklists() &&
-      mountpoint_->catalog_mgr()->IsRevisionBlacklisted())
-  {
+  if (mountpoint_->ReloadBlacklists()
+      && mountpoint_->catalog_mgr()->IsRevisionBlacklisted()) {
     PANIC(kLogDebug | kLogSyslogErr,
           "repository revision blacklisted, aborting");
   }
 
   LogCvmfs(kLogCvmfs, kLogDebug, "remounting root catalog");
-  const catalog::LoadReturn retval =
-                                    mountpoint_->catalog_mgr()->RemountDryrun();
+  const catalog::LoadReturn retval = mountpoint_->catalog_mgr()
+                                         ->RemountDryrun();
   switch (retval) {
     case catalog::kLoadNew:
       SetOfflineMode(false);
@@ -108,14 +107,14 @@ FuseRemounter::Status FuseRemounter::Check() {
       SetOfflineMode(true);
       catalogs_valid_until_ = time(NULL) + MountPoint::kShortTermTTL;
       SetAlarm(MountPoint::kShortTermTTL);
-      return (retval == catalog::kLoadFail) ?
-             kStatusFailGeneral : kStatusFailNoSpace;
+      return (retval == catalog::kLoadFail) ? kStatusFailGeneral
+                                            : kStatusFailNoSpace;
     case catalog::kLoadUp2Date: {
       LogCvmfs(kLogCvmfs, kLogDebug,
                "catalog up to date (could be offline mode)");
       SetOfflineMode(mountpoint_->catalog_mgr()->offline_mode());
-      unsigned ttl = offline_mode_ ?
-        MountPoint::kShortTermTTL : mountpoint_->GetEffectiveTtlSec();
+      const unsigned ttl = offline_mode_ ? MountPoint::kShortTermTTL
+                                         : mountpoint_->GetEffectiveTtlSec();
       catalogs_valid_until_ = time(NULL) + ttl;
       SetAlarm(ttl);
       return kStatusUp2Date;
@@ -133,7 +132,7 @@ FuseRemounter::Status FuseRemounter::Check() {
 FuseRemounter::Status FuseRemounter::CheckSynchronously() {
   BackoffThrottle throttle;
   while (true) {
-    Status status = Check();
+    const Status status = Check();
     switch (status) {
       case kStatusDraining:
         TryFinish();
@@ -164,15 +163,14 @@ FuseRemounter::FuseRemounter(MountPoint *mountpoint,
                              cvmfs::InodeGenerationInfo *inode_generation_info,
                              void **fuse_channel_or_session,
                              bool fuse_notify_invalidation)
-    : mountpoint_(mountpoint),
-      inode_generation_info_(inode_generation_info),
-      invalidator_(new FuseInvalidator(mountpoint,
-                                       fuse_channel_or_session,
-                                       fuse_notify_invalidation)),
-      invalidator_handle_(static_cast<int>(mountpoint->kcache_timeout_sec())),
-      fence_(new Fence()),
-      offline_mode_(false),
-      catalogs_valid_until_(MountPoint::kIndefiniteDeadline) {
+    : mountpoint_(mountpoint)
+    , inode_generation_info_(inode_generation_info)
+    , invalidator_(new FuseInvalidator(mountpoint, fuse_channel_or_session,
+                                       fuse_notify_invalidation))
+    , invalidator_handle_(static_cast<int>(mountpoint->kcache_timeout_sec()))
+    , fence_(new Fence())
+    , offline_mode_(false)
+    , catalogs_valid_until_(MountPoint::kIndefiniteDeadline) {
   memset(&thread_remount_trigger_, 0, sizeof(thread_remount_trigger_));
   pipe_remount_trigger_[0] = pipe_remount_trigger_[1] = -1;
   atomic_init32(&drainout_mode_);
@@ -207,11 +205,11 @@ void *FuseRemounter::MainRemountTrigger(void *data) {
   watch_ctrl.events = POLLIN | POLLPRI;
   while (true) {
     watch_ctrl.revents = 0;
-    int retval = poll(&watch_ctrl, 1, timeout_ms);
+    const int retval = poll(&watch_ctrl, 1, timeout_ms);
     if (retval < 0) {
       if (errno == EINTR) {
         if (timeout_ms >= 0) {
-          uint64_t now = platform_monotonic_time();
+          const uint64_t now = platform_monotonic_time();
           timeout_ms = (now > deadline) ? 0 : (deadline - now) * 1000;
         }
         continue;
@@ -274,13 +272,13 @@ void FuseRemounter::Spawn() {
   invalidator_->Spawn();
   if (!mountpoint_->fixed_catalog()) {
     MakePipe(pipe_remount_trigger_);
-    int retval = pthread_create(
-      &thread_remount_trigger_, NULL, MainRemountTrigger, this);
+    const int retval = pthread_create(&thread_remount_trigger_, NULL,
+                                      MainRemountTrigger, this);
     assert(retval == 0);
 
     SetOfflineMode(mountpoint_->catalog_mgr()->offline_mode());
-    unsigned ttl = offline_mode_ ?
-      MountPoint::kShortTermTTL : mountpoint_->GetEffectiveTtlSec();
+    const unsigned ttl = offline_mode_ ? MountPoint::kShortTermTTL
+                                       : mountpoint_->GetEffectiveTtlSec();
     catalogs_valid_until_ = time(NULL) + ttl;
     SetAlarm(ttl);
   }
@@ -294,7 +292,7 @@ void FuseRemounter::Spawn() {
  * flushed.
  */
 void FuseRemounter::TryFinish(const shash::Any &root_hash) {
-  FenceGuard fence_guard(&fence_maintenance_);
+  const FenceGuard fence_guard(&fence_maintenance_);
   if (IsInMaintenanceMode())
     return;
   if (!EnterCriticalSection())
@@ -329,8 +327,8 @@ void FuseRemounter::TryFinish(const shash::Any &root_hash) {
     retval = mountpoint_->catalog_mgr()->ChangeRoot(root_hash);
   }
   if (mountpoint_->inode_annotation()) {
-    inode_generation_info_->inode_generation =
-      mountpoint_->inode_annotation()->GetGeneration();
+    inode_generation_info_->inode_generation = mountpoint_->inode_annotation()
+                                                   ->GetGeneration();
   }
   mountpoint_->ReEvaluateAuthz();
   fence_->Open();
