@@ -14,7 +14,6 @@
 #include <cassert>
 #include <cstdlib>
 #include <cstring>
-
 #include <string>
 #include <vector>
 
@@ -29,7 +28,7 @@ using namespace std;  // NOLINT
 
 namespace glue {
 
-PathStore &PathStore::operator= (const PathStore &other) {
+PathStore &PathStore::operator=(const PathStore &other) {
   if (&other == this)
     return *this;
 
@@ -39,21 +38,18 @@ PathStore &PathStore::operator= (const PathStore &other) {
 }
 
 
-PathStore::PathStore(const PathStore &other) {
-  CopyFrom(other);
-}
+PathStore::PathStore(const PathStore &other) { CopyFrom(other); }
 
 
 void PathStore::CopyFrom(const PathStore &other) {
   map_ = other.map_;
 
   string_heap_ = new StringHeap(other.string_heap_->used());
-  shash::Md5 empty_path = map_.empty_key();
+  const shash::Md5 empty_path = map_.empty_key();
   for (unsigned i = 0; i < map_.capacity(); ++i) {
     if (map_.keys()[i] != empty_path) {
-      (map_.values() + i)->name =
-      string_heap_->AddString(map_.values()[i].name.length(),
-                              map_.values()[i].name.data());
+      (map_.values() + i)->name = string_heap_->AddString(
+          map_.values()[i].name.length(), map_.values()[i].name.data());
     }
   }
 }
@@ -63,9 +59,8 @@ void PathStore::CopyFrom(const PathStore &other) {
 
 
 void InodeTracker::InitLock() {
-  lock_ =
-    reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
-  int retval = pthread_mutex_init(lock_, NULL);
+  lock_ = reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
+  const int retval = pthread_mutex_init(lock_, NULL);
   assert(retval == 0);
 }
 
@@ -92,7 +87,7 @@ InodeTracker::InodeTracker(const InodeTracker &other) {
 }
 
 
-InodeTracker &InodeTracker::operator= (const InodeTracker &other) {
+InodeTracker &InodeTracker::operator=(const InodeTracker &other) {
   if (&other == this)
     return *this;
 
@@ -136,7 +131,7 @@ DentryTracker::DentryTracker(const DentryTracker &other) {
 }
 
 
-DentryTracker &DentryTracker::operator= (const DentryTracker &other) {
+DentryTracker &DentryTracker::operator=(const DentryTracker &other) {
   if (&other == this)
     return *this;
 
@@ -170,9 +165,10 @@ DentryTracker *DentryTracker::Move() {
 void DentryTracker::SpawnCleaner(unsigned interval_s) {
   assert(pipe_terminate_[0] == -1);
   cleaning_interval_ms_ = interval_s * 1000;
-  if (cleaning_interval_ms_ == 0) cleaning_interval_ms_ = -1;
+  if (cleaning_interval_ms_ == 0)
+    cleaning_interval_ms_ = -1;
   MakePipe(pipe_terminate_);
-  int retval = pthread_create(&thread_cleaner_, NULL, MainCleaner, this);
+  const int retval = pthread_create(&thread_cleaner_, NULL, MainCleaner, this);
   assert(retval == 0);
 }
 
@@ -184,15 +180,16 @@ void *DentryTracker::MainCleaner(void *data) {
   struct pollfd watch_term;
   watch_term.fd = tracker->pipe_terminate_[0];
   watch_term.events = POLLIN | POLLPRI;
-  int timeout_ms = tracker->cleaning_interval_ms_;;
+  int timeout_ms = tracker->cleaning_interval_ms_;
+  ;
   uint64_t deadline = platform_monotonic_time() + timeout_ms / 1000;
   while (true) {
     watch_term.revents = 0;
-    int retval = poll(&watch_term, 1, timeout_ms);
+    const int retval = poll(&watch_term, 1, timeout_ms);
     if (retval < 0) {
       if (errno == EINTR) {
         if (timeout_ms >= 0) {
-          uint64_t now = platform_monotonic_time();
+          const uint64_t now = platform_monotonic_time();
           timeout_ms = (now > deadline) ? 0 : (deadline - now) * 1000;
         }
         continue;
@@ -221,9 +218,8 @@ void *DentryTracker::MainCleaner(void *data) {
 
 
 void DentryTracker::InitLock() {
-  lock_ =
-    reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
-  int retval = pthread_mutex_init(lock_, NULL);
+  lock_ = reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
+  const int retval = pthread_mutex_init(lock_, NULL);
   assert(retval == 0);
 }
 
@@ -243,9 +239,8 @@ DentryTracker::Cursor DentryTracker::BeginEnumerate() {
 }
 
 
-bool DentryTracker::NextEntry(Cursor *cursor,
-  uint64_t *inode_parent, NameString *name)
-{
+bool DentryTracker::NextEntry(Cursor *cursor, uint64_t *inode_parent,
+                              NameString *name) {
   if (cursor->head == NULL)
     return false;
   if (cursor->pos >= entries_.size())
@@ -258,9 +253,7 @@ bool DentryTracker::NextEntry(Cursor *cursor,
 }
 
 
-void DentryTracker::EndEnumerate(Cursor * /* cursor */) {
-  Unlock();
-}
+void DentryTracker::EndEnumerate(Cursor * /* cursor */) { Unlock(); }
 
 
 //------------------------------------------------------------------------------
@@ -284,11 +277,11 @@ PageCacheTracker::PageCacheTracker(const PageCacheTracker &other) {
 }
 
 
-PageCacheTracker &PageCacheTracker::operator= (const PageCacheTracker &other) {
+PageCacheTracker &PageCacheTracker::operator=(const PageCacheTracker &other) {
   if (&other == this)
     return *this;
 
-  MutexLockGuard guard(lock_);
+  const MutexLockGuard guard(lock_);
   CopyFrom(other);
   return *this;
 }
@@ -308,17 +301,14 @@ void PageCacheTracker::CopyFrom(const PageCacheTracker &other) {
 
 
 void PageCacheTracker::InitLock() {
-  lock_ =
-    reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
-  int retval = pthread_mutex_init(lock_, NULL);
+  lock_ = reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
+  const int retval = pthread_mutex_init(lock_, NULL);
   assert(retval == 0);
 }
 
 PageCacheTracker::OpenDirectives PageCacheTracker::Open(
   uint64_t inode, const shash::Any &hash, const struct stat &info)
 {
-  assert(inode == info.st_ino);
-
   OpenDirectives open_directives;
   // Old behavior: always flush page cache on open
   if (!is_active_)
@@ -327,14 +317,14 @@ PageCacheTracker::OpenDirectives PageCacheTracker::Open(
   if (inode != info.st_ino) {
     PANIC(kLogStderr | kLogDebug,
           "invalid entry on open: %" PRIu64 " with st_ino=%" PRIu64,
-          " hash=%s size=%" PRIu64,
-          inode, info.st_ino, hash.ToString().c_str(), info.st_size);
+          " hash=%s size=%" PRIu64, inode, info.st_ino, hash.ToString().c_str(),
+          info.st_size);
   }
 
-  MutexLockGuard guard(lock_);
+  const MutexLockGuard guard(lock_);
 
   Entry entry;
-  bool retval = map_.Lookup(inode, &entry);
+  const bool retval = map_.Lookup(inode, &entry);
   if (!retval) {
     open_directives.keep_cache = true;
     open_directives.direct_io = false;
@@ -398,7 +388,7 @@ PageCacheTracker::OpenDirectives PageCacheTracker::OpenDirect() {
   if (!is_active_)
     return open_directives;
 
-  MutexLockGuard guard(lock_);
+  const MutexLockGuard guard(lock_);
   statistics_.n_open_direct++;
   return open_directives;
 }
@@ -407,7 +397,7 @@ void PageCacheTracker::Close(uint64_t inode) {
   if (!is_active_)
     return;
 
-  MutexLockGuard guard(lock_);
+  const MutexLockGuard guard(lock_);
   Entry entry;
   bool retval = map_.Lookup(inode, &entry);
 
@@ -438,15 +428,15 @@ void PageCacheTracker::Close(uint64_t inode) {
             "  -  open counter %d  -  hash %s",
             inode, old_open, entry.hash.ToString().c_str());
     }
-    uint64_t inode_update = stat_store_.Erase(entry.idx_stat);
+    const uint64_t inode_update = stat_store_.Erase(entry.idx_stat);
     Entry entry_update;
     retval = map_.Lookup(inode_update, &entry_update);
     if (!retval) {
       PANIC(kLogSyslogErr | kLogDebug,
             "invalid inode in page cache tracker: inode %" PRIu64
-            ", replacing %" PRIu64, inode_update, inode);
+            ", replacing %" PRIu64,
+            inode_update, inode);
     }
-    assert(retval);
     entry_update.idx_stat = entry.idx_stat;
     map_.Insert(inode_update, entry_update);
     entry.idx_stat = -1;
@@ -454,15 +444,13 @@ void PageCacheTracker::Close(uint64_t inode) {
   map_.Insert(inode, entry);
 }
 
-PageCacheTracker::EvictRaii::EvictRaii(PageCacheTracker *t)
-  : tracker_(t)
-{
-  int retval = pthread_mutex_lock(tracker_->lock_);
+PageCacheTracker::EvictRaii::EvictRaii(PageCacheTracker *t) : tracker_(t) {
+  const int retval = pthread_mutex_lock(tracker_->lock_);
   assert(retval == 0);
 }
 
 PageCacheTracker::EvictRaii::~EvictRaii() {
-  int retval = pthread_mutex_unlock(tracker_->lock_);
+  const int retval = pthread_mutex_unlock(tracker_->lock_);
   assert(retval == 0);
 }
 
@@ -470,7 +458,7 @@ void PageCacheTracker::EvictRaii::Evict(uint64_t inode) {
   if (!tracker_->is_active_)
     return;
 
-  bool contained_inode = tracker_->map_.Erase(inode);
+  const bool contained_inode = tracker_->map_.Erase(inode);
   if (contained_inode)
     tracker_->statistics_.n_remove++;
 }
