@@ -2,12 +2,13 @@
  * This file is part of the CernVM File System.
  */
 
-#include "cvmfs_config.h"
+
 #include "task_hash.h"
 
 #include <cstdlib>
 
-#include "hash.h"
+#include "crypto/hash.h"
+#include "util/exception.h"
 
 
 void TaskHash::Process(BlockItem *input_block) {
@@ -23,7 +24,7 @@ void TaskHash::Process(BlockItem *input_block) {
       shash::Final(chunk->hash_ctx(), chunk->hash_ptr());
       break;
     default:
-      abort();
+      PANIC(NULL);
   }
 
   tubes_out_->Dispatch(input_block);
