@@ -12,10 +12,8 @@
 #include "util/logging.h"
 
 
-void TaskWrite::OnBlockComplete(
-  const upload::UploaderResults &results,
-  BlockItem *block_item)
-{
+void TaskWrite::OnBlockComplete(const upload::UploaderResults &results,
+                                BlockItem *block_item) {
   if (results.return_code != 0) {
     PANIC(kLogStderr, "block upload failed (code: %d)", results.return_code);
   }
@@ -24,18 +22,15 @@ void TaskWrite::OnBlockComplete(
 }
 
 
-void TaskWrite::OnChunkComplete(
-  const upload::UploaderResults &results,
-  ChunkItem *chunk_item)
-{
+void TaskWrite::OnChunkComplete(const upload::UploaderResults &results,
+                                ChunkItem *chunk_item) {
   if (results.return_code != 0) {
     PANIC(kLogStderr, "chunk upload failed (code: %d)", results.return_code);
   }
 
   FileItem *file_item = chunk_item->file_item();
-  file_item->RegisterChunk(FileChunk(*chunk_item->hash_ptr(),
-                                     chunk_item->offset(),
-                                     chunk_item->size()));
+  file_item->RegisterChunk(FileChunk(
+      *chunk_item->hash_ptr(), chunk_item->offset(), chunk_item->size()));
   delete chunk_item;
 
   if (file_item->IsProcessed()) {
@@ -52,8 +47,8 @@ void TaskWrite::Process(BlockItem *input_block) {
     // The closure passed here, is called by the AbstractUploader as soon as
     // it successfully committed the complete chunk
     handle = uploader_->InitStreamedUpload(
-      upload::AbstractUploader::MakeClosure(
-        &TaskWrite::OnChunkComplete, this, chunk_item));
+        upload::AbstractUploader::MakeClosure(
+            &TaskWrite::OnChunkComplete, this, chunk_item));
     assert(handle != NULL);
     chunk_item->set_upload_handle(handle);
   }
@@ -61,11 +56,11 @@ void TaskWrite::Process(BlockItem *input_block) {
   switch (input_block->type()) {
     case BlockItem::kBlockData:
       uploader_->ScheduleUpload(
-        handle,
-        upload::AbstractUploader::UploadBuffer(
-          input_block->size(), input_block->data()),
-        upload::AbstractUploader::MakeClosure(
-          &TaskWrite::OnBlockComplete, this, input_block));
+          handle,
+          upload::AbstractUploader::UploadBuffer(input_block->size(),
+                                                 input_block->data()),
+          upload::AbstractUploader::MakeClosure(
+              &TaskWrite::OnBlockComplete, this, input_block));
       break;
     case BlockItem::kBlockStop:
       // If there is a sole piece and a legacy bulk chunk, two times the same
