@@ -17,8 +17,9 @@ using namespace std;  // NOLINT
 
 JsonDocument *JsonDocument::Create(const string &text) {
   UniquePtr<JsonDocument> json(new JsonDocument());
-  bool retval = json->Parse(text);
-  if (!retval) return NULL;
+  const bool retval = json->Parse(text);
+  if (!retval)
+    return NULL;
   return json.Release();
 }
 
@@ -41,10 +42,11 @@ string JsonDocument::EscapeString(const string &input) {
 }
 
 JsonDocument::JsonDocument()
-    : allocator_(kDefaultBlockSize), root_(NULL), raw_text_(NULL) {}
+    : allocator_(kDefaultBlockSize), root_(NULL), raw_text_(NULL) { }
 
 JsonDocument::~JsonDocument() {
-  if (raw_text_) free(raw_text_);
+  if (raw_text_)
+    free(raw_text_);
 }
 
 /**
@@ -63,8 +65,8 @@ bool JsonDocument::Parse(const string &text) {
   char *error_pos = 0;
   char *error_desc = 0;
   int error_line = 0;
-  JSON *root =
-      json_parse(raw_text_, &error_pos, &error_desc, &error_line, &allocator_);
+  JSON *root = json_parse(raw_text_, &error_pos, &error_desc, &error_line,
+                          &allocator_);
 
   // check if the json string was parsed successfully
   if (!root) {
@@ -110,8 +112,9 @@ string JsonDocument::PrintArray(JSON *first_child, PrintOptions print_options) {
  * Can be used as a canonical representation to sign or encrypt a JSON text.
  */
 string JsonDocument::PrintCanonical() {
-  if (!root_) return "";
-  PrintOptions print_options;
+  if (!root_)
+    return "";
+  const PrintOptions print_options;
   return PrintObject(root_->first_child, print_options);
 }
 
@@ -144,7 +147,8 @@ string JsonDocument::PrintObject(JSON *first_child,
  * JSON string for humans.
  */
 string JsonDocument::PrintPretty() {
-  if (!root_) return "";
+  if (!root_)
+    return "";
   PrintOptions print_options;
   print_options.with_whitespace = true;
   return PrintObject(root_->first_child, print_options);
@@ -154,10 +158,12 @@ std::string JsonDocument::PrintValue(JSON *value, PrintOptions print_options) {
   assert(value);
 
   string result;
-  for (unsigned i = 0; i < print_options.num_indent; ++i) result.push_back(' ');
+  for (unsigned i = 0; i < print_options.num_indent; ++i)
+    result.push_back(' ');
   if (value->name) {
     result += "\"" + EscapeString(value->name) + "\":";
-    if (print_options.with_whitespace) result += " ";
+    if (print_options.with_whitespace)
+      result += " ";
   }
   switch (value->type) {
     case JSON_NULL:
@@ -189,7 +195,8 @@ std::string JsonDocument::PrintValue(JSON *value, PrintOptions print_options) {
 
 JSON *JsonDocument::SearchInObject(const JSON *json_object, const string &name,
                                    const json_type type) {
-  if (!json_object || (json_object->type != JSON_OBJECT)) return NULL;
+  if (!json_object || (json_object->type != JSON_OBJECT))
+    return NULL;
 
   JSON *walker = json_object->first_child;
   while (walker != NULL) {
@@ -201,7 +208,7 @@ JSON *JsonDocument::SearchInObject(const JSON *json_object, const string &name,
   return NULL;
 }
 
-template <>
+template<>
 bool GetFromJSON<std::string>(const JSON *object, const std::string &name,
                               std::string *value) {
   const JSON *o = JsonDocument::SearchInObject(object, name, JSON_STRING);
@@ -217,7 +224,7 @@ bool GetFromJSON<std::string>(const JSON *object, const std::string &name,
   return true;
 }
 
-template <>
+template<>
 bool GetFromJSON<int>(const JSON *object, const std::string &name, int *value) {
   const JSON *o = JsonDocument::SearchInObject(object, name, JSON_INT);
 
@@ -230,7 +237,7 @@ bool GetFromJSON<int>(const JSON *object, const std::string &name, int *value) {
   return true;
 }
 
-template <>
+template<>
 bool GetFromJSON<float>(const JSON *object, const std::string &name,
                         float *value) {
   const JSON *o = JsonDocument::SearchInObject(object, name, JSON_FLOAT);
