@@ -36,12 +36,11 @@ using namespace std;  // NOLINT
  * Create the cvmfs_attr struct which contains the same information
  * as a stat, but also has pointers to the hash, symlink, and name.
  */
-struct cvmfs_attr* cvmfs_attr_init()
-{
+struct cvmfs_attr *cvmfs_attr_init() {
   struct cvmfs_attr *attr;
   attr = reinterpret_cast<cvmfs_attr *>(calloc(1, sizeof(*attr)));
-  attr->version  = 1;
-  attr->size     = sizeof(*attr);
+  attr->version = 1;
+  attr->size = sizeof(*attr);
   return attr;
 }
 
@@ -50,8 +49,7 @@ struct cvmfs_attr* cvmfs_attr_init()
  * Destroy the cvmfs_attr struct and frees the checksum, symlink,
  * name, and xattrs.
  */
-void cvmfs_attr_free(struct cvmfs_attr *attr)
-{
+void cvmfs_attr_free(struct cvmfs_attr *attr) {
   if (attr) {
     free(attr->cvm_checksum);
     free(attr->cvm_symlink);
@@ -63,15 +61,13 @@ void cvmfs_attr_free(struct cvmfs_attr *attr)
 }
 
 
-struct cvmfs_nc_attr *cvmfs_nc_attr_init()
-{
+struct cvmfs_nc_attr *cvmfs_nc_attr_init() {
   struct cvmfs_nc_attr *attr;
   attr = reinterpret_cast<cvmfs_nc_attr *>(calloc(1, sizeof(*attr)));
   return attr;
 }
 
-void cvmfs_nc_attr_free(struct cvmfs_nc_attr *nc_attr)
-{
+void cvmfs_nc_attr_free(struct cvmfs_nc_attr *nc_attr) {
   if (nc_attr) {
     free(nc_attr->mountpoint);
     free(nc_attr->hash);
@@ -86,14 +82,12 @@ void cvmfs_nc_attr_free(struct cvmfs_nc_attr *nc_attr)
  * parent paths, which is needed to ensure proper loading of nested catalogs
  * before the child is accessed.
  */
-static int expand_path(
-  const int depth,
-  LibContext *ctx,
-  char const *path,
-  string *expanded_path)
-{
-  string p_path = GetParentPath(path);
-  string fname = GetFileName(path);
+static int expand_path(const int depth,
+                       LibContext *ctx,
+                       char const *path,
+                       string *expanded_path) {
+  const string p_path = GetParentPath(path);
+  const string fname = GetFileName(path);
   int rc;
 
   if (fname == "..") {
@@ -105,7 +99,8 @@ static int expand_path(
       // attempt to access parent path of the root of the repository
       LogCvmfs(kLogCvmfs, kLogDebug,
                "libcvmfs cannot resolve symlinks to paths outside of the repo: "
-               "%s", path);
+               "%s",
+               path);
       errno = ENOENT;
       return -1;
     }
@@ -129,7 +124,7 @@ static int expand_path(
     }
   }
 
-  if (buf.length() == 0 || buf[buf.length()-1] != '/') {
+  if (buf.length() == 0 || buf[buf.length() - 1] != '/') {
     buf += "/";
   }
   buf += fname;
@@ -156,7 +151,7 @@ static int expand_path(
 
   // expand symbolic link
 
-  char *ln_buf = reinterpret_cast<char *>(alloca(st.st_size+2));
+  char *ln_buf = reinterpret_cast<char *>(alloca(st.st_size + 2));
   if (!ln_buf) {
     errno = ENOMEM;
     return -1;
@@ -168,11 +163,10 @@ static int expand_path(
   }
   if (ln_buf[0] == '/') {
     // symlink is absolute path, strip /cvmfs/$repo
-    unsigned len = ctx->mount_point()->fqrn().length();
-    if (strncmp(ln_buf, ctx->mount_point()->fqrn().c_str(), len) == 0 &&
-        (ln_buf[len] == '/' || ln_buf[len] == '\0'))
-    {
-      buf = ln_buf+len;
+    const unsigned len = ctx->mount_point()->fqrn().length();
+    if (strncmp(ln_buf, ctx->mount_point()->fqrn().c_str(), len) == 0
+        && (ln_buf[len] == '/' || ln_buf[len] == '\0')) {
+      buf = ln_buf + len;
       if (ln_buf[len] == '\0') {
         buf += "/";
       }
@@ -202,17 +196,16 @@ static int expand_path(
  */
 static int expand_ppath(LibContext *ctx,
                         const char *path,
-                        string *expanded_path)
-{
-  string p_path = GetParentPath(path);
-  string fname = GetFileName(path);
+                        string *expanded_path) {
+  const string p_path = GetParentPath(path);
+  const string fname = GetFileName(path);
 
   if (p_path == "") {
     *expanded_path = path;
     return 0;
   }
 
-  int rc = expand_path(0, ctx, p_path.c_str(), expanded_path);
+  const int rc = expand_path(0, ctx, p_path.c_str(), expanded_path);
   if (rc != 0) {
     return rc;
   }
@@ -242,14 +235,9 @@ int cvmfs_open(LibContext *ctx, const char *path) {
 }
 
 
-ssize_t cvmfs_pread(
-  LibContext *ctx,
-  int fd,
-  void *buf,
-  size_t size,
-  off_t off)
-{
-  ssize_t nbytes = ctx->Pread(fd, buf, size, off);
+ssize_t cvmfs_pread(LibContext *ctx, int fd, void *buf, size_t size,
+                    off_t off) {
+  const ssize_t nbytes = ctx->Pread(fd, buf, size, off);
   if (nbytes < 0) {
     errno = -nbytes;
     return -1;
@@ -258,9 +246,8 @@ ssize_t cvmfs_pread(
 }
 
 
-int cvmfs_close(LibContext *ctx, int fd)
-{
-  int rc = ctx->Close(fd);
+int cvmfs_close(LibContext *ctx, int fd) {
+  const int rc = ctx->Close(fd);
   if (rc < 0) {
     errno = -rc;
     return -1;
@@ -269,12 +256,7 @@ int cvmfs_close(LibContext *ctx, int fd)
 }
 
 
-int cvmfs_readlink(
-  LibContext *ctx,
-  const char *path,
-  char *buf,
-  size_t size
-) {
+int cvmfs_readlink(LibContext *ctx, const char *path, char *buf, size_t size) {
   string lpath;
   int rc;
   rc = expand_ppath(ctx, path, &lpath);
@@ -328,11 +310,9 @@ int cvmfs_lstat(LibContext *ctx, const char *path, struct stat *st) {
 }
 
 
-int cvmfs_stat_attr(
-  LibContext *ctx,
-  const char *path,
-  struct cvmfs_attr *attr
-) {
+int cvmfs_stat_attr(LibContext *ctx,
+                    const char *path,
+                    struct cvmfs_attr *attr) {
   string lpath;
   int rc;
   rc = expand_ppath(ctx, path, &lpath);
@@ -350,12 +330,10 @@ int cvmfs_stat_attr(
 }
 
 
-int cvmfs_listdir(
-  LibContext *ctx,
-  const char *path,
-  char ***buf,
-  size_t *buflen
-) {
+int cvmfs_listdir(LibContext *ctx,
+                  const char *path,
+                  char ***buf,
+                  size_t *buflen) {
   string lpath;
   int rc;
   rc = expand_path(0, ctx, path, &lpath);
@@ -373,13 +351,11 @@ int cvmfs_listdir(
   return 0;
 }
 
-int cvmfs_listdir_contents(
-  LibContext *ctx,
-  const char *path,
-  char ***buf,
-  size_t *listlen,
-  size_t *buflen
-) {
+int cvmfs_listdir_contents(LibContext *ctx,
+                           const char *path,
+                           char ***buf,
+                           size_t *listlen,
+                           size_t *buflen) {
   string lpath;
   int rc;
   rc = expand_path(0, ctx, path, &lpath);
@@ -396,13 +372,11 @@ int cvmfs_listdir_contents(
   return 0;
 }
 
-int cvmfs_listdir_stat(
-  LibContext *ctx,
-  const char *path,
-  struct cvmfs_stat_t **buf,
-  size_t *listlen,
-  size_t *buflen
-) {
+int cvmfs_listdir_stat(LibContext *ctx,
+                       const char *path,
+                       struct cvmfs_stat_t **buf,
+                       size_t *listlen,
+                       size_t *buflen) {
   string lpath;
   int rc;
   rc = expand_path(0, ctx, path, &lpath);
@@ -420,12 +394,9 @@ int cvmfs_listdir_stat(
 }
 
 
-
-int cvmfs_stat_nc(
-  LibContext *ctx,
-  const char *path,
-  struct cvmfs_nc_attr *nc_attr
-) {
+int cvmfs_stat_nc(LibContext *ctx,
+                  const char *path,
+                  struct cvmfs_nc_attr *nc_attr) {
   string lpath;
   int rc;
   rc = expand_path(0, ctx, path, &lpath);
@@ -443,12 +414,10 @@ int cvmfs_stat_nc(
 }
 
 
-int cvmfs_list_nc(
-  LibContext *ctx,
-  const char *path,
-  char ***buf,
-  size_t *buflen
-) {
+int cvmfs_list_nc(LibContext *ctx,
+                  const char *path,
+                  char ***buf,
+                  size_t *buflen) {
   string lpath;
   int rc;
   rc = expand_path(0, ctx, path, &lpath);
@@ -466,10 +435,10 @@ int cvmfs_list_nc(
 }
 
 
-void cvmfs_list_free(char **buf)
-{
+void cvmfs_list_free(char **buf) {
   // Quick return if base pointer is NULL
-  if (!buf) return;
+  if (!buf)
+    return;
   size_t pos = 0;
   // Iterate over each non-null entry and free
   // This assumes no null entries, which don't currently exist
@@ -480,25 +449,19 @@ void cvmfs_list_free(char **buf)
   free(buf);
 }
 
-void cvmfs_enable_threaded(
-  LibContext *ctx
-) {
-  ctx->EnableMultiThreaded();
-}
+void cvmfs_enable_threaded(LibContext *ctx) { ctx->EnableMultiThreaded(); }
 
-cvmfs_errors cvmfs_attach_repo_v2(
-  const char *fqrn,
-  SimpleOptionsParser *opts,
-  LibContext **ctx)
-{
+cvmfs_errors cvmfs_attach_repo_v2(const char *fqrn,
+                                  SimpleOptionsParser *opts,
+                                  LibContext **ctx) {
   assert(ctx != NULL);
   opts->SwitchTemplateManager(new DefaultOptionsTemplateManager(fqrn));
   *ctx = LibContext::Create(fqrn, opts);
   assert(*ctx != NULL);
-  loader::Failures result = (*ctx)->mount_point()->boot_status();
+  const loader::Failures result = (*ctx)->mount_point()->boot_status();
   if (result != loader::kFailOk) {
-    LogCvmfs(kLogCvmfs, kLogStderr, "Attaching %s failed: %s (%d)",
-             fqrn, (*ctx)->mount_point()->boot_error().c_str(), result);
+    LogCvmfs(kLogCvmfs, kLogStderr, "Attaching %s failed: %s (%d)", fqrn,
+             (*ctx)->mount_point()->boot_error().c_str(), result);
     delete *ctx;
     *ctx = NULL;
   }
@@ -511,13 +474,11 @@ void cvmfs_adopt_options(cvmfs_context *ctx, SimpleOptionsParser *opts) {
 }
 
 
-void cvmfs_detach_repo(LibContext *ctx) {
-  delete ctx;
-}
+void cvmfs_detach_repo(LibContext *ctx) { delete ctx; }
 
 
 cvmfs_errors cvmfs_init_v2(SimpleOptionsParser *opts) {
-  int result = LibGlobals::Initialize(opts);
+  const int result = LibGlobals::Initialize(opts);
   if (result != loader::kFailOk) {
     LogCvmfs(kLogCvmfs, kLogStderr, "Initialization failed: %s (%d)",
              LibGlobals::GetInstance()->file_system()->boot_error().c_str(),
@@ -528,27 +489,22 @@ cvmfs_errors cvmfs_init_v2(SimpleOptionsParser *opts) {
 }
 
 
-void cvmfs_fini() {
-  LibGlobals::CleanupInstance();
-}
+void cvmfs_fini() { LibGlobals::CleanupInstance(); }
 
 
 static void (*ext_log_fn)(const char *msg) = NULL;
 
 
-static void libcvmfs_log_fn(
-  const LogSource /*source*/,
-  const int /*mask*/,
-  const char *msg
-) {
+static void libcvmfs_log_fn(const LogSource /*source*/,
+                            const int /*mask*/,
+                            const char *msg) {
   if (ext_log_fn) {
     (*ext_log_fn)(msg);
   }
 }
 
 
-void cvmfs_set_log_fn(void (*log_fn)(const char *msg))
-{
+void cvmfs_set_log_fn(void (*log_fn)(const char *msg)) {
   ext_log_fn = log_fn;
   if (log_fn == NULL) {
     SetAltLogFunc(NULL);
@@ -560,8 +516,8 @@ void cvmfs_set_log_fn(void (*log_fn)(const char *msg))
 
 char *cvmfs_statistics_format(cvmfs_context *ctx) {
   assert(ctx != NULL);
-  std::string stats = ctx->mount_point()->statistics()
-    ->PrintList(perf::Statistics::kPrintHeader);
+  const std::string stats = ctx->mount_point()->statistics()->PrintList(
+      perf::Statistics::kPrintHeader);
   return strdup(stats.c_str());
 }
 
