@@ -33,18 +33,17 @@ namespace CVMFS_NAMESPACE_GUARD {
 
 static string EscapeShell(const std::string &raw) {
   for (unsigned i = 0, l = raw.length(); i < l; ++i) {
-    if (!(((raw[i] >= '0') && (raw[i] <= '9')) ||
-          ((raw[i] >= 'A') && (raw[i] <= 'Z')) ||
-          ((raw[i] >= 'a') && (raw[i] <= 'z')) ||
-          (raw[i] == '/') || (raw[i] == ':') || (raw[i] == '.') ||
-          (raw[i] == '_') || (raw[i] == '-') || (raw[i] == ',')))
-          {
+    if (!(((raw[i] >= '0') && (raw[i] <= '9'))
+          || ((raw[i] >= 'A') && (raw[i] <= 'Z'))
+          || ((raw[i] >= 'a') && (raw[i] <= 'z')) || (raw[i] == '/')
+          || (raw[i] == ':') || (raw[i] == '.') || (raw[i] == '_')
+          || (raw[i] == '-') || (raw[i] == ','))) {
       goto escape_shell_quote;
     }
   }
   return raw;
 
- escape_shell_quote:
+escape_shell_quote:
   string result = "'";
   for (unsigned i = 0, l = raw.length(); i < l; ++i) {
     if (raw[i] == '\'')
@@ -73,34 +72,34 @@ string OptionsManager::TrimParameter(const string &parameter) {
 }
 
 string OptionsManager::SanitizeParameterAssignment(string *line,
-                                                   vector <string> *tokens) {
-    size_t comment_idx = line->find("#");
-    if (comment_idx != string::npos)
-      *line = line->substr(0, comment_idx);
-    *line = Trim(*line);
-    if (line->empty())
-      return "";
-    *tokens = SplitString(*line, '=');
-    if (tokens->size() < 2)
-      return "";
-    string parameter = TrimParameter((*tokens)[0]);
-    if (parameter.find(" ") != string::npos)
-      return "";
-    return parameter;
+                                                   vector<string> *tokens) {
+  const size_t comment_idx = line->find("#");
+  if (comment_idx != string::npos)
+    *line = line->substr(0, comment_idx);
+  *line = Trim(*line);
+  if (line->empty())
+    return "";
+  *tokens = SplitString(*line, '=');
+  if (tokens->size() < 2)
+    return "";
+  string parameter = TrimParameter((*tokens)[0]);
+  if (parameter.find(" ") != string::npos)
+    return "";
+  return parameter;
 }
 
 void OptionsManager::SwitchTemplateManager(
-  OptionsTemplateManager *opt_templ_mgr_param) {
+    OptionsTemplateManager *opt_templ_mgr_param) {
   delete opt_templ_mgr_;
   if (opt_templ_mgr_param != NULL) {
     opt_templ_mgr_ = opt_templ_mgr_param;
   } else {
     opt_templ_mgr_ = new OptionsTemplateManager();
   }
-  for (std::map<std::string, std::string>::iterator it
-    = templatable_values_.begin();
-    it != templatable_values_.end();
-    it++) {
+  for (std::map<std::string, std::string>::iterator it =
+           templatable_values_.begin();
+       it != templatable_values_.end();
+       it++) {
     config_[it->first].value = it->second;
     opt_templ_mgr_->ParseString(&(config_[it->first].value));
     UpdateEnvironment(it->first, config_[it->first]);
@@ -109,7 +108,7 @@ void OptionsManager::SwitchTemplateManager(
 
 bool SimpleOptionsParser::TryParsePath(const string &config_file) {
   LogCvmfs(kLogCvmfs, kLogDebug, "Fast-parsing config file %s",
-      config_file.c_str());
+           config_file.c_str());
   string line;
   FILE *fconfig = fopen(config_file.c_str(), "r");
   if (fconfig == NULL)
@@ -117,19 +116,18 @@ bool SimpleOptionsParser::TryParsePath(const string &config_file) {
 
   // Read line by line and extract parameters
   while (GetLineFile(fconfig, &line)) {
-    vector <string> tokens;
-    string parameter = SanitizeParameterAssignment(&line, &tokens);
+    vector<string> tokens;
+    const string parameter = SanitizeParameterAssignment(&line, &tokens);
     if (parameter.empty())
       continue;
 
     // Strip quotes from value
     tokens.erase(tokens.begin());
     string value = Trim(JoinStrings(tokens, "="));
-    unsigned value_length = value.length();
+    const unsigned value_length = value.length();
     if (value_length > 2) {
-      if ( ((value[0] == '"') && ((value[value_length - 1] == '"'))) ||
-           ((value[0] == '\'') && ((value[value_length - 1] == '\''))) )
-      {
+      if (((value[0] == '"') && ((value[value_length - 1] == '"')))
+          || ((value[0] == '\'') && ((value[value_length - 1] == '\'')))) {
         value = value.substr(1, value_length - 2);
       }
     }
@@ -166,7 +164,7 @@ void BashOptionsManager::ParsePath(const string &config_file,
         close(pipe_quit[1]);
         // If this is not a process group leader, create a new session
         if (getpgrp() != getpid()) {
-          pid_t new_session = setsid();
+          const pid_t new_session = setsid();
           assert(new_session != (pid_t)-1);
         }
         (void)open(config_file.c_str(), O_RDONLY);
@@ -196,14 +194,15 @@ void BashOptionsManager::ParsePath(const string &config_file,
   if (!fconfig) {
     if (external && !DirectoryExists(config_path)) {
       string repo_required;
-      if (GetValue("CVMFS_CONFIG_REPO_REQUIRED", &repo_required) &&
-        IsOn(repo_required)) {
-          LogCvmfs(kLogCvmfs, kLogStderr | kLogSyslogErr,
-               "required configuration repository directory does not exist: %s",
-               config_path.c_str());
-          // Do not crash as in abort(), which can trigger core file creation
-          // from the mount helper
-          exit(1);
+      if (GetValue("CVMFS_CONFIG_REPO_REQUIRED", &repo_required)
+          && IsOn(repo_required)) {
+        LogCvmfs(
+            kLogCvmfs, kLogStderr | kLogSyslogErr,
+            "required configuration repository directory does not exist: %s",
+            config_path.c_str());
+        // Do not crash as in abort(), which can trigger core file creation
+        // from the mount helper
+        exit(1);
       }
 
       LogCvmfs(kLogCvmfs, kLogDebug | kLogSyslogWarn,
@@ -222,8 +221,8 @@ void BashOptionsManager::ParsePath(const string &config_file,
   // Let the shell read the file
   string line;
   const string newline = "\n";
-  const string cd = "cd \"" + ((config_path == "") ? "/" : config_path) + "\"" +
-                    newline;
+  const string cd = "cd \"" + ((config_path == "") ? "/" : config_path) + "\""
+                    + newline;
   WritePipe(fd_stdin, cd.data(), cd.length());
   while (GetLineFile(fconfig, &line)) {
     WritePipe(fd_stdin, line.data(), line.length());
@@ -233,8 +232,8 @@ void BashOptionsManager::ParsePath(const string &config_file,
 
   // Read line by line and extract parameters
   while (GetLineFile(fconfig, &line)) {
-    vector <string> tokens;
-    string parameter = SanitizeParameterAssignment(&line, &tokens);
+    vector<string> tokens;
+    const string parameter = SanitizeParameterAssignment(&line, &tokens);
     if (parameter.empty())
       continue;
 
@@ -265,7 +264,7 @@ bool OptionsManager::HasConfigRepository(const string &fqrn,
   if (GetValue("CVMFS_CONFIG_REPOSITORY", &config_repository)) {
     if (config_repository.empty() || (config_repository == fqrn))
       return false;
-    sanitizer::RepositorySanitizer repository_sanitizer;
+    const sanitizer::RepositorySanitizer repository_sanitizer;
     if (!repository_sanitizer.IsValid(config_repository)) {
       LogCvmfs(kLogCvmfs, kLogDebug | kLogSyslogErr,
                "invalid CVMFS_CONFIG_REPOSITORY: %s",
@@ -278,17 +277,34 @@ bool OptionsManager::HasConfigRepository(const string &fqrn,
   return false;
 }
 
+void OptionsManager::SetupGlobalEnvironmentParams() {
+  SetValue("CVMFS_ARCH", GetArch());
+
+  // Set CVMFS_VERSION environment variable
+  SetValue("CVMFS_VERSION", CVMFS_VERSION);
+
+  // Calculate and set CVMFS_VERSION_NUMERIC
+  // Format: major * 10000 + minor * 100 + patch
+  // Example: 2.13.2 becomes 21302
+  const int version_numeric = CVMFS_VERSION_MAJOR * 10000
+                              + CVMFS_VERSION_MINOR * 100 + CVMFS_VERSION_PATCH;
+  char version_numeric_str[16];
+  snprintf(version_numeric_str, sizeof(version_numeric_str), "%d",
+           version_numeric);
+  SetValue("CVMFS_VERSION_NUMERIC", version_numeric_str);
+}
 
 void OptionsManager::ParseDefault(const string &fqrn) {
   if (taint_environment_) {
-    int retval = setenv("CVMFS_FQRN", fqrn.c_str(), 1);
+    const int retval = setenv("CVMFS_FQRN", fqrn.c_str(), 1);
     assert(retval == 0);
   }
 
+  SetupGlobalEnvironmentParams();
   protected_parameters_.clear();
   ParsePath("/etc/cvmfs/default.conf", false);
-  vector<string> dist_defaults =
-    FindFilesBySuffix("/etc/cvmfs/default.d", ".conf");
+  vector<string> dist_defaults = FindFilesBySuffix("/etc/cvmfs/default.d",
+                                                   ".conf");
   for (unsigned i = 0; i < dist_defaults.size(); ++i) {
     ParsePath(dist_defaults[i], false);
   }
@@ -306,8 +322,7 @@ void OptionsManager::ParseDefault(const string &fqrn) {
     domain = JoinStrings(tokens, ".");
 
     if (HasConfigRepository(fqrn, &external_config_path))
-      ParsePath(external_config_path+ "domain.d/" + domain + ".conf",
-        true);
+      ParsePath(external_config_path + "domain.d/" + domain + ".conf", true);
     ParsePath("/etc/cvmfs/domain.d/" + domain + ".conf", false);
     ParsePath("/etc/cvmfs/domain.d/" + domain + ".local", false);
 
@@ -319,10 +334,9 @@ void OptionsManager::ParseDefault(const string &fqrn) {
 }
 
 
-void OptionsManager::PopulateParameter(
-  const string &param,
-  ConfigValue val) {
-  map<string, string>::const_iterator iter = protected_parameters_.find(param);
+void OptionsManager::PopulateParameter(const string &param, ConfigValue val) {
+  const map<string, string>::const_iterator iter = protected_parameters_.find(
+      param);
   if ((iter != protected_parameters_.end()) && (iter->second != val.value)) {
     LogCvmfs(kLogCvmfs, kLogDebug | kLogSyslogErr,
              "error in cvmfs configuration: attempt to change protected %s "
@@ -335,18 +349,16 @@ void OptionsManager::PopulateParameter(
   UpdateEnvironment(param, val);
 }
 
-void OptionsManager::UpdateEnvironment(
-  const string &param,
-  ConfigValue val) {
+void OptionsManager::UpdateEnvironment(const string &param, ConfigValue val) {
   if (taint_environment_) {
-    int retval = setenv(param.c_str(), val.value.c_str(), 1);
+    const int retval = setenv(param.c_str(), val.value.c_str(), 1);
     assert(retval == 0);
   }
 }
 
 void OptionsManager::ParseValue(std::string param, ConfigValue *val) {
-  string orig = val->value;
-  bool has_templ = opt_templ_mgr_->ParseString(&(val->value));
+  const string orig = val->value;
+  const bool has_templ = opt_templ_mgr_->ParseString(&(val->value));
   if (has_templ) {
     templatable_values_[param] = orig;
   }
@@ -357,24 +369,22 @@ void OptionsManager::ProtectParameter(const string &param) {
   string value;
   // We don't care about the result.  If param does not yet exists, we lock it
   // to the empty string.
-  (void) GetValue(param, &value);
+  (void)GetValue(param, &value);
   protected_parameters_[param] = value;
 }
 
 
-void OptionsManager::ClearConfig() {
-  config_.clear();
-}
+void OptionsManager::ClearConfig() { config_.clear(); }
 
 
 bool OptionsManager::IsDefined(const std::string &key) {
-  map<string, ConfigValue>::const_iterator iter = config_.find(key);
+  const map<string, ConfigValue>::const_iterator iter = config_.find(key);
   return iter != config_.end();
 }
 
 
 bool OptionsManager::GetValue(const string &key, string *value) const {
-  map<string, ConfigValue>::const_iterator iter = config_.find(key);
+  const map<string, ConfigValue>::const_iterator iter = config_.find(key);
   if (iter != config_.end()) {
     *value = iter->second.value;
     return true;
@@ -386,17 +396,17 @@ bool OptionsManager::GetValue(const string &key, string *value) const {
 
 std::string OptionsManager::GetValueOrDie(const string &key) {
   std::string value;
-  bool retval = GetValue(key, &value);
+  const bool retval = GetValue(key, &value);
   if (!retval) {
-    PANIC(kLogStderr | kLogDebug,
-          "%s configuration parameter missing", key.c_str());
+    PANIC(kLogStderr | kLogDebug, "%s configuration parameter missing",
+          key.c_str());
   }
   return value;
 }
 
 
 bool OptionsManager::GetSource(const string &key, string *value) {
-  map<string, ConfigValue>::const_iterator iter = config_.find(key);
+  const map<string, ConfigValue>::const_iterator iter = config_.find(key);
   if (iter != config_.end()) {
     *value = iter->second.source;
     return true;
@@ -408,42 +418,42 @@ bool OptionsManager::GetSource(const string &key, string *value) {
 
 bool OptionsManager::IsOn(const std::string &param_value) const {
   const string uppercase = ToUpper(param_value);
-  return ((uppercase == "YES") || (uppercase == "ON") || (uppercase == "1") ||
-          (uppercase == "TRUE"));
+  return ((uppercase == "YES") || (uppercase == "ON") || (uppercase == "1")
+          || (uppercase == "TRUE"));
 }
 
 
 bool OptionsManager::IsOff(const std::string &param_value) const {
   const string uppercase = ToUpper(param_value);
-  return ((uppercase == "NO") || (uppercase == "OFF") || (uppercase == "0") ||
-          (uppercase == "FALSE"));
+  return ((uppercase == "NO") || (uppercase == "OFF") || (uppercase == "0")
+          || (uppercase == "FALSE"));
 }
 
 
 vector<string> OptionsManager::GetAllKeys() {
   vector<string> result;
   for (map<string, ConfigValue>::const_iterator i = config_.begin(),
-       iEnd = config_.end(); i != iEnd; ++i)
-  {
+                                                iEnd = config_.end();
+       i != iEnd;
+       ++i) {
     result.push_back(i->first);
   }
   return result;
 }
 
 
-vector<string> OptionsManager::GetEnvironmentSubset(
-  const string &key_prefix,
-  bool strip_prefix)
-{
+vector<string> OptionsManager::GetEnvironmentSubset(const string &key_prefix,
+                                                    bool strip_prefix) {
   vector<string> result;
   for (map<string, ConfigValue>::const_iterator i = config_.begin(),
-       iEnd = config_.end(); i != iEnd; ++i)
-  {
+                                                iEnd = config_.end();
+       i != iEnd;
+       ++i) {
     const bool ignore_prefix = false;
     if (HasPrefix(i->first, key_prefix, ignore_prefix)) {
       const string output_key = strip_prefix
-        ? i->first.substr(key_prefix.length())
-        : i->first;
+                                    ? i->first.substr(key_prefix.length())
+                                    : i->first;
       result.push_back(output_key + "=" + i->second.value);
     }
   }
@@ -463,8 +473,8 @@ string OptionsManager::Dump() {
     assert(retval);
     retval = GetSource(keys[i], &source);
     assert(retval);
-    result += keys[i] + "=" + EscapeShell(value) +
-              "    # from " + source + "\n";
+    result += keys[i] + "=" + EscapeShell(value) + "    # from " + source
+              + "\n";
   }
   return result;
 }
@@ -491,14 +501,11 @@ void OptionsManager::UnsetValue(const string &key) {
     unsetenv(key.c_str());
 }
 
-const char *DefaultOptionsTemplateManager
-  ::kTemplateIdentFqrn = "fqrn";
+const char *DefaultOptionsTemplateManager ::kTemplateIdentFqrn = "fqrn";
 
-const char *DefaultOptionsTemplateManager
-  ::kTemplateIdentOrg = "org";
+const char *DefaultOptionsTemplateManager ::kTemplateIdentOrg = "org";
 
-DefaultOptionsTemplateManager::DefaultOptionsTemplateManager(
-  std::string fqrn) {
+DefaultOptionsTemplateManager::DefaultOptionsTemplateManager(std::string fqrn) {
   SetTemplate(kTemplateIdentFqrn, fqrn);
   vector<string> fqrn_parts = SplitString(fqrn, '.');
   SetTemplate(kTemplateIdentOrg, fqrn_parts[0]);
@@ -513,8 +520,7 @@ std::string OptionsTemplateManager::GetTemplate(std::string name) {
     return templates_[name];
   } else {
     std::string var_name = "@" + name + "@";
-    LogCvmfs(kLogCvmfs, kLogDebug, "Undeclared variable: %s",
-      var_name.c_str());
+    LogCvmfs(kLogCvmfs, kLogDebug, "Undeclared variable: %s", var_name.c_str());
     return var_name;
   }
 }
@@ -533,7 +539,7 @@ bool OptionsTemplateManager::ParseString(std::string *input) {
         } else {
           result += in[i];
         }
-      break;
+        break;
       case 1:
         if (in[i] == '@') {
           mode = 0;
@@ -543,7 +549,7 @@ bool OptionsTemplateManager::ParseString(std::string *input) {
         } else {
           stock += in[i];
         }
-      break;
+        break;
     }
   }
   if (mode == 1) {
