@@ -20,22 +20,19 @@ class CmdAbort : public Command {
   }
   virtual std::string GetDescription() const {
     return "Returns to the state before the current transaction was opened. "
-      "All changes staged in the current transaction are discarded. "
-      "Repositories attached to a gateway return their lease.";
-  }
-  virtual std::string GetUsage() const {
-    return "[options] <repository name>";
+           "All changes staged in the current transaction are discarded. "
+           "Repositories attached to a gateway return their lease.";
   }
+  virtual std::string GetUsage() const { return "[options] <repository name>"; }
   virtual std::vector<std::string> DoGetExamples() const {
     std::vector<std::string> e;
     e.push_back("-f myrepo.cvmfs.io  "
-      "# abort without asking for confirmation");
+                "# abort without asking for confirmation");
     return e;
   }
   virtual ParameterList GetParams() const {
     ParameterList p;
-    p.push_back(Parameter::Switch("force", 'f',
-      "Do not ask for confirmation"));
+    p.push_back(Parameter::Switch("force", 'f', "Do not ask for confirmation"));
     return p;
   }
 
