@@ -14,23 +14,22 @@ namespace publish {
 class CmdHash : public Command {
  public:
   virtual std::string GetName() const { return "hash"; }
-  virtual std::string GetBrief() const {
-    return "CernVM-FS hash functions";
-  }
+  virtual std::string GetBrief() const { return "CernVM-FS hash functions"; }
   virtual std::string GetDescription() const {
     return "Hash over a string or STDIN with one of the hash functions in "
            "CernVM-FS";
   }
   virtual ParameterList GetParams() const {
     ParameterList p;
-    p.push_back(Parameter::Mandatory("algorithm", 'a', "algorithm name",
-      "hash algorithm to use (e.g. shake128, sha1)"));
+    p.push_back(
+        Parameter::Mandatory("algorithm", 'a', "algorithm name",
+                             "hash algorithm to use (e.g. shake128, sha1)"));
     p.push_back(Parameter::Optional("input", 'i', "string",
-      "data to hash over (instead of STDIN)"));
+                                    "data to hash over (instead of STDIN)"));
     p.push_back(Parameter::Switch("fingerprint", 'f',
-      "print in fingerprint representation"));
-    p.push_back(Parameter::Switch("split", 's',
-      "additionally print the hash as 64bit integer tuples"));
+                                  "print in fingerprint representation"));
+    p.push_back(Parameter::Switch(
+        "split", 's', "additionally print the hash as 64bit integer tuples"));
     return p;
   }
   virtual bool IsHidden() const { return true; }
