@@ -17,8 +17,7 @@
 
 int publish::CallServerHook(const std::string &func,
                             const std::string &fqrn,
-                            const std::string &path_hooks)
-{
+                            const std::string &path_hooks) {
   if (!FileExists(path_hooks))
     return 0;
 
@@ -33,23 +32,17 @@ int publish::CallServerHook(const std::string &func,
   std::vector<std::string> cmd_line;
   cmd_line.push_back("/bin/sh");
   pid_t child_pid;
-  bool rvb = ManagedExec(cmd_line,
-                         preserve_fildes,
-                         map_fildes,
-                         false /* drop_credentials */,
-                         false /* clear_env */,
-                         false /* double_fork */,
-                         &child_pid);
+  const bool rvb = ManagedExec(
+      cmd_line, preserve_fildes, map_fildes, false /* drop_credentials */,
+      false /* clear_env */, false /* double_fork */, &child_pid);
   if (!rvb) {
     ClosePipe(pipe_stdin);
     return -127;
   }
   close(pipe_stdin[0]);
 
-  const std::string callout =
-    func + "() { :; }\n" +
-    ". " + path_hooks + "\n" +
-    func + " " + fqrn + "\n";
+  const std::string callout = func + "() { :; }\n" + ". " + path_hooks + "\n"
+                              + func + " " + fqrn + "\n";
   WritePipe(pipe_stdin[1], callout.data(), callout.length());
   close(pipe_stdin[1]);
 
