@@ -42,27 +42,26 @@ class CommandTag {
 };
 const std::string CommandTag::kHeadTag = "trunk";
 const std::string CommandTag::kPreviousHeadTag = "trunk-previous";
-}
+}  // namespace swissknife
 
 namespace publish {
 
 Repository::Repository(const SettingsRepository &settings, const bool exists)
-  : settings_(settings)
-  , statistics_(new perf::Statistics())
-  , signature_mgr_(new signature::SignatureManager())
-  , download_mgr_(NULL)
-  , simple_catalog_mgr_(NULL)
-  , whitelist_(NULL)
-  , reflog_(NULL)
-  , manifest_(NULL)
-  , history_(NULL)
-{
+    : settings_(settings)
+    , statistics_(new perf::Statistics())
+    , signature_mgr_(new signature::SignatureManager())
+    , download_mgr_(NULL)
+    , simple_catalog_mgr_(NULL)
+    , whitelist_(NULL)
+    , reflog_(NULL)
+    , manifest_(NULL)
+    , history_(NULL) {
   signature_mgr_->Init();
 
   if (exists) {
     int rvb;
-    std::string keys = JoinStrings(FindFilesBySuffix(
-      settings.keychain().keychain_dir(), ".pub"), ":");
+    const std::string keys = JoinStrings(
+        FindFilesBySuffix(settings.keychain().keychain_dir(), ".pub"), ":");
     rvb = signature_mgr_->LoadPublicRsaKeys(keys);
     if (!rvb) {
       signature_mgr_->Fini();
@@ -73,13 +72,13 @@ Repository::Repository(const SettingsRepository &settings, const bool exists)
   }
 
   if (!settings.cert_bundle().empty()) {
-    int rvi = setenv("X509_CERT_BUNDLE", settings.cert_bundle().c_str(),
-                     1 /* overwrite */);
+    const int rvi = setenv("X509_CERT_BUNDLE", settings.cert_bundle().c_str(),
+                           1 /* overwrite */);
     if (rvi != 0)
       throw EPublish("cannot set X509_CERT_BUNDLE environment variable");
   }
-  download_mgr_ = new download::DownloadManager(16,
-                             perf::StatisticsTemplate("download", statistics_));
+  download_mgr_ = new download::DownloadManager(
+      16, perf::StatisticsTemplate("download", statistics_));
   download_mgr_->UseSystemCertificatePath();
 
   if (settings.proxy() != "") {
@@ -90,7 +89,7 @@ Repository::Repository(const SettingsRepository &settings, const bool exists)
   if (exists) {
     try {
       DownloadRootObjects(settings.url(), settings.fqrn(), settings.tmp_dir());
-    } catch (const EPublish& e) {
+    } catch (const EPublish &e) {
       signature_mgr_->Fini();
       delete signature_mgr_;
       delete download_mgr_;
@@ -101,7 +100,8 @@ Repository::Repository(const SettingsRepository &settings, const bool exists)
 }
 
 Repository::~Repository() {
-  if (signature_mgr_ != NULL) signature_mgr_->Fini();
+  if (signature_mgr_ != NULL)
+    signature_mgr_->Fini();
 
   delete history_;
   delete manifest_;
@@ -116,45 +116,47 @@ Repository::~Repository() {
 const history::History *Repository::history() const { return history_; }
 
 catalog::SimpleCatalogManager *Repository::GetSimpleCatalogManager() {
-  if (simple_catalog_mgr_ != NULL) return simple_catalog_mgr_;
+  if (simple_catalog_mgr_ != NULL)
+    return simple_catalog_mgr_;
 
   simple_catalog_mgr_ = new catalog::SimpleCatalogManager(
-    manifest_->catalog_hash(),
-    settings_.url(),
-    settings_.tmp_dir(),
-    download_mgr_,
-    statistics_,
-    true /* manage_catalog_files */);
+      manifest_->catalog_hash(),
+      settings_.url(),
+      settings_.tmp_dir(),
+      download_mgr_,
+      statistics_,
+      true /* manage_catalog_files */);
   simple_catalog_mgr_->Init();
   return simple_catalog_mgr_;
 }
 
 
-void Repository::DownloadRootObjects(
-  const std::string &url, const std::string &fqrn, const std::string &tmp_dir)
-{
+void Repository::DownloadRootObjects(const std::string &url,
+                                     const std::string &fqrn,
+                                     const std::string &tmp_dir) {
   delete whitelist_;
   whitelist_ = new whitelist::Whitelist(fqrn, download_mgr_, signature_mgr_);
-  whitelist::Failures rv_whitelist = whitelist_->LoadUrl(url);
+  const whitelist::Failures rv_whitelist = whitelist_->LoadUrl(url);
   if (whitelist_->status() != whitelist::Whitelist::kStAvailable) {
-    throw EPublish(std::string("cannot load whitelist [") +
-                   whitelist::Code2Ascii(rv_whitelist) + "]");
+    throw EPublish(std::string("cannot load whitelist [")
+                   + whitelist::Code2Ascii(rv_whitelist) + "]");
   }
 
   manifest::ManifestEnsemble ensemble;
   const uint64_t minimum_timestamp = 0;
   const shash::Any *base_catalog = NULL;
-  manifest::Failures rv_manifest = manifest::Fetch(
-    url, fqrn, minimum_timestamp, base_catalog, signature_mgr_, download_mgr_,
-    &ensemble);
-  if (rv_manifest != manifest::kFailOk) throw EPublish("cannot load manifest");
+  const manifest::Failures rv_manifest = manifest::Fetch(
+      url, fqrn, minimum_timestamp, base_catalog, signature_mgr_, download_mgr_,
+      &ensemble);
+  if (rv_manifest != manifest::kFailOk)
+    throw EPublish("cannot load manifest");
   delete manifest_;
   manifest_ = new manifest::Manifest(*ensemble.manifest);
 
   std::string reflog_path;
-  FILE *reflog_fd =
-    CreateTempFile(tmp_dir + "/reflog", kPrivateFileMode, "w", &reflog_path);
-  std::string reflog_url = url + "/.cvmfsreflog";
+  FILE *reflog_fd = CreateTempFile(tmp_dir + "/reflog", kPrivateFileMode, "w",
+                                   &reflog_path);
+  const std::string reflog_url = url + "/.cvmfsreflog";
   // TODO(jblomer): verify reflog hash
   // shash::Any reflog_hash(manifest_->GetHashAlgorithm());
   cvmfs::FileSink filesink(reflog_fd);
@@ -165,53 +167,58 @@ void Repository::DownloadRootObjects(
   if (rv_dl == download::kFailOk) {
     delete reflog_;
     reflog_ = manifest::Reflog::Open(reflog_path);
-    if (reflog_ == NULL) throw EPublish("cannot open reflog");
+    if (reflog_ == NULL)
+      throw EPublish("cannot open reflog");
     reflog_->TakeDatabaseFileOwnership();
   } else {
     if (!download_reflog.IsFileNotFound()) {
-      throw EPublish(std::string("cannot load reflog [") +
-                     download::Code2Ascii(rv_dl) + "]");
+      throw EPublish(std::string("cannot load reflog [")
+                     + download::Code2Ascii(rv_dl) + "]");
     }
     assert(reflog_ == NULL);
   }
 
   std::string tags_path;
-  FILE *tags_fd =
-    CreateTempFile(tmp_dir + "/tags", kPrivateFileMode, "w", &tags_path);
+  FILE *tags_fd = CreateTempFile(tmp_dir + "/tags", kPrivateFileMode, "w",
+                                 &tags_path);
   if (!manifest_->history().IsNull()) {
-    std::string tags_url = url + "/data/" + manifest_->history().MakePath();
-    shash::Any tags_hash(manifest_->history());
+    const std::string tags_url = url + "/data/"
+                                 + manifest_->history().MakePath();
+    const shash::Any tags_hash(manifest_->history());
     cvmfs::FileSink filesink(tags_fd);
     download::JobInfo download_tags(&tags_url, true /* compressed */,
                                     true /* probe hosts */, &tags_hash,
                                     &filesink);
     rv_dl = download_mgr_->Fetch(&download_tags);
     fclose(tags_fd);
-    if (rv_dl != download::kFailOk) throw EPublish("cannot load tag database");
+    if (rv_dl != download::kFailOk)
+      throw EPublish("cannot load tag database");
     delete history_;
     history_ = history::SqliteHistory::OpenWritable(tags_path);
-    if (history_ == NULL) throw EPublish("cannot open tag database");
+    if (history_ == NULL)
+      throw EPublish("cannot open tag database");
   } else {
     fclose(tags_fd);
     delete history_;
     history_ = history::SqliteHistory::Create(tags_path, fqrn);
-    if (history_ == NULL) throw EPublish("cannot create tag database");
+    if (history_ == NULL)
+      throw EPublish("cannot create tag database");
   }
   history_->TakeDatabaseFileOwnership();
 
   if (!manifest_->meta_info().IsNull()) {
-    shash::Any info_hash(manifest_->meta_info());
-    std::string info_url = url + "/data/" + info_hash.MakePath();
+    const shash::Any info_hash(manifest_->meta_info());
+    const std::string info_url = url + "/data/" + info_hash.MakePath();
     cvmfs::MemSink metainfo_memsink;
     download::JobInfo download_info(&info_url, true /* compressed */,
                                     true /* probe_hosts */, &info_hash,
                                     &metainfo_memsink);
-    download::Failures rv_info = download_mgr_->Fetch(&download_info);
+    const download::Failures rv_info = download_mgr_->Fetch(&download_info);
     if (rv_info != download::kFailOk) {
-      throw EPublish(std::string("cannot load meta info [") +
-                     download::Code2Ascii(rv_info) + "]");
+      throw EPublish(std::string("cannot load meta info [")
+                     + download::Code2Ascii(rv_info) + "]");
     }
-    meta_info_ = std::string(reinterpret_cast<char*>(metainfo_memsink.data()),
+    meta_info_ = std::string(reinterpret_cast<char *>(metainfo_memsink.data()),
                              metainfo_memsink.pos());
   } else {
     meta_info_ = "n/a";
@@ -225,14 +232,18 @@ std::string Repository::GetFqrnFromUrl(const std::string &url) {
 
 
 bool Repository::IsMasterReplica() {
-  std::string url = settings_.url() + "/.cvmfs_master_replica";
+  const std::string url = settings_.url() + "/.cvmfs_master_replica";
   download::JobInfo head(&url, false /* probe_hosts */);
-  download::Failures retval = download_mgr_->Fetch(&head);
-  if (retval == download::kFailOk) { return true; }
-  if (head.IsFileNotFound()) { return false; }
+  const download::Failures retval = download_mgr_->Fetch(&head);
+  if (retval == download::kFailOk) {
+    return true;
+  }
+  if (head.IsFileNotFound()) {
+    return false;
+  }
 
-  throw EPublish(std::string("error looking for .cvmfs_master_replica [") +
-                 download::Code2Ascii(retval) + "]");
+  throw EPublish(std::string("error looking for .cvmfs_master_replica [")
+                 + download::Code2Ascii(retval) + "]");
 }
 
 
@@ -244,22 +255,22 @@ void Publisher::ConstructSpoolers() {
     return;
   assert((spooler_files_ == NULL) && (spooler_catalogs_ == NULL));
 
-  upload::SpoolerDefinition sd(
-    settings_.storage().GetLocator(),
-    settings_.transaction().hash_algorithm(),
-    settings_.transaction().compression_algorithm());
-  sd.session_token_file =
-    settings_.transaction().spool_area().gw_session_token();
+  upload::SpoolerDefinition sd(settings_.storage().GetLocator(),
+                               settings_.transaction().hash_algorithm(),
+                               settings_.transaction().compression_algorithm());
+  sd.session_token_file = settings_.transaction()
+                              .spool_area()
+                              .gw_session_token();
   sd.key_file = settings_.keychain().gw_key_path();
 
-  spooler_files_ =
-    upload::Spooler::Construct(sd, statistics_publish_.weak_ref());
+  spooler_files_ = upload::Spooler::Construct(sd,
+                                              statistics_publish_.weak_ref());
   if (spooler_files_ == NULL)
     throw EPublish("could not initialize file spooler");
 
-  upload::SpoolerDefinition sd_catalogs(sd.Dup2DefaultCompression());
-  spooler_catalogs_ =
-    upload::Spooler::Construct(sd_catalogs, statistics_publish_.weak_ref());
+  const upload::SpoolerDefinition sd_catalogs(sd.Dup2DefaultCompression());
+  spooler_catalogs_ = upload::Spooler::Construct(
+      sd_catalogs, statistics_publish_.weak_ref());
   if (spooler_catalogs_ == NULL) {
     delete spooler_files_;
     throw EPublish("could not initialize catalog spooler");
@@ -280,12 +291,10 @@ void Publisher::CreateKeychain() {
     signature_mgr_->GenerateCertificate(settings_.fqrn());
 
   whitelist_ = new whitelist::Whitelist(settings_.fqrn(), NULL, signature_mgr_);
-  std::string whitelist_str = whitelist::Whitelist::CreateString(
-    settings_.fqrn(),
-    settings_.whitelist_validity_days(),
-    settings_.transaction().hash_algorithm(),
-    signature_mgr_);
-  whitelist::Failures rv_wl = whitelist_->LoadMem(whitelist_str);
+  const std::string whitelist_str = whitelist::Whitelist::CreateString(
+      settings_.fqrn(), settings_.whitelist_validity_days(),
+      settings_.transaction().hash_algorithm(), signature_mgr_);
+  const whitelist::Failures rv_wl = whitelist_->LoadMem(whitelist_str);
   if (rv_wl != whitelist::kFailOk)
     throw EPublish("whitelist generation failed");
 }
@@ -294,17 +303,18 @@ void Publisher::CreateKeychain() {
 void Publisher::CreateRootObjects() {
   // Reflog
   const std::string reflog_path = CreateTempPath(
-    settings_.transaction().spool_area().tmp_dir() + "/cvmfs_reflog", 0600);
+      settings_.transaction().spool_area().tmp_dir() + "/cvmfs_reflog", 0600);
   reflog_ = manifest::Reflog::Create(reflog_path, settings_.fqrn());
-  if (reflog_ == NULL) throw EPublish("could not create reflog");
+  if (reflog_ == NULL)
+    throw EPublish("could not create reflog");
   reflog_->TakeDatabaseFileOwnership();
 
   // Root file catalog and initial manifest
   manifest_ = catalog::WritableCatalogManager::CreateRepository(
-    settings_.transaction().spool_area().tmp_dir(),
-    settings_.transaction().is_volatile(),
-    settings_.transaction().voms_authz(),
-    spooler_catalogs_);
+      settings_.transaction().spool_area().tmp_dir(),
+      settings_.transaction().is_volatile(),
+      settings_.transaction().voms_authz(),
+      spooler_catalogs_);
   spooler_catalogs_->WaitForUpload();
   if (manifest_ == NULL)
     throw EPublish("could not create initial file catalog");
@@ -312,22 +322,23 @@ void Publisher::CreateRootObjects() {
 
   manifest_->set_repository_name(settings_.fqrn());
   manifest_->set_ttl(settings_.transaction().ttl_second());
-  const bool needs_bootstrap_shortcuts =
-    !settings_.transaction().voms_authz().empty();
+  const bool
+      needs_bootstrap_shortcuts = !settings_.transaction().voms_authz().empty();
   manifest_->set_has_alt_catalog_path(needs_bootstrap_shortcuts);
   manifest_->set_garbage_collectability(
-    settings_.transaction().is_garbage_collectable());
+      settings_.transaction().is_garbage_collectable());
 
   // Tag database
   const std::string tags_path = CreateTempPath(
-    settings_.transaction().spool_area().tmp_dir() + "/cvmfs_tags", 0600);
+      settings_.transaction().spool_area().tmp_dir() + "/cvmfs_tags", 0600);
   history_ = history::SqliteHistory::Create(tags_path, settings_.fqrn());
-  if (history_ == NULL) throw EPublish("could not create tag database");
+  if (history_ == NULL)
+    throw EPublish("could not create tag database");
   history_->TakeDatabaseFileOwnership();
-  history::History::Tag tag_trunk(
-    "trunk",
-    manifest_->catalog_hash(), manifest_->catalog_size(), manifest_->revision(),
-    manifest_->publish_timestamp(), "empty repository", "" /* branch */);
+  const history::History::Tag tag_trunk(
+      "trunk", manifest_->catalog_hash(), manifest_->catalog_size(),
+      manifest_->revision(), manifest_->publish_timestamp(), "empty repository",
+      "" /* branch */);
   history_->Insert(tag_trunk);
 
   // Meta information, TODO(jblomer)
@@ -343,10 +354,10 @@ void Publisher::CreateStorage() {
 
 
 void Publisher::PushCertificate() {
-  upload::Spooler::CallbackPtr callback =
-    spooler_files_->RegisterListener(&Publisher::OnProcessCertificate, this);
+  upload::Spooler::CallbackPtr callback = spooler_files_->RegisterListener(
+      &Publisher::OnProcessCertificate, this);
   spooler_files_->ProcessCertificate(
-    new StringIngestionSource(signature_mgr_->GetCertificate()));
+      new StringIngestionSource(signature_mgr_->GetCertificate()));
   spooler_files_->WaitForUpload();
   spooler_files_->UnregisterListener(callback);
 }
@@ -359,8 +370,8 @@ void Publisher::PushHistory() {
   history_->DropDatabaseFileOwnership();
   delete history_;
 
-  upload::Spooler::CallbackPtr callback =
-    spooler_files_->RegisterListener(&Publisher::OnProcessHistory, this);
+  upload::Spooler::CallbackPtr callback = spooler_files_->RegisterListener(
+      &Publisher::OnProcessHistory, this);
   spooler_files_->ProcessHistory(history_path);
   spooler_files_->WaitForUpload();
   spooler_files_->UnregisterListener(callback);
@@ -372,8 +383,8 @@ void Publisher::PushHistory() {
 
 
 void Publisher::PushMetainfo() {
-  upload::Spooler::CallbackPtr callback =
-    spooler_files_->RegisterListener(&Publisher::OnProcessMetainfo, this);
+  upload::Spooler::CallbackPtr callback = spooler_files_->RegisterListener(
+      &Publisher::OnProcessMetainfo, this);
   spooler_files_->ProcessMetainfo(new StringIngestionSource(meta_info_));
   spooler_files_->WaitForUpload();
   spooler_files_->UnregisterListener(callback);
@@ -390,28 +401,32 @@ void Publisher::PushManifest() {
   unsigned char *signature;
   unsigned sig_size;
   bool rvb = signature_mgr_->Sign(
-    reinterpret_cast<const unsigned char *>(manifest_hash.ToString().data()),
-    manifest_hash.GetHexSize(), &signature, &sig_size);
-  if (!rvb) throw EPublish("cannot sign manifest");
+      reinterpret_cast<const unsigned char *>(manifest_hash.ToString().data()),
+      manifest_hash.GetHexSize(), &signature, &sig_size);
+  if (!rvb)
+    throw EPublish("cannot sign manifest");
   signed_manifest += std::string(reinterpret_cast<char *>(signature), sig_size);
   free(signature);
 
   // Create alternative bootstrapping symlinks for VOMS secured repos
   if (manifest_->has_alt_catalog_path()) {
-    rvb =
-      spooler_files_->PlaceBootstrappingShortcut(manifest_->certificate()) &&
-      spooler_files_->PlaceBootstrappingShortcut(manifest_->catalog_hash()) &&
-      (manifest_->history().IsNull() ||
-        spooler_files_->PlaceBootstrappingShortcut(manifest_->history())) &&
-      (manifest_->meta_info().IsNull() ||
-        spooler_files_->PlaceBootstrappingShortcut(manifest_->meta_info()));
-    if (!rvb) EPublish("cannot place VOMS bootstrapping symlinks");
+    rvb = spooler_files_->PlaceBootstrappingShortcut(manifest_->certificate())
+          && spooler_files_->PlaceBootstrappingShortcut(
+              manifest_->catalog_hash())
+          && (manifest_->history().IsNull()
+              || spooler_files_->PlaceBootstrappingShortcut(
+                  manifest_->history()))
+          && (manifest_->meta_info().IsNull()
+              || spooler_files_->PlaceBootstrappingShortcut(
+                  manifest_->meta_info()));
+    if (!rvb)
+      EPublish("cannot place VOMS bootstrapping symlinks");
   }
 
-  upload::Spooler::CallbackPtr callback =
-    spooler_files_->RegisterListener(&Publisher::OnUploadManifest, this);
+  upload::Spooler::CallbackPtr callback = spooler_files_->RegisterListener(
+      &Publisher::OnUploadManifest, this);
   spooler_files_->Upload(".cvmfspublished",
-                   new StringIngestionSource(signed_manifest));
+                         new StringIngestionSource(signed_manifest));
   spooler_files_->WaitForUpload();
   spooler_files_->UnregisterListener(callback);
 }
@@ -425,8 +440,8 @@ void Publisher::PushReflog() {
   shash::Any hash_reflog(settings_.transaction().hash_algorithm());
   manifest::Reflog::HashDatabase(reflog_path, &hash_reflog);
 
-  upload::Spooler::CallbackPtr callback =
-    spooler_files_->RegisterListener(&Publisher::OnUploadReflog, this);
+  upload::Spooler::CallbackPtr callback = spooler_files_->RegisterListener(
+      &Publisher::OnUploadReflog, this);
   spooler_files_->UploadReflog(reflog_path);
   spooler_files_->WaitForUpload();
   spooler_files_->UnregisterListener(callback);
@@ -441,8 +456,8 @@ void Publisher::PushReflog() {
 
 void Publisher::PushWhitelist() {
   // TODO(jblomer): PKCS7 handling
-  upload::Spooler::CallbackPtr callback =
-    spooler_files_->RegisterListener(&Publisher::OnUploadWhitelist, this);
+  upload::Spooler::CallbackPtr callback = spooler_files_->RegisterListener(
+      &Publisher::OnUploadWhitelist, this);
   spooler_files_->Upload(".cvmfswhitelist",
                          new StringIngestionSource(whitelist_->ExportString()));
   spooler_files_->WaitForUpload();
@@ -491,31 +506,39 @@ void Publisher::ExportKeychain() {
   bool rvb;
   rvb = SafeWriteToFile(signature_mgr_->GetActivePubkeys(),
                         settings_.keychain().master_public_key_path(), 0644);
-  if (!rvb) throw EPublish("cannot export public master key");
+  if (!rvb)
+    throw EPublish("cannot export public master key");
   rvb = SafeWriteToFile(signature_mgr_->GetCertificate(),
                         settings_.keychain().certificate_path(), 0644);
-  if (!rvb) throw EPublish("cannot export certificate");
+  if (!rvb)
+    throw EPublish("cannot export certificate");
 
   rvb = SafeWriteToFile(signature_mgr_->GetPrivateKey(),
                         settings_.keychain().private_key_path(), 0600);
-  if (!rvb) throw EPublish("cannot export private certificate key");
+  if (!rvb)
+    throw EPublish("cannot export private certificate key");
   rvb = SafeWriteToFile(signature_mgr_->GetPrivateMasterKey(),
                         settings_.keychain().master_private_key_path(), 0600);
-  if (!rvb) throw EPublish("cannot export private master key");
+  if (!rvb)
+    throw EPublish("cannot export private master key");
 
   int rvi;
   rvi = chown(settings_.keychain().master_public_key_path().c_str(),
               settings_.owner_uid(), settings_.owner_gid());
-  if (rvi != 0) throw EPublish("cannot set key file ownership");
+  if (rvi != 0)
+    throw EPublish("cannot set key file ownership");
   rvi = chown(settings_.keychain().certificate_path().c_str(),
               settings_.owner_uid(), settings_.owner_gid());
-  if (rvi != 0) throw EPublish("cannot set key file ownership");
+  if (rvi != 0)
+    throw EPublish("cannot set key file ownership");
   rvi = chown(settings_.keychain().private_key_path().c_str(),
               settings_.owner_uid(), settings_.owner_gid());
-  if (rvi != 0) throw EPublish("cannot set key file ownership");
+  if (rvi != 0)
+    throw EPublish("cannot set key file ownership");
   rvi = chown(settings_.keychain().master_private_key_path().c_str(),
               settings_.owner_uid(), settings_.owner_gid());
-  if (rvi != 0) throw EPublish("cannot set key file ownership");
+  if (rvi != 0)
+    throw EPublish("cannot set key file ownership");
 }
 
 void Publisher::OnProcessCertificate(const upload::SpoolerResult &result) {
@@ -560,12 +583,14 @@ void Publisher::OnUploadWhitelist(const upload::SpoolerResult &result) {
   }
 }
 
-void Publisher::CreateDirectoryAsOwner(const std::string &path, int mode)
-{
+void Publisher::CreateDirectoryAsOwner(const std::string &path, int mode) {
   const bool rvb = MkdirDeep(path, mode);
-  if (!rvb) throw EPublish("cannot create directory " + path);
-  int rvi = chown(path.c_str(), settings_.owner_uid(), settings_.owner_gid());
-  if (rvi != 0) throw EPublish("cannot set ownership on directory " + path);
+  if (!rvb)
+    throw EPublish("cannot create directory " + path);
+  const int rvi = chown(path.c_str(), settings_.owner_uid(),
+                        settings_.owner_gid());
+  if (rvi != 0)
+    throw EPublish("cannot set ownership on directory " + path);
 }
 
 void Publisher::InitSpoolArea() {
@@ -586,36 +611,39 @@ void Publisher::InitSpoolArea() {
                            kDefaultDirMode);
   }
   if (!DirectoryExists(settings_.transaction().spool_area().union_mnt())) {
-    CreateDirectoryAsOwner(
-      settings_.transaction().spool_area().union_mnt(), kDefaultDirMode);
+    CreateDirectoryAsOwner(settings_.transaction().spool_area().union_mnt(),
+                           kDefaultDirMode);
   }
 }
 
 Publisher::Publisher(const SettingsPublisher &settings, const bool exists)
-  : Repository(SettingsRepository(settings), exists)
-  , settings_(settings)
-  , statistics_publish_(new perf::StatisticsTemplate("publish", statistics_))
-  , llvl_(settings.is_silent() ? kLogNone : kLogNormal)
-  , in_transaction_(settings.transaction().spool_area().transaction_lock())
-  , is_publishing_(settings.transaction().spool_area().publishing_lock())
-  , spooler_files_(NULL)
-  , spooler_catalogs_(NULL)
-  , catalog_mgr_(NULL)
-  , sync_parameters_(NULL)
-  , sync_mediator_(NULL)
-  , sync_union_(NULL)
-{
+    : Repository(SettingsRepository(settings), exists)
+    , settings_(settings)
+    , statistics_publish_(new perf::StatisticsTemplate("publish", statistics_))
+    , llvl_(settings.is_silent() ? kLogNone : kLogNormal)
+    , in_transaction_(settings.transaction().spool_area().transaction_lock())
+    , is_publishing_(settings.transaction().spool_area().publishing_lock())
+    , spooler_files_(NULL)
+    , spooler_catalogs_(NULL)
+    , catalog_mgr_(NULL)
+    , sync_parameters_(NULL)
+    , sync_mediator_(NULL)
+    , sync_union_(NULL) {
   if (settings.transaction().layout_revision() != kRequiredLayoutRevision) {
-    unsigned layout_revision = settings.transaction().layout_revision();
-    throw EPublish(
-      "This repository uses layout revision " + StringifyInt(layout_revision)
-        + ".\n"
-      "This version of CernVM-FS requires layout revision " + StringifyInt(
-        kRequiredLayoutRevision) + ", which is\n"
-      "incompatible to " + StringifyInt(layout_revision) + ".\n\n"
-      "Please run `cvmfs_server migrate` to update your repository before "
-      "proceeding.",
-      EPublish::kFailLayoutRevision);
+    const unsigned layout_revision = settings.transaction().layout_revision();
+    throw EPublish("This repository uses layout revision "
+                       + StringifyInt(layout_revision)
+                       + ".\n"
+                         "This version of CernVM-FS requires layout revision "
+                       + StringifyInt(kRequiredLayoutRevision)
+                       + ", which is\n"
+                         "incompatible to "
+                       + StringifyInt(layout_revision)
+                       + ".\n\n"
+                         "Please run `cvmfs_server migrate` to update your "
+                         "repository before "
+                         "proceeding.",
+                   EPublish::kFailLayoutRevision);
   }
 
   if (!exists)
@@ -626,32 +654,32 @@ Publisher::Publisher(const SettingsPublisher &settings, const bool exists)
 
   if (settings.storage().type() == upload::SpoolerDefinition::Gateway) {
     if (!settings.keychain().HasGatewayKey()) {
-      throw EPublish("gateway key missing: " +
-                     settings.keychain().gw_key_path());
+      throw EPublish("gateway key missing: "
+                     + settings.keychain().gw_key_path());
     }
     gw_key_ = gateway::ReadGatewayKey(settings.keychain().gw_key_path());
     if (!gw_key_.IsValid()) {
-      throw EPublish("cannot read gateway key: " +
-                     settings.keychain().gw_key_path());
+      throw EPublish("cannot read gateway key: "
+                     + settings.keychain().gw_key_path());
     }
   }
 
-  if ((settings.storage().type() != upload::SpoolerDefinition::Gateway) &&
-      !settings.transaction().in_enter_session())
-  {
+  if ((settings.storage().type() != upload::SpoolerDefinition::Gateway)
+      && !settings.transaction().in_enter_session()) {
     int rvb = signature_mgr_->LoadCertificatePath(
-      settings.keychain().certificate_path());
+        settings.keychain().certificate_path());
     if (!rvb)
       throw EPublish("cannot load certificate, thus cannot commit changes");
     rvb = signature_mgr_->LoadPrivateKeyPath(
-      settings.keychain().private_key_path(), "");
+        settings.keychain().private_key_path(), "");
     if (!rvb)
       throw EPublish("cannot load private key, thus cannot commit changes");
     // The private master key might be on a key card instead
     if (FileExists(settings.keychain().master_private_key_path())) {
       rvb = signature_mgr_->LoadPrivateMasterKeyPath(
-        settings.keychain().master_private_key_path());
-      if (!rvb) throw EPublish("cannot load private master key");
+          settings.keychain().master_private_key_path());
+      if (!rvb)
+        throw EPublish("cannot load private master key");
     }
     if (!signature_mgr_->KeysMatch())
       throw EPublish("corrupted keychain");
@@ -679,20 +707,20 @@ void Publisher::ConstructSyncManagers() {
 
   if (catalog_mgr_ == NULL) {
     catalog_mgr_ = new catalog::WritableCatalogManager(
-      settings_.transaction().base_hash(),
-      settings_.url(),
-      settings_.transaction().spool_area().tmp_dir(),
-      spooler_catalogs_,
-      download_mgr_,
-      settings_.transaction().enforce_limits(),
-      settings_.transaction().limit_nested_catalog_kentries(),
-      settings_.transaction().limit_root_catalog_kentries(),
-      settings_.transaction().limit_file_size_mb(),
-      statistics_,
-      settings_.transaction().use_catalog_autobalance(),
-      settings_.transaction().autobalance_max_weight(),
-      settings_.transaction().autobalance_min_weight(),
-      "");
+        settings_.transaction().base_hash(),
+        settings_.url(),
+        settings_.transaction().spool_area().tmp_dir(),
+        spooler_catalogs_,
+        download_mgr_,
+        settings_.transaction().enforce_limits(),
+        settings_.transaction().limit_nested_catalog_kentries(),
+        settings_.transaction().limit_root_catalog_kentries(),
+        settings_.transaction().limit_file_size_mb(),
+        statistics_,
+        settings_.transaction().use_catalog_autobalance(),
+        settings_.transaction().autobalance_max_weight(),
+        settings_.transaction().autobalance_min_weight(),
+        "");
     catalog_mgr_->Init();
   }
 
@@ -715,42 +743,42 @@ void Publisher::ConstructSyncManagers() {
   }
 
   if (sync_mediator_ == NULL) {
-    sync_mediator_ =
-      new SyncMediator(catalog_mgr_, sync_parameters_, *statistics_publish_);
+    sync_mediator_ = new SyncMediator(catalog_mgr_, sync_parameters_,
+                                      *statistics_publish_);
   }
 
   if (sync_union_ == NULL) {
     switch (settings_.transaction().union_fs()) {
       case kUnionFsAufs:
         sync_union_ = new publish::SyncUnionAufs(
-          sync_mediator_,
-          settings_.transaction().spool_area().readonly_mnt(),
-          settings_.transaction().spool_area().union_mnt(),
-          settings_.transaction().spool_area().scratch_dir());
+            sync_mediator_,
+            settings_.transaction().spool_area().readonly_mnt(),
+            settings_.transaction().spool_area().union_mnt(),
+            settings_.transaction().spool_area().scratch_dir());
         break;
       case kUnionFsOverlay:
         sync_union_ = new publish::SyncUnionOverlayfs(
-          sync_mediator_,
-          settings_.transaction().spool_area().readonly_mnt(),
-          settings_.transaction().spool_area().union_mnt(),
-          settings_.transaction().spool_area().scratch_dir());
+            sync_mediator_,
+            settings_.transaction().spool_area().readonly_mnt(),
+            settings_.transaction().spool_area().union_mnt(),
+            settings_.transaction().spool_area().scratch_dir());
         break;
       case kUnionFsTarball:
         sync_union_ = new publish::SyncUnionTarball(
-          sync_mediator_,
-          settings_.transaction().spool_area().readonly_mnt(),
-          // TODO(jblomer): get from settings
-          "tar_file",
-          "base_directory",
-          -1u,
-          -1u,
-          "to_delete",
-          false /* create_catalog */);
+            sync_mediator_,
+            settings_.transaction().spool_area().readonly_mnt(),
+            // TODO(jblomer): get from settings
+            "tar_file",
+            "base_directory",
+            -1u,
+            -1u,
+            "to_delete",
+            false /* create_catalog */);
         break;
       default:
         throw EPublish("unknown union file system");
     }
-    bool rvb = sync_union_->Initialize();
+    const bool rvb = sync_union_->Initialize();
     if (!rvb) {
       delete sync_union_;
       sync_union_ = NULL;
@@ -760,38 +788,41 @@ void Publisher::ConstructSyncManagers() {
 }
 
 void Publisher::ExitShell() {
-  std::string session_dir = Env::GetEnterSessionDir();
-  std::string session_pid_tmp = session_dir + "/session_pid";
+  const std::string session_dir = Env::GetEnterSessionDir();
+  const std::string session_pid_tmp = session_dir + "/session_pid";
   std::string session_pid;
-  int fd_session_pid = open(session_pid_tmp.c_str(), O_RDONLY);
-  if (fd_session_pid < 0) throw EPublish("Session pid cannot be retrieved");
+  const int fd_session_pid = open(session_pid_tmp.c_str(), O_RDONLY);
+  if (fd_session_pid < 0)
+    throw EPublish("Session pid cannot be retrieved");
   SafeReadToString(fd_session_pid, &session_pid);
 
-  pid_t pid_child = String2Uint64(session_pid);
+  const pid_t pid_child = String2Uint64(session_pid);
   kill(pid_child, SIGUSR1);
 }
 
 void Publisher::Sync() {
-  ServerLockFileGuard g(is_publishing_);
+  const ServerLockFileGuard g(is_publishing_);
 
   ConstructSyncManagers();
 
   sync_union_->Traverse();
   bool rvb = sync_mediator_->Commit(manifest_);
-  if (!rvb) throw EPublish("cannot write change set to storage");
+  if (!rvb)
+    throw EPublish("cannot write change set to storage");
 
   if (!settings_.transaction().dry_run()) {
     spooler_files_->WaitForUpload();
     spooler_catalogs_->WaitForUpload();
     spooler_files_->FinalizeSession(false /* commit */);
 
-    const std::string old_root_hash =
-      settings_.transaction().base_hash().ToString(true /* with_suffix */);
-    const std::string new_root_hash =
-      manifest_->catalog_hash().ToString(true /* with_suffix */);
-    rvb = spooler_catalogs_->FinalizeSession(true /* commit */,
-      old_root_hash, new_root_hash,
-      /* TODO(jblomer) */ sync_parameters_->repo_tag);
+    const std::string old_root_hash = settings_.transaction()
+                                          .base_hash()
+                                          .ToString(true /* with_suffix */);
+    const std::string new_root_hash = manifest_->catalog_hash().ToString(
+        true /* with_suffix */);
+    rvb = spooler_catalogs_->FinalizeSession(
+        true /* commit */, old_root_hash, new_root_hash,
+        /* TODO(jblomer) */ sync_parameters_->repo_tag);
     if (!rvb)
       throw EPublish("failed to commit transaction");
 
@@ -841,11 +872,11 @@ void Publisher::MarkReplicatible(bool value) {
     throw EPublish("cannot set replication mode");
 }
 
-void Publisher::Ingest() {}
-void Publisher::Migrate() {}
-void Publisher::Resign() {}
-void Publisher::Rollback() {}
-void Publisher::UpdateMetaInfo() {}
+void Publisher::Ingest() { }
+void Publisher::Migrate() { }
+void Publisher::Resign() { }
+void Publisher::Rollback() { }
+void Publisher::UpdateMetaInfo() { }
 
 void Publisher::Transaction() {
   TransactionRetry();
@@ -856,12 +887,9 @@ void Publisher::Transaction() {
 
 
 Replica::Replica(const SettingsReplica &settings)
-  : Repository(SettingsRepository(settings))
-{
-}
+    : Repository(SettingsRepository(settings)) { }
 
 
-Replica::~Replica() {
-}
+Replica::~Replica() { }
 
 }  // namespace publish
