@@ -36,8 +36,8 @@ static void *MainUnpinListener(void *data) {
   LogCvmfs(kLogQuota, kLogDebug, "starting unpin listener for %s",
            handle->repository_name.c_str());
 
-  struct pollfd *watch_fds =
-    static_cast<struct pollfd *>(smalloc(2 * sizeof(struct pollfd)));
+  struct pollfd *watch_fds = static_cast<struct pollfd *>(
+      smalloc(2 * sizeof(struct pollfd)));
   watch_fds[0].fd = handle->pipe_terminate[0];
   watch_fds[0].events = POLLIN | POLLPRI;
   watch_fds[0].revents = 0;
@@ -45,7 +45,7 @@ static void *MainUnpinListener(void *data) {
   watch_fds[1].events = POLLIN | POLLPRI;
   watch_fds[1].revents = 0;
   while (true) {
-    int retval = poll(watch_fds, 2, -1);
+    const int retval = poll(watch_fds, 2, -1);
     if (retval < 0) {
       continue;
     }
@@ -78,8 +78,8 @@ static void *MainWatchdogListener(void *data) {
   LogCvmfs(kLogQuota, kLogDebug, "starting cache manager watchdog for %s",
            handle->repository_name.c_str());
 
-  struct pollfd *watch_fds =
-  static_cast<struct pollfd *>(smalloc(2 * sizeof(struct pollfd)));
+  struct pollfd *watch_fds = static_cast<struct pollfd *>(
+      smalloc(2 * sizeof(struct pollfd)));
   watch_fds[0].fd = handle->pipe_terminate[0];
   watch_fds[0].events = POLLIN | POLLPRI;
   watch_fds[0].revents = 0;
@@ -87,7 +87,7 @@ static void *MainWatchdogListener(void *data) {
   watch_fds[1].events = POLLIN | POLLPRI;
   watch_fds[1].revents = 0;
   while (true) {
-    int retval = poll(watch_fds, 2, -1);
+    const int retval = poll(watch_fds, 2, -1);
     if (retval < 0) {
       continue;
     }
@@ -98,10 +98,8 @@ static void *MainWatchdogListener(void *data) {
 
     // Release pinned catalogs
     if (watch_fds[1].revents) {
-      if ((watch_fds[1].revents & POLLERR) ||
-          (watch_fds[1].revents & POLLHUP) ||
-          (watch_fds[1].revents & POLLNVAL))
-      {
+      if ((watch_fds[1].revents & POLLERR) || (watch_fds[1].revents & POLLHUP)
+          || (watch_fds[1].revents & POLLNVAL)) {
         PANIC(kLogDebug | kLogSyslogErr, "cache manager disappeared, aborting");
       }
       // Clean the pipe
@@ -121,19 +119,18 @@ static void *MainWatchdogListener(void *data) {
 /**
  * Registers a back channel that reacts on high watermark of pinned chunks
  */
-ListenerHandle *
-RegisterUnpinListener(QuotaManager *quota_manager,
-                      CatalogManager *catalog_manager,
-                      const string &repository_name)
-{
+ListenerHandle *RegisterUnpinListener(QuotaManager *quota_manager,
+                                      CatalogManager *catalog_manager,
+                                      const string &repository_name) {
   ListenerHandle *handle = new ListenerHandle();
   quota_manager->RegisterBackChannel(handle->pipe_backchannel, repository_name);
   MakePipe(handle->pipe_terminate);
   handle->quota_manager = quota_manager;
   handle->catalog_manager = catalog_manager;
   handle->repository_name = repository_name;
-  int retval = pthread_create(&handle->thread_listener, NULL, MainUnpinListener,
-                              static_cast<void *>(handle));
+  const int retval = pthread_create(&handle->thread_listener, NULL,
+                                    MainUnpinListener,
+                                    static_cast<void *>(handle));
   assert(retval == 0);
   return handle;
 }
@@ -143,20 +140,17 @@ RegisterUnpinListener(QuotaManager *quota_manager,
  * Registers a back channel that kills the fuse module if the cache manager
  * disappears
  */
-ListenerHandle *
-RegisterWatchdogListener(
-  QuotaManager *quota_manager,
-  const string &repository_name)
-{
+ListenerHandle *RegisterWatchdogListener(QuotaManager *quota_manager,
+                                         const string &repository_name) {
   ListenerHandle *handle = new ListenerHandle();
   quota_manager->RegisterBackChannel(handle->pipe_backchannel, repository_name);
   MakePipe(handle->pipe_terminate);
   handle->quota_manager = quota_manager;
   handle->catalog_manager = NULL;
   handle->repository_name = repository_name;
-  int retval = pthread_create(&handle->thread_listener, NULL,
-                              MainWatchdogListener,
-                              static_cast<void *>(handle));
+  const int retval = pthread_create(&handle->thread_listener, NULL,
+                                    MainWatchdogListener,
+                                    static_cast<void *>(handle));
   assert(retval == 0);
   return handle;
 }
@@ -168,8 +162,8 @@ void UnregisterListener(ListenerHandle *handle) {
   pthread_join(handle->thread_listener, NULL);
   ClosePipe(handle->pipe_terminate);
 
-  handle->quota_manager->UnregisterBackChannel(
-    handle->pipe_backchannel, handle->repository_name);
+  handle->quota_manager->UnregisterBackChannel(handle->pipe_backchannel,
+                                               handle->repository_name);
 
   delete handle;
 }
