@@ -8,7 +8,6 @@ cvmfs_server_publish() {
   local hash_algorithm
   local tweaks_option=
   local tag_name=
-  local tag_channel=00
   local tag_description=
   local retcode=0
   local verbosity=""
@@ -17,13 +16,15 @@ cvmfs_server_publish() {
   local authz_file=""
   local force_external=0
   local force_native=0
+  local force_direct_io=0
   local force_compression_algorithm=""
   local external_option=""
+  local direct_io_option=""
   local open_fd_dialog=1
 
   # optional parameter handling
   OPTIND=1
-  while getopts "F:NXZ:pa:c:m:vn:fe" option
+  while getopts "F:NXZ:pa:c:m:vn:fed" option
   do
     case $option in
       p)
@@ -32,9 +33,6 @@ cvmfs_server_publish() {
       a)
         tag_name="$OPTARG"
       ;;
-      c)
-        tag_channel="$OPTARG"
-      ;;
       m)
         tag_description="$OPTARG"
       ;;
@@ -56,6 +54,9 @@ cvmfs_server_publish() {
       F)
         authz_file="-F $OPTARG"
       ;;
+      d)
+        force_direct_io=1
+      ;;
       f)
         open_fd_dialog=0
       ;;
@@ -98,7 +99,8 @@ cvmfs_server_publish() {
     if [ x"$upstream_type" = xgw ]; then
         health_check -g -r $name
     else
-        health_check -r $name
+        # TODO(jblomer): switch me back to `health_check -r $name`
+        health_check -g -r $name
     fi
 
     # get repository information
@@ -117,6 +119,9 @@ cvmfs_server_publish() {
         external_option="-Y"
       fi
     fi
+    if [ $force_direct_io -eq 1 ]; then
+      direct_io_option="-W"
+    fi
 
     # more sanity checks
     is_owner_or_root $name || { echo "Permission denied: Repository $name is owned by $user"; retcode=1; continue; }
@@ -172,6 +177,7 @@ cvmfs_server_publish() {
       -d /cvmfs/${name}/.cvmfsdirtab                     \
       -b $base_hash                                      \
       -w $stratum0                                       \
+      $(get_swissknife_proxy)                            \
       -t ${spool_dir}/tmp                                \
       -u /cvmfs/${name}                                  \
       -s ${scratch_dir}                                  \
@@ -180,7 +186,6 @@ cvmfs_server_publish() {
     local log_level=
     [ "x$CVMFS_LOG_LEVEL" != x ] && log_level="-z $CVMFS_LOG_LEVEL"
 
-    local trusted_certs="/etc/cvmfs/repositories.d/${name}/trusted_certs"
     local sync_command="$(__swissknife_cmd dbg) sync \
         -u /cvmfs/$name                                \
         -s ${scratch_dir}                              \
@@ -192,19 +197,16 @@ cvmfs_server_publish() {
         -o $manifest                                   \
         -e $hash_algorithm                             \
         -Z $compression_alg                            \
-        -C $trusted_certs                              \
         -N $name                                       \
         -K $CVMFS_PUBLIC_KEY                           \
         $(get_follow_http_redirects_flag)              \
+        $(get_swissknife_proxy)                        \
         $authz_file                                    \
-        $log_level $tweaks_option $external_option $verbosity"
+        $log_level $tweaks_option $external_option $direct_io_option $verbosity"
 
     if [ ! -z "$tag_name" ]; then
       sync_command="$sync_command -D $tag_name"
     fi
-    if [ ! -z "$tag_channel" ]; then
-      sync_command="$sync_command -G $tag_channel"
-    fi
 
     if [ x"$tag_description" != x"" ]; then
       sync_command="$sync_command -J $tag_description"
@@ -237,6 +239,9 @@ cvmfs_server_publish() {
     if [ "x$CVMFS_AUTOCATALOGS_MIN_WEIGHT" != "x" ]; then
       sync_command="$sync_command -M $CVMFS_AUTOCATALOGS_MIN_WEIGHT"
     fi
+    if [ "x$CVMFS_SERVER_USE_CATALOG_CACHE" = "xtrue" ]; then
+      sync_command="$sync_command -G"
+    fi
     if [ "x$CVMFS_IGNORE_XDIR_HARDLINKS" = "xtrue" ]; then
       sync_command="$sync_command -i"
     fi
@@ -246,6 +251,9 @@ cvmfs_server_publish() {
     if [ "x${CVMFS_ENFORCE_LIMITS:-$CVMFS_DEFAULT_ENFORCE_LIMITS}" = "xtrue" ]; then
       sync_command="$sync_command -E"
     fi
+    if [ "x$CVMFS_ENABLE_MTIME_NS" = "xtrue" ]; then
+      sync_command="$sync_command -j"
+    fi
     if [ "x$CVMFS_NESTED_KCATALOG_LIMIT" != "x" ]; then
       sync_command="$sync_command -Q $CVMFS_NESTED_KCATALOG_LIMIT"
     fi
@@ -273,6 +281,9 @@ cvmfs_server_publish() {
     if [ "x$CVMFS_IGNORE_SPECIAL_FILES" = "xtrue" ]; then
       sync_command="$sync_command -g"
     fi
+    if [ "x$CVMFS_UPLOAD_STATS_DB" = "xtrue" ]; then
+      sync_command="$sync_command -I"
+    fi
     local sync_command_virtual_dir=
     if [ "x${CVMFS_VIRTUAL_DIR}" = "xtrue" ]; then
       sync_command_virtual_dir="$sync_command -S snapshots"
@@ -297,6 +308,7 @@ cvmfs_server_publish() {
       -p /etc/cvmfs/keys/${name}.pub                    \
       -f $name                                          \
       -e $hash_algorithm                                \
+      $(get_swissknife_proxy)                           \
       $(get_follow_http_redirects_flag)"
     if ! is_checked_out $name; then
       # enables magic undo tag handling
@@ -310,9 +322,6 @@ cvmfs_server_publish() {
     if [ ! -z "$tag_name" ]; then
       tag_command="$tag_command -a $tag_name"
     fi
-    if [ ! -z "$tag_channel" ]; then
-      tag_command="$tag_command -c $tag_channel"
-    fi
     if [ ! -z "$tag_description" ]; then
       tag_command="$tag_command -D \"$tag_description\""
     fi
@@ -325,6 +334,7 @@ cvmfs_server_publish() {
       -p /etc/cvmfs/keys/${name}.pub                              \
       -f $name                                                    \
       -e $hash_algorithm                                          \
+      $(get_swissknife_proxy)                                     \
       $(get_follow_http_redirects_flag)                           \
       -x"
 
@@ -354,6 +364,7 @@ cvmfs_server_publish() {
     fi
 
     if [ x"$upstream_type" = xgw ]; then
+        # TODO(jpriessn): implement publication counters upload to gateway
         close_transaction  $name $use_fd_fallback
         publish_after_hook $name
         publish_succeeded $name
@@ -377,6 +388,7 @@ cvmfs_server_publish() {
           -f $name                                            \
           -b $base_hash                                       \
           -e $hash_algorithm                                  \
+          $(get_swissknife_proxy)                             \
           $(get_follow_http_redirects_flag)                   \
           -d \\\"$REPLY\\\""
         echo $user_shell \"${tag_cleanup_command}\" >> $tag_remove_cmd_file
@@ -443,6 +455,9 @@ cvmfs_server_publish() {
     fi
 
     # remount the repository
+    if [ "x$CVMFS_UPLOAD_STATS_PLOTS" = "xtrue" ]; then
+      /usr/share/cvmfs-server/upload_stats_plots.sh $name
+    fi
     close_transaction  $name $use_fd_fallback
     publish_after_hook $name
     publish_succeeded  $name
@@ -480,9 +495,10 @@ filter_auto_tags() {
     -t ${CVMFS_SPOOL_DIR}/tmp                  \
     -p /etc/cvmfs/keys/${repository_name}.pub  \
     -f $repository_name                        \
+    $(get_swissknife_proxy)                    \
     -x $(get_follow_http_redirects_flag)       | \
     grep -E \
-    '^generic(_[[:digit:]]+)?-[[:digit:]]{4}-[[:digit:]]{2}-[[:digit:]]{2}T[[:digit:]]{2}:[[:digit:]]{2}:[[:digit:]]{2}Z' | \
+    '^generic(_[[:digit:]]+)?-[[:digit:]]{4}-[[:digit:]]{2}-[[:digit:]]{2}T[[:digit:]]{2}:[[:digit:]]{2}:[[:digit:]]{2}(\.[[:digit:]]{1,3})?Z' | \
     awk '{print $1 " " $5}')"
   [ "x$auto_tags" = "x" ] && return 0 || true
 
