@@ -39,47 +39,44 @@ struct posix_file_handle {
  * BASIC FS OPERATIONS
  */
 void posix_list_dir(struct fs_traversal_context *ctx, const char *dir,
-  char ***buf, size_t *len);
+                    char ***buf, size_t *len);
 
-int posix_get_stat(struct fs_traversal_context *ctx,
-  const char *path, struct cvmfs_attr *stat_result, bool get_hash);
+int posix_get_stat(struct fs_traversal_context *ctx, const char *path,
+                   struct cvmfs_attr *stat_result, bool get_hash);
 
-int posix_set_meta(struct fs_traversal_context *ctx,
-  const char *path, const struct cvmfs_attr *stat_info);
+int posix_set_meta(struct fs_traversal_context *ctx, const char *path,
+                   const struct cvmfs_attr *stat_info);
 
 char *posix_get_identifier(struct fs_traversal_context *ctx,
-  const struct cvmfs_attr *stat);
+                           const struct cvmfs_attr *stat);
 
-bool posix_has_file(struct fs_traversal_context *ctx,
-  const char *ident);
+bool posix_has_file(struct fs_traversal_context *ctx, const char *ident);
 
-int posix_do_unlink(struct fs_traversal_context *ctx,
-  const char *path);
+int posix_do_unlink(struct fs_traversal_context *ctx, const char *path);
 
-int posix_do_rmdir(struct fs_traversal_context *ctx,
-  const char *path);
+int posix_do_rmdir(struct fs_traversal_context *ctx, const char *path);
 
-int posix_do_link(struct fs_traversal_context *ctx,
-  const char *path, const char *identifier);
+int posix_do_link(struct fs_traversal_context *ctx, const char *path,
+                  const char *identifier);
 
 int posix_do_mkdir(struct fs_traversal_context *ctx, const char *path,
-  const struct cvmfs_attr *stat_info);
+                   const struct cvmfs_attr *stat_info);
 
 int posix_do_symlink(struct fs_traversal_context *ctx, const char *src,
-  const char *dest, const struct cvmfs_attr *stat_info);
+                     const char *dest, const struct cvmfs_attr *stat_info);
 
 int posix_touch(struct fs_traversal_context *ctx,
-  const struct cvmfs_attr *stat_info);
+                const struct cvmfs_attr *stat_info);
 
 bool posix_is_hash_consistent(struct fs_traversal_context *ctx,
-  const struct cvmfs_attr *stat_info);
+                              const struct cvmfs_attr *stat_info);
 
 /*
  * FILE OPERATIONS
  */
 
 void *posix_get_handle(struct fs_traversal_context *ctx,
-  const char *identifier);
+                       const char *identifier);
 
 int posix_do_fopen(void *file_ctx, fs_open_type op_mode);
 
@@ -101,30 +98,23 @@ int posix_garbage_collector(struct fs_traversal_context *ctx);
 /*
  * ARCHIVE PROVENANCE INFORMATION
  */
-bool posix_archive_config(
-  std::string config_name,
-  std::string prov_name
-);
+bool posix_archive_config(std::string config_name, std::string prov_name);
 
-void posix_write_provenance_info(
-  struct fs_traversal_context *ctx,
-  const char *info_file
-);
+void posix_write_provenance_info(struct fs_traversal_context *ctx,
+                                 const char *info_file);
 
-void posix_archive_provenance(
-  struct fs_traversal_context *src,
-  struct fs_traversal_context *dest);
+void posix_archive_provenance(struct fs_traversal_context *src,
+                              struct fs_traversal_context *dest);
 
 /*
  * INITIALIZATION
  */
 
-struct fs_traversal_context *posix_initialize(
-  const char *repo,
-  const char *base,
-  const char *data,
-  const char *config,
-  int num_threads);
+struct fs_traversal_context *posix_initialize(const char *repo,
+                                              const char *base,
+                                              const char *data,
+                                              const char *config,
+                                              int num_threads);
 
 void posix_finalize(struct fs_traversal_context *ctx);
 
@@ -158,8 +148,7 @@ struct fs_traversal *posix_get_interface() {
 }
 
 // Utility function
-int posix_cleanup_path(struct fs_traversal_context *ctx,
-  const char *path) {
+int posix_cleanup_path(struct fs_traversal_context *ctx, const char *path) {
   std::string complete_path = BuildPath(ctx, path);
   std::string dirname = GetParentPath(complete_path);
   if (!DirectoryExists(dirname)) {
@@ -170,14 +159,14 @@ int posix_cleanup_path(struct fs_traversal_context *ctx,
   if (FileExists(complete_path) || SymlinkExists(complete_path)) {
     // Unlink file if existing
     int res = posix_do_unlink(ctx, path);
-    if (res != 0) return -1;
+    if (res != 0)
+      return -1;
   }
   if (DirectoryExists(complete_path)) {
     struct dirent *de;
     DIR *dr = opendir(complete_path.c_str());
     while ((de = readdir(dr)) != NULL) {
-      if (strcmp(de->d_name, ".") != 0
-        && strcmp(de->d_name, "..") != 0) {
+      if (strcmp(de->d_name, ".") != 0 && strcmp(de->d_name, "..") != 0) {
         std::string cur_path = std::string(path) + "/" + de->d_name;
         if (posix_cleanup_path(ctx, cur_path.c_str()) != 0) {
           return -1;
@@ -186,7 +175,8 @@ int posix_cleanup_path(struct fs_traversal_context *ctx,
     }
     int res = closedir(dr);
     res |= posix_do_rmdir(ctx, path);
-    if (res != 0) return -1;
+    if (res != 0)
+      return -1;
   }
   return 0;
 }
@@ -196,9 +186,9 @@ int posix_cleanup_path(struct fs_traversal_context *ctx,
  */
 
 void posix_list_dir(struct fs_traversal_context *ctx,
-  const char *dir,
-  char ***buf,
-  size_t *len) {
+                    const char *dir,
+                    char ***buf,
+                    size_t *len) {
   struct dirent *de;
   *len = 0;
   size_t buflen = 5;
@@ -214,9 +204,8 @@ void posix_list_dir(struct fs_traversal_context *ctx,
   }
 
   while ((de = readdir(dr)) != NULL) {
-    if (strcmp(de->d_name, ".") != 0
-      && strcmp(de->d_name, "..") != 0
-      && strcmp(de->d_name, WARNING_FILE_NAME) != 0) {
+    if (strcmp(de->d_name, ".") != 0 && strcmp(de->d_name, "..") != 0
+        && strcmp(de->d_name, WARNING_FILE_NAME) != 0) {
       AppendStringToList(de->d_name, buf, len, &buflen);
     }
   }
@@ -226,10 +215,9 @@ void posix_list_dir(struct fs_traversal_context *ctx,
 }
 
 int posix_get_stat(struct fs_traversal_context *ctx,
-  const char *path,
-  struct cvmfs_attr *stat_result,
-  bool get_hash)
-{
+                   const char *path,
+                   struct cvmfs_attr *stat_result,
+                   bool get_hash) {
   std::string complete_path = BuildPath(ctx, path);
   struct stat buf;
   int res = lstat(complete_path.c_str(), &buf);
@@ -257,9 +245,8 @@ int posix_get_stat(struct fs_traversal_context *ctx,
   }
 
   if (S_ISLNK(buf.st_mode)) {
-    char slnk[PATH_MAX+1];
-    const ssize_t length =
-      readlink(complete_path.c_str(), slnk, PATH_MAX);
+    char slnk[PATH_MAX + 1];
+    const ssize_t length = readlink(complete_path.c_str(), slnk, PATH_MAX);
     if (length < 0) {
       return -1;
     }
@@ -274,74 +261,79 @@ int posix_get_stat(struct fs_traversal_context *ctx,
   stat_result->cvm_name = strdup(file_name.c_str());
 
   stat_result->cvm_xattrs = XattrList::CreateFromFile(complete_path);
-  if (stat_result->cvm_xattrs == NULL) return -1;
+  if (stat_result->cvm_xattrs == NULL)
+    return -1;
 
   return 0;
 }
 
-int posix_set_meta(struct fs_traversal_context *ctx,
-  const char *path, const struct cvmfs_attr *stat_info) {
+int posix_set_meta(struct fs_traversal_context *ctx, const char *path,
+                   const struct cvmfs_attr *stat_info) {
   std::string complete_path = BuildPath(ctx, path);
   return PosixSetMeta(complete_path.c_str(), stat_info,
-    !S_ISLNK(stat_info->st_mode));
+                      !S_ISLNK(stat_info->st_mode));
 }
 
 char *posix_get_identifier(struct fs_traversal_context *ctx,
-  const struct cvmfs_attr *stat) {
-  shash::Any content_hash =
-    shash::MkFromHexPtr(shash::HexPtr(stat->cvm_checksum));
+                           const struct cvmfs_attr *stat) {
+  shash::Any content_hash = shash::MkFromHexPtr(
+      shash::HexPtr(stat->cvm_checksum));
   shash::Any meta_hash = HashMeta(stat);
   std::string path = ("/"
-    + content_hash.MakePathExplicit(kDirLevels, kDigitsPerDirLevel, '.')
-    + meta_hash.ToString());
+                      + content_hash.MakePathExplicit(kDirLevels,
+                                                      kDigitsPerDirLevel, '.')
+                      + meta_hash.ToString());
   char *res = strdup(path.c_str());
   return res;
 }
 
-bool posix_has_file(struct fs_traversal_context *ctx,
-  const char *ident) {
+bool posix_has_file(struct fs_traversal_context *ctx, const char *ident) {
   return FileExists(BuildHiddenPath(ctx, ident));
 }
 
-int posix_do_unlink(struct fs_traversal_context *ctx,
-  const char *path) {
+int posix_do_unlink(struct fs_traversal_context *ctx, const char *path) {
   std::string complete_path = BuildPath(ctx, path);
   std::string parent_path = GetParentPath(complete_path);
   const char *complete_path_char = complete_path.c_str();
   struct stat buf;
   int res2 = lstat(complete_path_char, &buf);
-  if (res2 == -1 && errno == ENOENT) return -1;
+  if (res2 == -1 && errno == ENOENT)
+    return -1;
   assert(res2 == 0);
   struct utimbuf mtimes;
-  if (!BackupMtimes(parent_path, &mtimes)) return -1;
+  if (!BackupMtimes(parent_path, &mtimes))
+    return -1;
   // Unlinking
   int res1 = unlink(complete_path_char);
   res1 |= utime(parent_path.c_str(), &mtimes);
-  if (res1 == -1) return -1;
+  if (res1 == -1)
+    return -1;
   // GC Flagging
   if (S_ISREG(buf.st_mode) && buf.st_nlink == 2) {
-    struct fs_traversal_posix_context *pos_ctx
-      =  reinterpret_cast<struct fs_traversal_posix_context*>(ctx->ctx);
+    struct fs_traversal_posix_context
+        *pos_ctx = reinterpret_cast<struct fs_traversal_posix_context *>(
+            ctx->ctx);
     pos_ctx->gc_flagged[buf.st_ino] = true;
   }
   return 0;
 }
 
-int posix_do_rmdir(struct fs_traversal_context *ctx,
-  const char *path) {
+int posix_do_rmdir(struct fs_traversal_context *ctx, const char *path) {
   std::string complete_path = BuildPath(ctx, path);
   std::string parent_path = GetParentPath(complete_path);
   struct utimbuf mtimes;
-  if (!BackupMtimes(parent_path, &mtimes)) return -1;
+  if (!BackupMtimes(parent_path, &mtimes))
+    return -1;
   int res = rmdir(complete_path.c_str());
   res |= utime(parent_path.c_str(), &mtimes);
-  if (res != 0) return -1;
+  if (res != 0)
+    return -1;
   return 0;
 }
 
 int posix_do_link(struct fs_traversal_context *ctx,
-  const char *path,
-  const char *identifier) {
+                  const char *path,
+                  const char *identifier) {
   std::string complete_path = BuildPath(ctx, path);
   std::string parent_path = GetParentPath(complete_path);
   std::string hidden_datapath = BuildHiddenPath(ctx, identifier);
@@ -352,15 +344,17 @@ int posix_do_link(struct fs_traversal_context *ctx,
     return -1;
   }
   struct utimbuf mtimes_parent;
-  if (!BackupMtimes(parent_path, &mtimes_parent)) return -1;
+  if (!BackupMtimes(parent_path, &mtimes_parent))
+    return -1;
 
   struct utimbuf mtimes_link;
-  if (!BackupMtimes(hidden_datapath, &mtimes_link)) return -1;
+  if (!BackupMtimes(hidden_datapath, &mtimes_link))
+    return -1;
 
   if (posix_cleanup_path(ctx, path) != 0) {
     return -1;
   }
-    // GC Unflagging
+  // GC Unflagging
   struct stat buf;
   int res2 = lstat(hidden_datapath_char, &buf);
   assert(res2 == 0);
@@ -369,13 +363,14 @@ int posix_do_link(struct fs_traversal_context *ctx,
   res1 |= utime(hidden_datapath.c_str(), &mtimes_link);
   if (res1 != 0) {
     LogCvmfs(kLogCvmfs, kLogStderr,
-      "Failed to create link : %s->%s : %d : %s\n",
-      hidden_datapath_char, complete_path.c_str(), errno, strerror(errno));
+             "Failed to create link : %s->%s : %d : %s\n", hidden_datapath_char,
+             complete_path.c_str(), errno, strerror(errno));
     return -1;
   }
   if (S_ISREG(buf.st_mode) && buf.st_nlink == 2) {
-    struct fs_traversal_posix_context *pos_ctx
-      =  reinterpret_cast<struct fs_traversal_posix_context*>(ctx->ctx);
+    struct fs_traversal_posix_context
+        *pos_ctx = reinterpret_cast<struct fs_traversal_posix_context *>(
+            ctx->ctx);
     if (pos_ctx->gc_flagged.count(buf.st_ino) > 0) {
       pos_ctx->gc_flagged[buf.st_ino] = false;
     }
@@ -384,42 +379,46 @@ int posix_do_link(struct fs_traversal_context *ctx,
 }
 
 int posix_do_mkdir(struct fs_traversal_context *ctx,
-  const char *path,
-  const struct cvmfs_attr *stat_info) {
+                   const char *path,
+                   const struct cvmfs_attr *stat_info) {
   std::string complete_path = BuildPath(ctx, path);
   std::string parent_path = GetParentPath(complete_path);
   std::string dirname = GetParentPath(complete_path);
   struct utimbuf mtimes;
-  if (!BackupMtimes(parent_path, &mtimes)) return -1;
+  if (!BackupMtimes(parent_path, &mtimes))
+    return -1;
   if (posix_cleanup_path(ctx, path) != 0) {
     return -1;
   }
   int res = mkdir(complete_path.c_str(), stat_info->st_mode);
   res |= utime(parent_path.c_str(), &mtimes);
-  if (res != 0) return -1;
+  if (res != 0)
+    return -1;
   return PosixSetMeta(complete_path.c_str(), stat_info);
 }
 
 int posix_do_symlink(struct fs_traversal_context *ctx,
-  const char *src,
-  const char *dest,
-  const struct cvmfs_attr *stat_info) {
+                     const char *src,
+                     const char *dest,
+                     const struct cvmfs_attr *stat_info) {
   std::string complete_src_path = BuildPath(ctx, src);
   std::string parent_path = GetParentPath(complete_src_path);
   std::string complete_dest_path = dest;
   struct utimbuf mtimes;
-  if (!BackupMtimes(parent_path, &mtimes)) return -1;
+  if (!BackupMtimes(parent_path, &mtimes))
+    return -1;
   if (posix_cleanup_path(ctx, src) != 0) {
     return -1;
   }
   int res = symlink(complete_dest_path.c_str(), complete_src_path.c_str());
   res |= utime(parent_path.c_str(), &mtimes);
-  if (res != 0) return -1;
+  if (res != 0)
+    return -1;
   return PosixSetMeta(complete_src_path.c_str(), stat_info, false);
 }
 
 int posix_touch(struct fs_traversal_context *ctx,
-  const struct cvmfs_attr *stat_info) {
+                const struct cvmfs_attr *stat_info) {
   // NOTE(steuber): creat is only atomic on non-NFS paths!
   char *identifier = posix_get_identifier(ctx, stat_info);
   if (posix_has_file(ctx, identifier)) {
@@ -430,19 +429,23 @@ int posix_touch(struct fs_traversal_context *ctx,
   std::string hidden_datapath = BuildHiddenPath(ctx, identifier);
   free(identifier);
   int res1 = creat(hidden_datapath.c_str(), stat_info->st_mode);
-  if (res1 < 0) return -1;
+  if (res1 < 0)
+    return -1;
   int res2 = close(res1);
-  if (res2 < 0) return -1;
+  if (res2 < 0)
+    return -1;
   int res3 = PosixSetMeta(hidden_datapath.c_str(), stat_info);
-  if (res3 < 0) return -1;
+  if (res3 < 0)
+    return -1;
   return 0;
 }
 
 bool posix_is_hash_consistent(struct fs_traversal_context *ctx,
-  const struct cvmfs_attr *stat_info) {
+                              const struct cvmfs_attr *stat_info) {
   errno = 0;
-  std::string complete_path = BuildPath(ctx,
-    (std::string(stat_info->cvm_parent)+"/"+stat_info->cvm_name).c_str());
+  std::string complete_path = BuildPath(
+      ctx,
+      (std::string(stat_info->cvm_parent) + "/" + stat_info->cvm_name).c_str());
   struct stat display_path_stat;
   int res1 = lstat(complete_path.c_str(), &display_path_stat);
   if (res1 == -1) {
@@ -466,7 +469,7 @@ bool posix_is_hash_consistent(struct fs_traversal_context *ctx,
 }
 
 void *posix_get_handle(struct fs_traversal_context *ctx,
-  const char *identifier) {
+                       const char *identifier) {
   struct posix_file_handle *file_ctx = new struct posix_file_handle;
   file_ctx->path = BuildHiddenPath(ctx, identifier);
 
@@ -476,22 +479,24 @@ void *posix_get_handle(struct fs_traversal_context *ctx,
 bool EnableWriteAccess(posix_file_handle *handle) {
   struct stat info;
   int retval = stat(handle->path.c_str(), &info);
-  if (retval != 0) return false;
+  if (retval != 0)
+    return false;
   handle->original_mode = info.st_mode;
   retval = chmod(handle->path.c_str(), info.st_mode | S_IWUSR | S_IWUSR);
   return retval == 0;
 }
 
 int posix_do_fopen(void *file_ctx, fs_open_type op_mode) {
-  struct posix_file_handle *handle =
-    reinterpret_cast<posix_file_handle *>(file_ctx);
+  struct posix_file_handle *handle = reinterpret_cast<posix_file_handle *>(
+      file_ctx);
   const char *mode = "r";
   if (op_mode == fs_open_write) {
     mode = "w";
   } else if (op_mode == fs_open_append) {
     mode = "a";
   }
-  if (!BackupMtimes(handle->path, &(handle->mtimes))) return -1;
+  if (!BackupMtimes(handle->path, &(handle->mtimes)))
+    return -1;
   handle->original_mode = 0;
 
   FILE *fd = fopen(handle->path.c_str(), mode);
@@ -510,8 +515,8 @@ int posix_do_fopen(void *file_ctx, fs_open_type op_mode) {
 }
 
 int posix_do_fclose(void *file_ctx) {
-  struct posix_file_handle *handle =
-    reinterpret_cast<posix_file_handle *>(file_ctx);
+  struct posix_file_handle *handle = reinterpret_cast<posix_file_handle *>(
+      file_ctx);
   int res = 0;
   if (handle->original_mode != 0) {
     res = fchmod(fileno(handle->fd), handle->original_mode);
@@ -524,24 +529,25 @@ int posix_do_fclose(void *file_ctx) {
     return -1;
   }
   res = utime(handle->path.c_str(), &(handle->mtimes));
-  if (res != 0) return -1;
+  if (res != 0)
+    return -1;
   return 0;
 }
 
 int posix_do_fread(void *file_ctx, char *buff, size_t len, size_t *read_len) {
-  struct posix_file_handle *handle =
-    reinterpret_cast<posix_file_handle *>(file_ctx);
+  struct posix_file_handle *handle = reinterpret_cast<posix_file_handle *>(
+      file_ctx);
   *read_len = fread(buff, sizeof(char), len, handle->fd);
   if (*read_len < len && ferror(handle->fd) != 0) {
-      clearerr(handle->fd);
-      return -1;
+    clearerr(handle->fd);
+    return -1;
   }
   return 0;
 }
 
 int posix_do_fwrite(void *file_ctx, const char *buff, size_t len) {
-  struct posix_file_handle *handle =
-    reinterpret_cast<posix_file_handle *>(file_ctx);
+  struct posix_file_handle *handle = reinterpret_cast<posix_file_handle *>(
+      file_ctx);
   size_t written_len = fwrite(buff, sizeof(char), len, handle->fd);
   if (written_len != len) {
     clearerr(handle->fd);
@@ -551,8 +557,8 @@ int posix_do_fwrite(void *file_ctx, const char *buff, size_t len) {
 }
 
 void posix_do_ffree(void *file_ctx) {
-  struct posix_file_handle *handle =
-    reinterpret_cast<posix_file_handle *>(file_ctx);
+  struct posix_file_handle *handle = reinterpret_cast<posix_file_handle *>(
+      file_ctx);
   if (handle->fd != NULL) {
     posix_do_fclose(file_ctx);
   }
@@ -563,15 +569,12 @@ int posix_garbage_collector(struct fs_traversal_context *ctx) {
   return RunGarbageCollection(ctx);
 }
 
-bool posix_archive_config(
-  std::string config_name,
-  std::string prov_name
-) {
+bool posix_archive_config(std::string config_name, std::string prov_name) {
   FILE *prov = fopen(prov_name.c_str(), "w");
   if (prov == NULL) {
     LogCvmfs(kLogCvmfs, kLogStderr,
-      "Archive config: failed to open : %s : %d : %s\n",
-      prov_name.c_str(), errno, strerror(errno));
+             "Archive config: failed to open : %s : %d : %s\n",
+             prov_name.c_str(), errno, strerror(errno));
     return false;
   }
 
@@ -580,8 +583,8 @@ bool posix_archive_config(
     FILE *config = fopen(config_files[i].c_str(), "r");
     if (config == NULL) {
       LogCvmfs(kLogCvmfs, kLogStderr,
-        "Archive config: failed to open : %s : %d : %s\n",
-        config_name.c_str(), errno, strerror(errno));
+               "Archive config: failed to open : %s : %d : %s\n",
+               config_name.c_str(), errno, strerror(errno));
       fclose(prov);
       return false;
     }
@@ -592,8 +595,8 @@ bool posix_archive_config(
       size_t nbytes = 0;
       nbytes = fread(&buffer, sizeof(char), sizeof(buffer), config);
       if (nbytes < sizeof(buffer) && ferror(config) != 0) {
-        LogCvmfs(kLogCvmfs, kLogStderr,
-          "Archive config: read failed : %d %s\n", errno, strerror(errno));
+        LogCvmfs(kLogCvmfs, kLogStderr, "Archive config: read failed : %d %s\n",
+                 errno, strerror(errno));
         fclose(config);
         fclose(prov);
         return false;
@@ -602,8 +605,8 @@ bool posix_archive_config(
       size_t written_len = fwrite(buffer, sizeof(char), nbytes, prov);
       if (written_len != nbytes) {
         LogCvmfs(kLogCvmfs, kLogStderr,
-                 "Archive config: write failed : %d %s\n",
-                 errno, strerror(errno));
+                 "Archive config: write failed : %d %s\n", errno,
+                 strerror(errno));
         fclose(config);
         fclose(prov);
         return false;
@@ -617,10 +620,8 @@ bool posix_archive_config(
   return true;
 }
 
-void posix_write_provenance_info(
-  struct fs_traversal_context *ctx,
-  const char *info_file
-) {
+void posix_write_provenance_info(struct fs_traversal_context *ctx,
+                                 const char *info_file) {
   FILE *f = fopen(info_file, "w");
   if (f != NULL) {
     fwrite("repo : ", sizeof(char), 7, f);
@@ -640,10 +641,8 @@ void posix_write_provenance_info(
   }
 }
 
-void posix_archive_provenance(
-  struct fs_traversal_context *src,
-  struct fs_traversal_context *dest)
-{
+void posix_archive_provenance(struct fs_traversal_context *src,
+                              struct fs_traversal_context *dest) {
   std::string prov_dir;
   prov_dir.append(dest->base);
   prov_dir.append(".provenance/");
@@ -653,7 +652,7 @@ void posix_archive_provenance(
   if (!DirectoryExists(prov_dir.c_str())) {
     if (!MkdirDeep(prov_dir.c_str(), 0755, true)) {
       LogCvmfs(kLogCvmfs, kLogStderr,
-        "Failed to create repository directory '%s'", prov_dir.c_str());
+               "Failed to create repository directory '%s'", prov_dir.c_str());
     }
   }
 
@@ -664,8 +663,8 @@ void posix_archive_provenance(
   if (src->config) {
     std::string src_config = prov_dir + "src.config";
     if (!posix_archive_config(src->config, src_config)) {
-      LogCvmfs(kLogCvmfs, kLogStderr,
-        "Failed to archive source config '%s'", src->config);
+      LogCvmfs(kLogCvmfs, kLogStderr, "Failed to archive source config '%s'",
+               src->config);
     }
   }
 
@@ -677,22 +676,21 @@ void posix_archive_provenance(
     std::string dest_config = prov_dir + "dest.config";
     if (!posix_archive_config(dest->config, dest_config)) {
       LogCvmfs(kLogCvmfs, kLogStderr,
-        "Failed to archive destination config '%s'", dest->config);
+               "Failed to archive destination config '%s'", dest->config);
     }
   }
 }
 
-struct fs_traversal_context *posix_initialize(
-  const char *repo,
-  const char *base,
-  const char *data,
-  const char *config,
-  int num_threads) {
+struct fs_traversal_context *posix_initialize(const char *repo,
+                                              const char *base,
+                                              const char *data,
+                                              const char *config,
+                                              int num_threads) {
   fs_traversal_context *result = new struct fs_traversal_context;
   result->version = 1;
   result->lib_version = strdup("1.0");
-  struct fs_traversal_posix_context *posix_ctx
-    = new struct fs_traversal_posix_context;
+  struct fs_traversal_posix_context
+      *posix_ctx = new struct fs_traversal_posix_context;
   posix_ctx->num_threads = num_threads;
   result->ctx = posix_ctx;
 
@@ -700,10 +698,10 @@ struct fs_traversal_context *posix_initialize(
   if (!base) {
     result->base = strdup("/tmp/cvmfs/");
   } else {
-    if  (base[strlen(base)-1] != '/') {
+    if (base[strlen(base) - 1] != '/') {
       size_t len = 2 + strlen(base);
-      char *base_dir = reinterpret_cast<char *>(smalloc(len*sizeof(char)));
-      snprintf(base_dir, len, "%s/",  base);
+      char *base_dir = reinterpret_cast<char *>(smalloc(len * sizeof(char)));
+      snprintf(base_dir, len, "%s/", base);
       result->base = strdup(base_dir);
       free(base_dir);
     } else {
@@ -713,8 +711,7 @@ struct fs_traversal_context *posix_initialize(
 
   // Retrieve repository (inside base directory) for traversal
   if (!repo) {
-    LogCvmfs(kLogCvmfs, kLogStderr,
-      "Repository name must be specified");
+    LogCvmfs(kLogCvmfs, kLogStderr, "Repository name must be specified");
     return NULL;
   }
   result->repo = strdup(repo);
@@ -722,8 +719,8 @@ struct fs_traversal_context *posix_initialize(
   // Retrieve data directory (for hidden dedup directory)
   if (!data) {
     size_t len = 6 + strlen(result->base);
-    char *def_data = reinterpret_cast<char *>(smalloc(len*sizeof(char)));
-    snprintf(def_data, len, "%s.data",  result->base);
+    char *def_data = reinterpret_cast<char *>(smalloc(len * sizeof(char)));
+    snprintf(def_data, len, "%s.data", result->base);
     result->data = strdup(def_data);
     free(def_data);
   } else {
@@ -732,7 +729,8 @@ struct fs_traversal_context *posix_initialize(
 
   if (config && strlen(config) > 0) {
     LogCvmfs(kLogCvmfs, kLogStderr,
-      "Configuration file is not supported in POSIX interface '%s'", config);
+             "Configuration file is not supported in POSIX interface '%s'",
+             config);
     return NULL;
   }
   result->config = NULL;
@@ -742,7 +740,7 @@ struct fs_traversal_context *posix_initialize(
   if (!DirectoryExists(req_dirs.c_str())) {
     if (!MkdirDeep(req_dirs.c_str(), 0755, true)) {
       LogCvmfs(kLogCvmfs, kLogStderr,
-        "Failed to create repository directory '%s'", req_dirs.c_str());
+               "Failed to create repository directory '%s'", req_dirs.c_str());
       return NULL;
     }
   }
@@ -759,8 +757,9 @@ void posix_finalize(struct fs_traversal_context *ctx) {
   free(ctx->data);
   free(ctx->config);
   free(ctx->lib_version);
-  struct fs_traversal_posix_context *posix_ctx
-    =  reinterpret_cast<struct fs_traversal_posix_context*>(ctx->ctx);
+  struct fs_traversal_posix_context
+      *posix_ctx = reinterpret_cast<struct fs_traversal_posix_context *>(
+          ctx->ctx);
   delete posix_ctx;
   delete ctx;
 }
