@@ -10,7 +10,6 @@
 #include <string.h>
 #include <time.h>
 
-
 #include "shrinkwrap/fs_traversal.h"
 #include "shrinkwrap/fs_traversal_interface.h"
 #include "util/concurrency.h"
@@ -22,13 +21,15 @@ namespace {
 
 struct Params {
   bool CheckType(const std::string &type) {
-    if ((type == "cvmfs") || (type == "posix")) return true;
+    if ((type == "cvmfs") || (type == "posix"))
+      return true;
     LogCvmfs(kLogCvmfs, kLogStderr, "Unknown type: %s", type.c_str());
     return false;
   }
 
   bool Check() {
-    if (!CheckType(src_type) || !CheckType(dst_type)) return false;
+    if (!CheckType(src_type) || !CheckType(dst_type))
+      return false;
 
     return true;
   }
@@ -45,20 +46,19 @@ struct Params {
   }
 
   Params()
-    : repo_name()
-    , src_type("cvmfs")
-    , src_base_dir("/cvmfs")
-    , src_config_path("cvmfs.conf:cvmfs.local")
-    , src_data_dir()
-    , dst_type("posix")
-    , dst_config_path()
-    , dst_base_dir("/export/cvmfs")
-    , dst_data_dir()
-    , spec_trace_path()
-    , num_parallel(0)
-    , stat_period(10)
-    , do_garbage_collection(false)
-  { }
+      : repo_name()
+      , src_type("cvmfs")
+      , src_base_dir("/cvmfs")
+      , src_config_path("cvmfs.conf:cvmfs.local")
+      , src_data_dir()
+      , dst_type("posix")
+      , dst_config_path()
+      , dst_base_dir("/export/cvmfs")
+      , dst_data_dir()
+      , spec_trace_path()
+      , num_parallel(0)
+      , stat_period(10)
+      , do_garbage_collection(false) { }
 
   std::string repo_name;
   std::string src_type;
@@ -76,27 +76,28 @@ struct Params {
 };
 
 void Usage() {
-  LogCvmfs(kLogCvmfs, kLogStdout,
-       "CernVM File System Shrinkwrapper, version %s\n\n"
-       "This tool takes a cvmfs repository and outputs\n"
-       "to a destination files system.\n"
-       "Usage: cvmfs_shrinkwrap "
-       "[-r][-sbcf][-dxyz][-t][-jrg]\n"
-        "Options:\n"
-        " -r --repo        Repository name [required]\n"
-        " -s --src-type    Source filesystem type [default:cvmfs]\n"
-        " -b --src-base    Source base location [default:/cvmfs/]\n"
-        " -c --src-cache   Source cache\n"
-        " -f --src-config  Source config [default:cvmfs.conf:cvmfs.local]\n"
-        " -d --dest-type   Dest filesystem type [default:posix]\n"
-        " -x --dest-base   Dest base [default:/export/cvmfs]\n"
-        " -y --dest-cache  Dest cache [default:$BASE/.data]\n"
-        " -z --dest-config Dest config\n"
-        " -t --spec-file   Specification file [default=$REPO.spec]\n"
-        " -j --threads     Number of concurrent copy threads [default:2*CPUs]\n"
-        " -p --stat-period Frequency of stat prints, 0 disables [default:10]\n"
-        " -g --gc          Perform garbage collection on destination\n",
-           CVMFS_VERSION);
+  LogCvmfs(
+      kLogCvmfs, kLogStdout,
+      "CernVM File System Shrinkwrapper, version %s\n\n"
+      "This tool takes a cvmfs repository and outputs\n"
+      "to a destination files system.\n"
+      "Usage: cvmfs_shrinkwrap "
+      "[-r][-sbcf][-dxyz][-t][-jrg]\n"
+      "Options:\n"
+      " -r --repo        Repository name [required]\n"
+      " -s --src-type    Source filesystem type [default:cvmfs]\n"
+      " -b --src-base    Source base location [default:/cvmfs/]\n"
+      " -c --src-cache   Source cache\n"
+      " -f --src-config  Source config [default:cvmfs.conf:cvmfs.local]\n"
+      " -d --dest-type   Dest filesystem type [default:posix]\n"
+      " -x --dest-base   Dest base [default:/export/cvmfs]\n"
+      " -y --dest-cache  Dest cache [default:$BASE/.data]\n"
+      " -z --dest-config Dest config\n"
+      " -t --spec-file   Specification file [default=$REPO.spec]\n"
+      " -j --threads     Number of concurrent copy threads [default:2*CPUs]\n"
+      " -p --stat-period Frequency of stat prints, 0 disables [default:10]\n"
+      " -g --gc          Perform garbage collection on destination\n",
+      CVMFS_VERSION);
 }
 
 }  // anonymous namespace
@@ -107,22 +108,21 @@ int main(int argc, char **argv) {
   int c;
   static struct option long_opts[] = {
       /* All of the options require an argument */
-      {"help",        no_argument, 0, 'h'},
-      {"repo",        required_argument, 0, 'r'},
-      {"src-type",    required_argument, 0, 's'},
-      {"src-base",    required_argument, 0, 'b'},
-      {"src-cache",   required_argument, 0, 'c'},
-      {"src-config",  required_argument, 0, 'f'},
-      {"dest-type",   required_argument, 0, 'd'},
-      {"dest-base",   required_argument, 0, 'x'},
-      {"dest-cache",  required_argument, 0, 'y'},
+      {"help", no_argument, 0, 'h'},
+      {"repo", required_argument, 0, 'r'},
+      {"src-type", required_argument, 0, 's'},
+      {"src-base", required_argument, 0, 'b'},
+      {"src-cache", required_argument, 0, 'c'},
+      {"src-config", required_argument, 0, 'f'},
+      {"dest-type", required_argument, 0, 'd'},
+      {"dest-base", required_argument, 0, 'x'},
+      {"dest-cache", required_argument, 0, 'y'},
       {"dest-config", required_argument, 0, 'z'},
-      {"spec-file",   required_argument, 0, 't'},
-      {"threads",     required_argument, 0, 'j'},
+      {"spec-file", required_argument, 0, 't'},
+      {"threads", required_argument, 0, 'j'},
       {"stat-period", required_argument, 0, 'p'},
-      {"gc",          no_argument, 0, 'g'},
-      {0, 0, 0, 0}
-    };
+      {"gc", no_argument, 0, 'g'},
+      {0, 0, 0, 0}};
 
   static const char short_opts[] = "hb:s:r:c:f:d:x:y:t:j:p:g";
 
@@ -163,9 +163,10 @@ int main(int argc, char **argv) {
         break;
       case 'j':
         if (!String2Uint64Parse(optarg, &params.num_parallel)) {
-          LogCvmfs(kLogCvmfs, kLogStderr,
-            "Invalid value passed to 'j': %s : only non-negative integers",
-             optarg);
+          LogCvmfs(
+              kLogCvmfs, kLogStderr,
+              "Invalid value passed to 'j': %s : only non-negative integers",
+              optarg);
           Usage();
           return 1;
         }
@@ -175,9 +176,10 @@ int main(int argc, char **argv) {
         break;
       case 'p':
         if (!String2Uint64Parse(optarg, &params.stat_period)) {
-          LogCvmfs(kLogCvmfs, kLogStderr,
-            "Invalid value passed to 'p': %s : only non-negative integers",
-             optarg);
+          LogCvmfs(
+              kLogCvmfs, kLogStderr,
+              "Invalid value passed to 'p': %s : only non-negative integers",
+              optarg);
           Usage();
           return 1;
         }
@@ -189,35 +191,34 @@ int main(int argc, char **argv) {
     }
   }
 
-  if (!params.Check()) return 1;
+  if (!params.Check())
+    return 1;
   params.Complete();
 
   struct fs_traversal *src = shrinkwrap::FindInterface(params.src_type.c_str());
   if (!src) {
     return 1;
   }
-  src->context_ = src->initialize(
-    params.repo_name.c_str(),
-    params.src_base_dir.c_str(),
-    params.src_data_dir.c_str(),
-    params.src_config_path.c_str(),
-    params.num_parallel);
+  src->context_ = src->initialize(params.repo_name.c_str(),
+                                  params.src_base_dir.c_str(),
+                                  params.src_data_dir.c_str(),
+                                  params.src_config_path.c_str(),
+                                  params.num_parallel);
   if (!src->context_) {
     LogCvmfs(kLogCvmfs, kLogStderr, "Unable to initialize source");
     return 1;
   }
 
-  struct fs_traversal *dest =
-    shrinkwrap::FindInterface(params.dst_type.c_str());
+  struct fs_traversal *dest = shrinkwrap::FindInterface(
+      params.dst_type.c_str());
   if (!dest) {
     return 1;
   }
-  dest->context_ = dest->initialize(
-    params.repo_name.c_str(),
-    params.dst_base_dir.c_str(),
-    params.dst_data_dir.c_str(),
-    params.dst_config_path.c_str(),
-    params.num_parallel);
+  dest->context_ = dest->initialize(params.repo_name.c_str(),
+                                    params.dst_base_dir.c_str(),
+                                    params.dst_data_dir.c_str(),
+                                    params.dst_config_path.c_str(),
+                                    params.num_parallel);
   if (!dest->context_) {
     LogCvmfs(kLogCvmfs, kLogStderr, "Unable to initialize destination");
     src->finalize(src->context_);
@@ -227,13 +228,9 @@ int main(int argc, char **argv) {
 
   dest->archive_provenance(src->context_, dest->context_);
 
-  int result = shrinkwrap::SyncInit(
-    src,
-    dest,
-    "", /* spec_base_dir, unused */
-    params.spec_trace_path.c_str(),
-    params.num_parallel,
-    params.stat_period);
+  const int result = shrinkwrap::SyncInit(
+      src, dest, "", /* spec_base_dir, unused */
+      params.spec_trace_path.c_str(), params.num_parallel, params.stat_period);
 
   src->finalize(src->context_);
   if (params.do_garbage_collection) {
