@@ -28,8 +28,8 @@ std::string Counter::PrintKi() { return StringifyInt(Get() / 1024); }
 std::string Counter::PrintM() { return StringifyInt(Get() / (1000 * 1000)); }
 std::string Counter::PrintMi() { return StringifyInt(Get() / (1024 * 1024)); }
 std::string Counter::PrintRatio(Counter divider) {
-  double enumerator_value = Get();
-  double divider_value = divider.Get();
+  const double enumerator_value = Get();
+  const double divider_value = divider.Get();
   return StringifyDouble(enumerator_value / divider_value);
 }
 
@@ -47,10 +47,11 @@ std::string Counter::PrintRatio(Counter divider) {
 Statistics *Statistics::Fork() {
   Statistics *child = new Statistics();
 
-  MutexLockGuard lock_guard(lock_);
+  const MutexLockGuard lock_guard(lock_);
   for (map<string, CounterInfo *>::iterator i = counters_.begin(),
-       iEnd = counters_.end(); i != iEnd; ++i)
-  {
+                                            iEnd = counters_.end();
+       i != iEnd;
+       ++i) {
     atomic_inc32(&i->second->refcnt);
   }
   child->counters_ = counters_;
@@ -60,8 +61,8 @@ Statistics *Statistics::Fork() {
 
 
 Counter *Statistics::Lookup(const std::string &name) const {
-  MutexLockGuard lock_guard(lock_);
-  map<string, CounterInfo *>::const_iterator i = counters_.find(name);
+  const MutexLockGuard lock_guard(lock_);
+  const map<string, CounterInfo *>::const_iterator i = counters_.find(name);
   if (i != counters_.end())
     return &i->second->counter;
   return NULL;
@@ -69,8 +70,8 @@ Counter *Statistics::Lookup(const std::string &name) const {
 
 
 string Statistics::LookupDesc(const std::string &name) {
-  MutexLockGuard lock_guard(lock_);
-  map<string, CounterInfo *>::const_iterator i = counters_.find(name);
+  const MutexLockGuard lock_guard(lock_);
+  const map<string, CounterInfo *>::const_iterator i = counters_.find(name);
   if (i != counters_.end())
     return i->second->desc;
   return "";
@@ -81,12 +82,13 @@ string Statistics::PrintList(const PrintOptions print_options) {
   if (print_options == kPrintHeader)
     result += "Name|Value|Description\n";
 
-  MutexLockGuard lock_guard(lock_);
+  const MutexLockGuard lock_guard(lock_);
   for (map<string, CounterInfo *>::const_iterator i = counters_.begin(),
-       iEnd = counters_.end(); i != iEnd; ++i)
-  {
-    result += i->first + "|" + i->second->counter.ToString() +
-              "|" + i->second->desc + "\n";
+                                                  iEnd = counters_.end();
+       i != iEnd;
+       ++i) {
+    result += i->first + "|" + i->second->counter.ToString() + "|"
+              + i->second->desc + "\n";
   }
   return result;
 }
@@ -104,7 +106,7 @@ string Statistics::PrintList(const PrintOptions print_options) {
  * }
  */
 string Statistics::PrintJSON() {
-  MutexLockGuard lock_guard(lock_);
+  const MutexLockGuard lock_guard(lock_);
 
   JsonStringGenerator json_statistics;
 
@@ -113,13 +115,14 @@ string Statistics::PrintJSON() {
   std::string last_namespace = "";
   for (map<string, CounterInfo *>::const_iterator i = counters_.begin(),
                                                   iEnd = counters_.end();
-       i != iEnd; ++i) {
+       i != iEnd;
+       ++i) {
     std::vector<std::string> tokens = SplitString(i->first, '.');
 
     if (tokens[0] != last_namespace) {
       if (last_namespace != "") {
-        json_statistics.AddJsonObject(last_namespace,
-                                    json_statistics_namespace.GenerateString());
+        json_statistics.AddJsonObject(
+            last_namespace, json_statistics_namespace.GenerateString());
       }
       json_statistics_namespace.Clear();
     }
@@ -130,7 +133,7 @@ string Statistics::PrintJSON() {
   }
   if (last_namespace != "") {
     json_statistics.AddJsonObject(last_namespace,
-                                json_statistics_namespace.GenerateString());
+                                  json_statistics_namespace.GenerateString());
   }
 
   return json_statistics.GenerateString();
@@ -139,26 +142,26 @@ string Statistics::PrintJSON() {
 /**
  * Snapshot current state of the counters.
  * Elements will either be updated or inserted into the map.
- * 
+ *
  * Note: This function does NOT clear previous elements part of the map.
- * 
+ *
  * Returns map of the updated counters and the timestamp of the snapshot.
-*/
-void Statistics::SnapshotCounters(
-                        std::map<std::string, int64_t> *counters,
-                        uint64_t *timestamp_ns) {
-  MutexLockGuard lock_guard(lock_);
+ */
+void Statistics::SnapshotCounters(std::map<std::string, int64_t> *counters,
+                                  uint64_t *timestamp_ns) {
+  const MutexLockGuard lock_guard(lock_);
   *timestamp_ns = platform_realtime_ns();
   for (map<string, CounterInfo *>::const_iterator i = counters_.begin(),
-       iEnd = counters_.end(); i != iEnd; ++i)
-  {
+                                                  iEnd = counters_.end();
+       i != iEnd;
+       ++i) {
     // modify or insert
     (*counters)[i->first] = (*i->second).counter.Get();
   }
 }
 
 Counter *Statistics::Register(const string &name, const string &desc) {
-  MutexLockGuard lock_guard(lock_);
+  const MutexLockGuard lock_guard(lock_);
   assert(counters_.find(name) == counters_.end());
   CounterInfo *counter_info = new CounterInfo(desc);
   counters_[name] = counter_info;
@@ -167,18 +170,18 @@ Counter *Statistics::Register(const string &name, const string &desc) {
 
 
 Statistics::Statistics() {
-  lock_ =
-    reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
-  int retval = pthread_mutex_init(lock_, NULL);
+  lock_ = reinterpret_cast<pthread_mutex_t *>(smalloc(sizeof(pthread_mutex_t)));
+  const int retval = pthread_mutex_init(lock_, NULL);
   assert(retval == 0);
 }
 
 
 Statistics::~Statistics() {
   for (map<string, CounterInfo *>::iterator i = counters_.begin(),
-       iEnd = counters_.end(); i != iEnd; ++i)
-  {
-    int32_t old_value = atomic_xadd32(&i->second->refcnt, -1);
+                                            iEnd = counters_.end();
+       i != iEnd;
+       ++i) {
+    const int32_t old_value = atomic_xadd32(&i->second->refcnt, -1);
     if (old_value == 1)
       delete i->second;
   }
@@ -194,12 +197,9 @@ Statistics::~Statistics() {
  * If necessary, capacity_s is extended to be a multiple of resolution_s
  */
 Recorder::Recorder(uint32_t resolution_s, uint32_t capacity_s)
-  : last_timestamp_(0)
-  , capacity_s_(capacity_s)
-  , resolution_s_(resolution_s)
-{
+    : last_timestamp_(0), capacity_s_(capacity_s), resolution_s_(resolution_s) {
   assert((resolution_s > 0) && (capacity_s > resolution_s));
-  bool has_remainder = (capacity_s_ % resolution_s_) != 0;
+  const bool has_remainder = (capacity_s_ % resolution_s_) != 0;
   if (has_remainder) {
     capacity_s_ += resolution_s_ - (capacity_s_ % resolution_s_);
   }
@@ -210,14 +210,12 @@ Recorder::Recorder(uint32_t resolution_s, uint32_t capacity_s)
 }
 
 
-void Recorder::Tick() {
-  TickAt(platform_monotonic_time());
-}
+void Recorder::Tick() { TickAt(platform_monotonic_time()); }
 
 
 void Recorder::TickAt(uint64_t timestamp) {
-  uint64_t bin_abs = timestamp / resolution_s_;
-  uint64_t last_bin_abs = last_timestamp_ / resolution_s_;
+  const uint64_t bin_abs = timestamp / resolution_s_;
+  const uint64_t last_bin_abs = last_timestamp_ / resolution_s_;
 
   // timestamp in the past: don't update last_timestamp_
   if (bin_abs < last_bin_abs) {
@@ -232,7 +230,8 @@ void Recorder::TickAt(uint64_t timestamp) {
   } else {
     // When clearing bins between last_timestamp_ and now, avoid cycling the
     // ring buffer multiple times.
-    unsigned max_bins_clear = std::min(bin_abs, last_bin_abs + no_bins_ + 1);
+    const unsigned max_bins_clear = std::min(bin_abs,
+                                             last_bin_abs + no_bins_ + 1);
     for (uint64_t i = last_bin_abs + 1; i < max_bins_clear; ++i)
       bins_[i % no_bins_] = 0;
     bins_[bin_abs % no_bins_] = 1;
@@ -243,15 +242,15 @@ void Recorder::TickAt(uint64_t timestamp) {
 
 
 uint64_t Recorder::GetNoTicks(uint32_t retrospect_s) const {
-  uint64_t now = platform_monotonic_time();
+  const uint64_t now = platform_monotonic_time();
   if (retrospect_s > now)
     retrospect_s = now;
 
-  uint64_t last_bin_abs = last_timestamp_ / resolution_s_;
-  uint64_t past_bin_abs = (now - retrospect_s) / resolution_s_;
-  int64_t min_bin_abs =
-    std::max(past_bin_abs,
-             (last_bin_abs < no_bins_) ? 0 : (last_bin_abs - (no_bins_ - 1)));
+  const uint64_t last_bin_abs = last_timestamp_ / resolution_s_;
+  const uint64_t past_bin_abs = (now - retrospect_s) / resolution_s_;
+  const int64_t min_bin_abs = std::max(
+      past_bin_abs,
+      (last_bin_abs < no_bins_) ? 0 : (last_bin_abs - (no_bins_ - 1)));
   uint64_t result = 0;
   for (int64_t i = last_bin_abs; i >= min_bin_abs; --i) {
     result += bins_[i % no_bins_];
@@ -270,11 +269,9 @@ void MultiRecorder::AddRecorder(uint32_t resolution_s, uint32_t capacity_s) {
 
 
 uint64_t MultiRecorder::GetNoTicks(uint32_t retrospect_s) const {
-  unsigned N = recorders_.size();
+  const unsigned N = recorders_.size();
   for (unsigned i = 0; i < N; ++i) {
-    if ( (recorders_[i].capacity_s() >= retrospect_s) ||
-         (i == (N - 1)) )
-    {
+    if ((recorders_[i].capacity_s() >= retrospect_s) || (i == (N - 1))) {
       return recorders_[i].GetNoTicks(retrospect_s);
     }
   }
@@ -283,7 +280,7 @@ uint64_t MultiRecorder::GetNoTicks(uint32_t retrospect_s) const {
 
 
 void MultiRecorder::Tick() {
-  uint64_t now = platform_monotonic_time();
+  const uint64_t now = platform_monotonic_time();
   for (unsigned i = 0; i < recorders_.size(); ++i)
     recorders_[i].TickAt(now);
 }
