@@ -22,12 +22,10 @@ using namespace std;  // NOLINT
 
 namespace swissknife {
 
-catalog::Catalog *Assistant::GetCatalog(
-  const shash::Any &catalog_hash,
-  OpenMode open_mode)
-{
+catalog::Catalog *Assistant::GetCatalog(const shash::Any &catalog_hash,
+                                        OpenMode open_mode) {
   assert(shash::kSuffixCatalog == catalog_hash.suffix);
-  string local_path = CreateTempPath(tmp_dir_ + "/catalog", 0600);
+  const string local_path = CreateTempPath(tmp_dir_ + "/catalog", 0600);
   assert(!local_path.empty());
 
   if (!FetchObject(catalog_hash, local_path)) {
@@ -38,13 +36,11 @@ catalog::Catalog *Assistant::GetCatalog(
   catalog::Catalog *catalog;
   switch (open_mode) {
     case kOpenReadWrite:
-      catalog = catalog::WritableCatalog::AttachFreely(catalog_root_path,
-                                                      local_path,
-                                                      catalog_hash);
+      catalog = catalog::WritableCatalog::AttachFreely(
+          catalog_root_path, local_path, catalog_hash);
       break;
     case kOpenReadOnly:
-      catalog = catalog::Catalog::AttachFreely(catalog_root_path,
-                                               local_path,
+      catalog = catalog::Catalog::AttachFreely(catalog_root_path, local_path,
                                                catalog_hash);
       break;
     default:
@@ -60,7 +56,7 @@ history::History *Assistant::GetHistory(OpenMode open_mode) {
   const shash::Any history_hash = manifest_->history();
   history::History *history;
 
-  string local_path = CreateTempPath(tmp_dir_ + "/history", 0600);
+  const string local_path = CreateTempPath(tmp_dir_ + "/history", 0600);
   assert(!local_path.empty());
 
   if (history_hash.IsNull()) {
@@ -111,8 +107,8 @@ bool Assistant::FetchObject(const shash::Any &id, const string &local_path) {
 
   if (dl_retval != download::kFailOk) {
     LogCvmfs(kLogCvmfs, kLogStderr, "failed to download object '%s' (%d - %s)",
-             id.ToStringWithSuffix().c_str(),
-             dl_retval, download::Code2Ascii(dl_retval));
+             id.ToStringWithSuffix().c_str(), dl_retval,
+             download::Code2Ascii(dl_retval));
     return false;
   }
   return true;
