@@ -24,8 +24,6 @@ class Manifest;
 }
 
 
-
-
 namespace swissknife {
 
 class CommandCheck : public Command {
@@ -35,8 +33,8 @@ class CommandCheck : public Command {
   virtual std::string GetName() const { return "check"; }
   virtual std::string GetDescription() const {
     return "CernVM File System repository sanity checker\n"
-      "This command checks the consistency of the file catalogs of a "
-        "cvmfs repository.";
+           "This command checks the consistency of the file catalogs of a "
+           "cvmfs repository.";
   }
   virtual ParameterList GetParams() const {
     ParameterList r;
@@ -52,26 +50,26 @@ class CommandCheck : public Command {
     r.push_back(Parameter::Optional('@', "proxy url"));
     r.push_back(Parameter::Switch('c', "check availability of data chunks"));
     r.push_back(Parameter::Switch('d', "don't use hashmap to avoid duplicated"
-                                      " lookups. Note that this is a fallback"
-                                      " option that may be removed."));
+                                       " lookups. Note that this is a fallback"
+                                       " option that may be removed."));
     r.push_back(Parameter::Switch('L', "follow HTTP redirects"));
     return r;
   }
   int Main(const ArgumentList &args);
 
  protected:
-  bool InspectTree(const std::string               &path,
-                   const shash::Any                &catalog_hash,
-                   const uint64_t                   catalog_size,
-                   const bool                       is_nested_catalog,
-                   const catalog::DirectoryEntry  *transition_point,
-                   catalog::DeltaCounters         *computed_counters);
-  catalog::Catalog* FetchCatalog(const std::string  &path,
-                                 const shash::Any   &catalog_hash,
-                                 const uint64_t      catalog_size = 0);
+  bool InspectTree(const std::string &path,
+                   const shash::Any &catalog_hash,
+                   const uint64_t catalog_size,
+                   const bool is_nested_catalog,
+                   const catalog::DirectoryEntry *transition_point,
+                   catalog::DeltaCounters *computed_counters);
+  catalog::Catalog *FetchCatalog(const std::string &path,
+                                 const shash::Any &catalog_hash,
+                                 const uint64_t catalog_size = 0);
   bool FindSubtreeRootCatalog(const std::string &subtree_path,
-                              shash::Any        *root_hash,
-                              uint64_t          *root_size);
+                              shash::Any *root_hash,
+                              uint64_t *root_size);
 
   std::string DecompressPiece(const shash::Any catalog_hash);
   std::string DownloadPiece(const shash::Any catalog_hash);
@@ -84,8 +82,7 @@ class CommandCheck : public Command {
             catalog::DeltaCounters *computed_counters,
             std::set<PathString> *bind_mountpoints);
   bool Exists(const std::string &file);
-  bool CompareCounters(const catalog::Counters &a,
-                       const catalog::Counters &b);
+  bool CompareCounters(const catalog::Counters &a, const catalog::Counters &b);
   bool CompareEntries(const catalog::DirectoryEntry &a,
                       const catalog::DirectoryEntry &b,
                       const bool compare_names,
@@ -94,9 +91,9 @@ class CommandCheck : public Command {
  private:
   std::string temp_directory_;
   std::string repo_base_path_;
-  bool        check_chunks_;
-  bool        no_duplicates_map_;
-  bool        is_remote_;
+  bool check_chunks_;
+  bool no_duplicates_map_;
+  bool is_remote_;
   SmallHashDynamic<shash::Any, char> duplicates_map_;
 };
 
