@@ -6,7 +6,6 @@
 
 #include "swissknife_graft.h"
 
-
 #include <fcntl.h>
 #include <unistd.h>
 
@@ -43,7 +42,7 @@ bool swissknife::CommandGraft::ChecksumFdWithChunks(
   chunk_hash_context.buffer = alloca(chunk_hash_context.size);
   shash::Init(chunk_hash_context);
 
-  bool do_chunk = chunk_size_ > 0;
+  const bool do_chunk = chunk_size_ > 0;
   if (do_chunk) {
     if (!chunk_offsets || !chunk_checksums) {
       return false;
@@ -104,9 +103,8 @@ bool swissknife::CommandGraft::ChecksumFdWithChunks(
   }
 
   // Zero-size chunks are not allowed; except if there is only one chunk
-  if (do_chunk && (chunk_offsets->back() == *file_size) &&
-      (chunk_offsets->size() > 1))
-  {
+  if (do_chunk && (chunk_offsets->back() == *file_size)
+      && (chunk_offsets->size() > 1)) {
     chunk_offsets->pop_back();
     chunk_checksums->pop_back();
   }
@@ -128,12 +126,14 @@ bool swissknife::CommandGraft::DirCallback(const std::string &relative_path,
   if (!output_file_.size()) {
     return true;
   }
-  std::string full_output_path = output_file_ + "/" +
-                                 (relative_path.size() ? relative_path : ".") +
-                                 "/" + dir_name;
-  std::string full_input_path = input_file_ + "/" +
-                                (relative_path.size() ? relative_path : ".") +
-                                "/" + dir_name;
+  const std::string full_output_path = output_file_ + "/"
+                                       + (relative_path.size() ? relative_path
+                                                               : ".")
+                                       + "/" + dir_name;
+  const std::string full_input_path = input_file_ + "/"
+                                      + (relative_path.size() ? relative_path
+                                                              : ".")
+                                      + "/" + dir_name;
   platform_stat64 sbuf;
   if (-1 == platform_stat(full_input_path.c_str(), &sbuf)) {
     return false;
@@ -143,36 +143,38 @@ bool swissknife::CommandGraft::DirCallback(const std::string &relative_path,
 
 void swissknife::CommandGraft::FileCallback(const std::string &relative_path,
                                             const std::string &file_name) {
-  std::string full_input_path = input_file_ + "/" +
-                                (relative_path.size() ? relative_path : ".") +
-                                "/" + file_name;
+  const std::string full_input_path = input_file_ + "/"
+                                      + (relative_path.size() ? relative_path
+                                                              : ".")
+                                      + "/" + file_name;
   std::string full_output_path;
   if (output_file_.size()) {
-    full_output_path = output_file_ + "/" +
-                       (relative_path.size() ? relative_path : ".") + "/" +
-                       file_name;
+    full_output_path = output_file_ + "/"
+                       + (relative_path.size() ? relative_path : ".") + "/"
+                       + file_name;
   }
   Publish(full_input_path, full_output_path, false, false);
 }
 
 int swissknife::CommandGraft::Main(const swissknife::ArgumentList &args) {
   const std::string &input_file = *args.find('i')->second;
-  const std::string output_file =
-      (args.find('o') == args.end()) ? "" : *(args.find('o')->second);
+  const std::string output_file = (args.find('o') == args.end())
+                                      ? ""
+                                      : *(args.find('o')->second);
   verbose_ = args.find('v') != args.end();
   generate_bulk_hash_ = args.find('b') != args.end();
   hash_alg_ = (args.find('a') == args.end())
                   ? shash::kSha1
                   : shash::ParseHashAlgorithm(*args.find('a')->second);
-  compression_alg_ =
-      (args.find('Z') == args.end())
-          ? zlib::kNoCompression
-          : zlib::ParseCompressionAlgorithm(*args.find('Z')->second);
+  compression_alg_ = (args.find('Z') == args.end())
+                         ? zlib::kNoCompression
+                         : zlib::ParseCompressionAlgorithm(
+                               *args.find('Z')->second);
 
   if (args.find('c') == args.end()) {
     chunk_size_ = kDefaultChunkSize;
   } else {
-    std::string chunk_size = *args.find('c')->second;
+    const std::string chunk_size = *args.find('c')->second;
     if (!String2Uint64Parse(chunk_size, &chunk_size_)) {
       LogCvmfs(kLogCvmfs, kLogStderr, "Unable to parse chunk size: %s",
                chunk_size.c_str());
@@ -182,9 +184,11 @@ int swissknife::CommandGraft::Main(const swissknife::ArgumentList &args) {
   chunk_size_ *= 1024 * 1024;  // Convert to MB.
 
   platform_stat64 sbuf;
-  bool output_file_is_dir = output_file.size() &&
-                            (0 == platform_stat(output_file.c_str(), &sbuf)) &&
-                            S_ISDIR(sbuf.st_mode);
+  const bool output_file_is_dir = output_file.size()
+                                  && (0
+                                      == platform_stat(output_file.c_str(),
+                                                       &sbuf))
+                                  && S_ISDIR(sbuf.st_mode);
   if (output_file_is_dir && (input_file == "-")) {
     LogCvmfs(kLogCvmfs, kLogStderr, "Output file (%s): Is a directory\n",
              output_file.c_str());
@@ -192,8 +196,9 @@ int swissknife::CommandGraft::Main(const swissknife::ArgumentList &args) {
   }
 
   if (input_file != "-") {
-    bool input_file_is_dir = (0 == platform_stat(input_file.c_str(), &sbuf)) &&
-                             S_ISDIR(sbuf.st_mode);
+    const bool input_file_is_dir = (0
+                                    == platform_stat(input_file.c_str(), &sbuf))
+                                   && S_ISDIR(sbuf.st_mode);
     if (input_file_is_dir) {
       if (!output_file_is_dir && output_file.size()) {
         LogCvmfs(kLogCvmfs, kLogStderr,
@@ -230,7 +235,8 @@ int swissknife::CommandGraft::Publish(const std::string &input_file,
   } else {
     fd = open(input_file.c_str(), O_RDONLY);
     if (fd < 0) {
-      std::string errmsg = "Unable to open input file (" + input_file + ")";
+      const std::string errmsg = "Unable to open input file (" + input_file
+                                 + ")";
       perror(errmsg.c_str());
       return 1;
     }
@@ -239,10 +245,10 @@ int swissknife::CommandGraft::Publish(const std::string &input_file,
   // Get input file mode; output file will be set identically.
   platform_stat64 sbuf;
   if (-1 == platform_fstat(fd, &sbuf)) {
-    std::string errmsg = "Unable to stat input file (" + input_file + ")";
+    const std::string errmsg = "Unable to stat input file (" + input_file + ")";
     perror(errmsg.c_str());
   }
-  mode_t input_file_mode = input_file_is_stdin ? 0644 : sbuf.st_mode;
+  const mode_t input_file_mode = input_file_is_stdin ? 0644 : sbuf.st_mode;
 
   shash::Any file_hash(hash_alg_);
   uint64_t processed_size;
@@ -250,15 +256,16 @@ int swissknife::CommandGraft::Publish(const std::string &input_file,
   std::vector<shash::Any> chunk_checksums;
   zlib::Compressor *compressor = zlib::Compressor::Construct(compression_alg_);
 
-  bool retval =
-      ChecksumFdWithChunks(fd, compressor, &processed_size, &file_hash,
-                           &chunk_offsets, &chunk_checksums);
+  bool retval = ChecksumFdWithChunks(fd, compressor, &processed_size,
+                                     &file_hash, &chunk_offsets,
+                                     &chunk_checksums);
 
   if (!input_file_is_stdin) {
     close(fd);
   }
   if (!retval) {
-    std::string errmsg = "Unable to checksum input file (" + input_file + ")";
+    const std::string errmsg = "Unable to checksum input file (" + input_file
+                               + ")";
     perror(errmsg.c_str());
     return 1;
   }
@@ -276,7 +283,8 @@ int swissknife::CommandGraft::Publish(const std::string &input_file,
     }
     fd = open(graft_fname.c_str(), O_CREAT | O_TRUNC | O_WRONLY, 0644);
     if (fd < 0) {
-      std::string errmsg = "Unable to open graft file (" + graft_fname + ")";
+      const std::string errmsg = "Unable to open graft file (" + graft_fname
+                                 + ")";
       perror(errmsg.c_str());
       return 1;
     }
@@ -284,10 +292,10 @@ int swissknife::CommandGraft::Publish(const std::string &input_file,
     fd = 1;
   }
   const bool with_suffix = true;
-  std::string graft_contents =
-    "size=" + StringifyInt(processed_size) + "\n" +
-    "checksum=" + file_hash.ToString(with_suffix) + "\n" +
-    "compression=" + zlib::AlgorithmName(compression_alg_) + "\n";
+  std::string graft_contents = "size=" + StringifyInt(processed_size) + "\n"
+                               + "checksum=" + file_hash.ToString(with_suffix)
+                               + "\n" + "compression="
+                               + zlib::AlgorithmName(compression_alg_) + "\n";
   if (!chunk_offsets.empty()) {
     std::vector<std::string> chunk_off_str;
     chunk_off_str.reserve(chunk_offsets.size());
@@ -298,10 +306,10 @@ int swissknife::CommandGraft::Publish(const std::string &input_file,
       chunk_ck_str.push_back(chunk_checksums[idx].ToStringWithSuffix());
     }
     graft_contents += "chunk_offsets=" + JoinStrings(chunk_off_str, ",") + "\n";
-    graft_contents +=
-        "chunk_checksums=" + JoinStrings(chunk_ck_str, ",") + "\n";
+    graft_contents += "chunk_checksums=" + JoinStrings(chunk_ck_str, ",")
+                      + "\n";
   }
-  size_t nbytes = graft_contents.size();
+  const size_t nbytes = graft_contents.size();
   const char *buf = graft_contents.c_str();
   retval = SafeWrite(fd, buf, nbytes);
   if (!retval) {
@@ -322,10 +330,11 @@ int swissknife::CommandGraft::Publish(const std::string &input_file,
   } else {
     output_fname = output_file;
   }
-  fd =
-      open(output_fname.c_str(), O_CREAT | O_TRUNC | O_WRONLY, input_file_mode);
+  fd = open(output_fname.c_str(), O_CREAT | O_TRUNC | O_WRONLY,
+            input_file_mode);
   if (fd < 0) {
-    std::string errmsg = "Unable to open output file (" + output_file + ")";
+    const std::string errmsg = "Unable to open output file (" + output_file
+                               + ")";
     perror(errmsg.c_str());
     return 1;
   }
