@@ -16,7 +16,7 @@
 
 namespace {
 
-bool CheckParams(const swissknife::CommandLease::Parameters& p) {
+bool CheckParams(const swissknife::CommandLease::Parameters &p) {
   if (p.action != "acquire" && p.action != "drop") {
     return false;
   }
@@ -39,7 +39,7 @@ enum LeaseError {
   kLeaseCurlReqError,
 };
 
-CommandLease::~CommandLease() {}
+CommandLease::~CommandLease() { }
 
 ParameterList CommandLease::GetParams() const {
   ParameterList r;
@@ -50,7 +50,7 @@ ParameterList CommandLease::GetParams() const {
   return r;
 }
 
-int CommandLease::Main(const ArgumentList& args) {
+int CommandLease::Main(const ArgumentList &args) {
   Parameters params;
 
   params.repo_service_url = *(args.find('u')->second);
@@ -84,20 +84,18 @@ int CommandLease::Main(const ArgumentList& args) {
     if (MakeAcquireRequest(key_id, secret, params.lease_path,
                            params.repo_service_url, &buffer)) {
       std::string session_token;
-      LeaseReply rep = ParseAcquireReply(buffer, &session_token);
+      const LeaseReply rep = ParseAcquireReply(buffer, &session_token);
       switch (rep) {
-        case kLeaseReplySuccess:
-          {
-            const std::string token_file_name =
-              "/var/spool/cvmfs/" + lease_fqdn + "/session_token";
+        case kLeaseReplySuccess: {
+          const std::string token_file_name = "/var/spool/cvmfs/" + lease_fqdn
+                                              + "/session_token";
 
-            if (!SafeWriteToFile(session_token, token_file_name, 0600)) {
-              LogCvmfs(kLogCvmfs, kLogStderr, "Error opening file: %s",
-                  std::strerror(errno));
-              ret = kLeaseFileOpenError;
-            }
+          if (!SafeWriteToFile(session_token, token_file_name, 0600)) {
+            LogCvmfs(kLogCvmfs, kLogStderr, "Error opening file: %s",
+                     std::strerror(errno));
+            ret = kLeaseFileOpenError;
           }
-          break;
+        } break;
         case kLeaseReplyBusy:
           return kLeaseBusy;
           break;
@@ -111,9 +109,9 @@ int CommandLease::Main(const ArgumentList& args) {
   } else if (params.action == "drop") {
     // Try to read session token from repository scratch directory
     std::string session_token;
-    std::string token_file_name =
-        "/var/spool/cvmfs/" + lease_fqdn + "/session_token";
-    FILE* token_file = std::fopen(token_file_name.c_str(), "r");
+    const std::string token_file_name = "/var/spool/cvmfs/" + lease_fqdn
+                                        + "/session_token";
+    FILE *token_file = std::fopen(token_file_name.c_str(), "r");
     if (token_file) {
       GetLineFile(token_file, &session_token);
       LogCvmfs(kLogCvmfs, kLogDebug, "Read session token from file: %s",
