@@ -2,15 +2,11 @@
  * This file is part of the CernVM File System.
  */
 
-#include <string>
-
-
-
 #include <cassert>
+#include <string>
 
 #include "statistics_database.h"
 #include "swissknife.h"
-
 #include "swissknife_check.h"
 #include "swissknife_filestats.h"
 #include "swissknife_gc.h"
@@ -18,6 +14,7 @@
 #include "swissknife_history.h"
 #include "swissknife_info.h"
 #include "swissknife_ingest.h"
+#include "swissknife_ingestsql.h"
 #include "swissknife_lease.h"
 #include "swissknife_letter.h"
 #include "swissknife_list_reflog.h"
@@ -41,19 +38,16 @@ Commands command_list;
 
 void Usage() {
   LogCvmfs(kLogCvmfs, kLogStdout,
-    "CernVM-FS repository storage management commands\n"
-    "Version %s\n"
-    "Usage (normally called from cvmfs_server):\n"
-    "  cvmfs_swissknife <command> [options]\n",
-    CVMFS_VERSION);
+           "CernVM-FS repository storage management commands\n"
+           "Usage (normally called from cvmfs_server):\n"
+           "  cvmfs_swissknife <command> [options]\n");
 
   for (unsigned i = 0; i < command_list.size(); ++i) {
-    LogCvmfs(kLogCvmfs, kLogStdout | kLogNoLinebreak, "\n"
+    LogCvmfs(kLogCvmfs, kLogStdout | kLogNoLinebreak,
+             "\n"
              "Command %s\n"
-             "--------", command_list[i]->GetName().c_str());
-    for (unsigned j = 0; j < command_list[i]->GetName().length(); ++j) {
-      LogCvmfs(kLogCvmfs, kLogStdout | kLogNoLinebreak, "-");
-    }
+             "--",
+             command_list[i]->GetName().c_str());
     LogCvmfs(kLogCvmfs, kLogStdout | kLogNoLinebreak, "\n");
     LogCvmfs(kLogCvmfs, kLogStdout, "%s",
              command_list[i]->GetDescription().c_str());
@@ -105,6 +99,7 @@ int main(int argc, char **argv) {
   command_list.push_back(new swissknife::CommandReconstructReflog());
   command_list.push_back(new swissknife::CommandLease());
   command_list.push_back(new swissknife::Ingest());
+  command_list.push_back(new swissknife::IngestSQL());
   command_list.push_back(new swissknife::CommandNotify());
   command_list.push_back(new swissknife::CommandFileStats());
 
@@ -166,9 +161,8 @@ int main(int argc, char **argv) {
     }
     if (c == swissknife::Command::kGenericParam) {
       valid_option = true;
-      vector<string> flags = SplitString(optarg,
-                                         swissknife::
-                                         Command::kGenericParamSeparator);
+      vector<string> flags = SplitString(
+          optarg, swissknife::Command::kGenericParamSeparator);
       for (unsigned i = 0; i < flags.size(); ++i) {
         if (flags[i] == "stats") {
           display_statistics = true;
@@ -191,19 +185,20 @@ int main(int argc, char **argv) {
   }
 
   // run the command
-  string start_time = GetGMTimestamp();
+  const string start_time = GetGMTimestamp();
   const int retval = command->Main(args);
-  string finish_time = GetGMTimestamp();
+  const string finish_time = GetGMTimestamp();
 
   if (display_statistics) {
     LogCvmfs(kLogCvmfs, kLogStdout, "Command statistics");
     LogCvmfs(kLogCvmfs, kLogStdout, "%s",
              command->statistics()
-             ->PrintList(perf::Statistics::kPrintHeader).c_str());
+                 ->PrintList(perf::Statistics::kPrintHeader)
+                 .c_str());
   }
 
   // delete the command list
-        Commands::const_iterator i    = command_list.begin();
+  Commands::const_iterator i = command_list.begin();
   const Commands::const_iterator iend = command_list.end();
   for (; i != iend; ++i) {
     delete *i;
