@@ -9,7 +9,7 @@
 
 namespace {
 
-bool ValidateArgs(const swissknife::ArgumentList& args) {
+bool ValidateArgs(const swissknife::ArgumentList &args) {
   const bool publish = args.count('p') > 0;
   const bool subscribe = args.count('s') > 0;
 
@@ -37,7 +37,7 @@ bool ValidateArgs(const swissknife::ArgumentList& args) {
   return true;
 }
 
-uint64_t GetMinRevision(const swissknife::ArgumentList& args) {
+uint64_t GetMinRevision(const swissknife::ArgumentList &args) {
   if (args.count('m') > 0) {
     return std::atoi(args.find('m')->second->c_str());
   } else {
@@ -49,7 +49,7 @@ uint64_t GetMinRevision(const swissknife::ArgumentList& args) {
 
 namespace swissknife {
 
-CommandNotify::~CommandNotify() {}
+CommandNotify::~CommandNotify() { }
 
 ParameterList CommandNotify::GetParams() const {
   ParameterList l;
@@ -66,21 +66,21 @@ ParameterList CommandNotify::GetParams() const {
   return l;
 }
 
-int CommandNotify::Main(const ArgumentList& args) {
+int CommandNotify::Main(const ArgumentList &args) {
   if (!ValidateArgs(args)) {
     return 1;
   }
 
   int ret = 0;
-  bool verbose = args.count('v') > 0;
-  std::string server_url = *args.find('u')->second;
-  bool publish = args.count('p') > 0;
+  const bool verbose = args.count('v') > 0;
+  const std::string server_url = *args.find('u')->second;
+  const bool publish = args.count('p') > 0;
   if (publish) {
-    std::string repository_url = *args.find('r')->second;
+    const std::string repository_url = *args.find('r')->second;
     ret = notify::DoPublish(server_url, repository_url, verbose);
   } else {  // subscribe
-    std::string topic = *args.find('t')->second;
-    bool continuous = args.count('c') > 0;
+    const std::string topic = *args.find('t')->second;
+    const bool continuous = args.count('c') > 0;
     const uint64_t revision = GetMinRevision(args);
     ret = notify::DoSubscribe(server_url, topic, revision, continuous, verbose);
   }
