@@ -19,15 +19,15 @@ SyncItemTar::SyncItemTar(const std::string &relative_parent_path,
                          const std::string &filename, struct archive *archive,
                          struct archive_entry *entry,
                          Signal *read_archive_signal,
-                         const SyncUnion *union_engine,
-                         const uid_t uid, const gid_t gid)
-    : SyncItem(relative_parent_path, filename, union_engine, kItemUnknown),
-      archive_(archive),
-      archive_entry_(entry),
-      obtained_tar_stat_(false),
-      read_archive_signal_(read_archive_signal),
-      uid_(uid),
-      gid_(gid) {
+                         const SyncUnion *union_engine, const uid_t uid,
+                         const gid_t gid)
+    : SyncItem(relative_parent_path, filename, union_engine, kItemUnknown)
+    , archive_(archive)
+    , archive_entry_(entry)
+    , obtained_tar_stat_(false)
+    , read_archive_signal_(read_archive_signal)
+    , uid_(uid)
+    , gid_(gid) {
   GetStatFromTar();
 }
 
@@ -36,18 +36,19 @@ SyncItemTar::SyncItemTar(const std::string &relative_parent_path,
                          struct archive_entry *entry,
                          Signal *read_archive_signal,
                          const SyncUnion *union_engine)
-    : SyncItem(relative_parent_path, filename, union_engine, kItemUnknown),
-      archive_(archive),
-      archive_entry_(entry),
-      obtained_tar_stat_(false),
-      read_archive_signal_(read_archive_signal),
-      uid_(-1u),
-      gid_(-1u) {
+    : SyncItem(relative_parent_path, filename, union_engine, kItemUnknown)
+    , archive_(archive)
+    , archive_entry_(entry)
+    , obtained_tar_stat_(false)
+    , read_archive_signal_(read_archive_signal)
+    , uid_(-1u)
+    , gid_(-1u) {
   GetStatFromTar();
 }
 
 void SyncItemTar::StatScratch(const bool refresh) const {
-  if (scratch_stat_.obtained && !refresh) return;
+  if (scratch_stat_.obtained && !refresh)
+    return;
   scratch_stat_.stat = GetStatFromTar();
   scratch_stat_.error_code = 0;
   scratch_stat_.obtained = true;
@@ -99,7 +100,8 @@ bool SyncItemTar::IsType(const SyncItemType expected_type) const {
 
 platform_stat64 SyncItemTar::GetStatFromTar() const {
   assert(archive_entry_);
-  if (obtained_tar_stat_) return tar_stat_;
+  if (obtained_tar_stat_)
+    return tar_stat_;
 
   const struct stat *entry_stat = archive_entry_stat(archive_entry_);
   assert(NULL != entry_stat);
@@ -137,8 +139,7 @@ platform_stat64 SyncItemTar::GetStatFromTar() const {
 }
 
 catalog::DirectoryEntryBase SyncItemTar::CreateBasicCatalogDirent(
-  bool enable_mtime_ns) const
-{
+    bool enable_mtime_ns) const {
   assert(obtained_tar_stat_);
 
   catalog::DirectoryEntryBase dirent;
@@ -163,7 +164,7 @@ catalog::DirectoryEntryBase SyncItemTar::CreateBasicCatalogDirent(
   dirent.name_.Assign(this->filename().data(), this->filename().length());
 
   if (this->IsSymlink()) {
-    std::string symlink(archive_entry_symlink(archive_entry_));
+    const std::string symlink(archive_entry_symlink(archive_entry_));
     dirent.symlink_.Assign(symlink.c_str(), symlink.length());
   }
 
@@ -173,15 +174,15 @@ catalog::DirectoryEntryBase SyncItemTar::CreateBasicCatalogDirent(
 
   if (enable_mtime_ns) {
 #ifdef __APPLE__
-    dirent.mtime_ns_ =
-      static_cast<int32_t>(this->tar_stat_.st_mtimespec.tv_nsec);
+    dirent.mtime_ns_ = static_cast<int32_t>(
+        this->tar_stat_.st_mtimespec.tv_nsec);
 #else
     dirent.mtime_ns_ = static_cast<int32_t>(this->tar_stat_.st_mtim.tv_nsec);
 #endif
   }
 
-  assert(dirent.IsRegular() || dirent.IsDirectory() || dirent.IsLink() ||
-         dirent.IsSpecial());
+  assert(dirent.IsRegular() || dirent.IsDirectory() || dirent.IsLink()
+         || dirent.IsSpecial());
 
   return dirent;
 }
