@@ -5,6 +5,7 @@
 #ifndef CVMFS_UTIL_SHARED_PTR_H_
 #define CVMFS_UTIL_SHARED_PTR_H_
 
+#include <cstdint>
 #include <cstdlib>
 
 #include "util/atomic.h"
@@ -13,7 +14,7 @@
 namespace CVMFS_NAMESPACE_GUARD {
 #endif  // CVMFS_NAMESPACE_GUARD
 
-template <typename T>
+template<typename T>
 class SharedPtr {
  public:
   typedef T element_type;
@@ -23,9 +24,9 @@ class SharedPtr {
     count_ = NULL;
   }
 
-  template <class Y>
-  explicit SharedPtr(Y* p) {
-    value_ = static_cast<element_type*>(p);
+  template<class Y>
+  explicit SharedPtr(Y *p) {
+    value_ = static_cast<element_type *>(p);
     count_ = new atomic_int64;
     atomic_write64(count_, 1);
   }
@@ -40,22 +41,22 @@ class SharedPtr {
     }
   }
 
-  SharedPtr(SharedPtr const& r)
+  SharedPtr(SharedPtr const &r)
       : value_(r.value_), count_(r.count_) {  // never throws
     if (count_) {
       atomic_inc64(count_);
     }
   }
 
-  template <class Y>
-  explicit SharedPtr(SharedPtr<Y> const& r)
+  template<class Y>
+  explicit SharedPtr(SharedPtr<Y> const &r)
       : value_(r.value_), count_(r.count_) {  // never throws
     if (count_) {
       atomic_inc64(count_);
     }
   }
 
-  SharedPtr& operator=(SharedPtr const& r) {  // never throws
+  SharedPtr &operator=(SharedPtr const &r) {  // never throws
     if (this == &r)
       return *this;
 
@@ -68,8 +69,8 @@ class SharedPtr {
     return *this;
   }
 
-  template <class Y>
-  SharedPtr& operator=(SharedPtr<Y> const& r) {  // never throws
+  template<class Y>
+  SharedPtr &operator=(SharedPtr<Y> const &r) {  // never throws
     Reset();
     value_ = r.Get();
     count_ = r.GetCountPtr();
@@ -91,29 +92,27 @@ class SharedPtr {
     }
   }
 
-  template <class Y>
-  void Reset(Y* p) {
+  template<class Y>
+  void Reset(Y *p) {
     Reset();
-    value_ = static_cast<element_type*>(p);
+    value_ = static_cast<element_type *>(p);
     count_ = new atomic_int64;
     atomic_write64(count_, 1);
   }
 
-  T& operator*() const {  // never throws
+  T &operator*() const {  // never throws
     return *value_;
   }
 
-  T* operator->() const {  // never throws
+  T *operator->() const {  // never throws
     return value_;
   }
 
-  element_type* Get() const {  // never throws
+  element_type *Get() const {  // never throws
     return value_;
   }
 
-  atomic_int64* GetCountPtr() const {
-    return count_;
-  }
+  atomic_int64 *GetCountPtr() const { return count_; }
 
   bool Unique() const {  // never throws
     return count_ && (atomic_read64(count_) == 1);
@@ -124,51 +123,51 @@ class SharedPtr {
   }
 
  private:
-  element_type* value_;
-  atomic_int64* count_;
+  element_type *value_;
+  atomic_int64 *count_;
 };
 
-template <class T, class U>
-bool operator==(SharedPtr<T> const& a,
-                SharedPtr<U> const& b) {  // never throws
+template<class T, class U>
+bool operator==(SharedPtr<T> const &a,
+                SharedPtr<U> const &b) {  // never throws
   return a.value_ == b.value_;
 }
 
-template <class T, class U>
-bool operator!=(SharedPtr<T> const& a,
-                SharedPtr<U> const& b) {  // never throws
+template<class T, class U>
+bool operator!=(SharedPtr<T> const &a,
+                SharedPtr<U> const &b) {  // never throws
   return a.value_ != b.value_;
 }
 
-template <class T, class U>
-bool operator<(SharedPtr<T> const& a, SharedPtr<U> const& b) {  // never throws
+template<class T, class U>
+bool operator<(SharedPtr<T> const &a, SharedPtr<U> const &b) {  // never throws
   return a.value_ < b.value_;
 }
 
-template <class T>
-typename SharedPtr<T>::element_type* GetPointer(
-    SharedPtr<T> const& p) {  // never throws
+template<class T>
+typename SharedPtr<T>::element_type *GetPointer(
+    SharedPtr<T> const &p) {  // never throws
   return p.value_;
 }
 
-template <class T, class U>
-SharedPtr<T> StaticPointerCast(SharedPtr<U> const& r) {  // never throws
-  return SharedPtr<T>(static_cast<T*>(r.value_));
+template<class T, class U>
+SharedPtr<T> StaticPointerCast(SharedPtr<U> const &r) {  // never throws
+  return SharedPtr<T>(static_cast<T *>(r.value_));
 }
 
-template <class T, class U>
-SharedPtr<T> ConstPointerCast(SharedPtr<U> const& r) {  // never throws
-  return SharedPtr<T>(const_cast<T*>(r.value_));
+template<class T, class U>
+SharedPtr<T> ConstPointerCast(SharedPtr<U> const &r) {  // never throws
+  return SharedPtr<T>(const_cast<T *>(r.value_));
 }
 
-template <class T, class U>
-SharedPtr<T> DynamicPointerCast(SharedPtr<U> const& r) {  // never throws
-  return SharedPtr<T>(dynamic_cast<T*>(r.value_));
+template<class T, class U>
+SharedPtr<T> DynamicPointerCast(SharedPtr<U> const &r) {  // never throws
+  return SharedPtr<T>(dynamic_cast<T *>(r.value_));
 }
 
-template <class T, class U>
-SharedPtr<T> ReinterpretPointerCast(SharedPtr<U> const& r) {  // never throws
-  return SharedPtr<T>(reinterpret_cast<T*>(r.value_));
+template<class T, class U>
+SharedPtr<T> ReinterpretPointerCast(SharedPtr<U> const &r) {  // never throws
+  return SharedPtr<T>(reinterpret_cast<T *>(r.value_));
 }
 
 #ifdef CVMFS_NAMESPACE_GUARD
