@@ -18,7 +18,10 @@ def open_geodb(dbname):
         import maxminddb
     return maxminddb.open_database(dbname)
 
-gidb="/var/lib/cvmfs-server/geo/GeoLite2-City.mmdb"
+gidbpath1="/var/lib/cvmfs-server/geo/iplocation.mmdb"
+gidbpath2="/var/lib/cvmfs-server/geo/GeoLite2-City.mmdb"
+oldgidb=""
+gidb=""
 gireader=None
 oldgireader=None
 gichecktime=0
@@ -57,12 +60,23 @@ def lookup_geoinfo(now, addr):
                     #  acquire the lock for every lookup.
                     oldgireader.close()
                     oldgireader = None
-                    print('cvmfs_geo: closed old ' + gidb)
+                    print('cvmfs_geo: closed old ' + oldgidb)
                 gichecktime = now
-                modtime = os.stat(gidb).st_mtime
+                try:
+                    gidb = gidbpath1
+                    statb = os.stat(gidb)
+                except FileNotFoundError:
+                    try:
+                        gidb = gidbpath2
+                        statb = os.stat(gidb)
+                    except FileNotFoundError as e:
+                        e.filename = gidbpath1 + ' or ' + gidbpath2
+                        raise e
+                modtime = statb.st_mtime
                 if modtime != gimodtime:
                     # database was modified, reopen it
                     oldgireader = gireader
+                    oldgidb = gidb
                     gireader = open_geodb(gidb)
                     gimodtime = modtime
                     print('cvmfs_geo: opened ' + gidb)
@@ -124,27 +138,34 @@ def addr_geoinfo(now, addr):
 
     return response['location']
 
-# Look up geo info by name.  Try IPv4 first since that DB is
+# Look up geo info by name (dns or ip address).  Try IPv4 first since that DB is
 # better and most servers today are dual stack if they have IPv6.
 # Store results in a cache.  Wsgi is multithreaded so need to lock
 # accesses to the shared cache.
 # Return geo info record or None if none found.
-def name_geoinfo(now, name):
+def name_geoinfo(now, hostname):
     global geo_cache
-    if (len(name) > 256) or not addr_pattern.search(name):
+    if (len(hostname) > 256) or not addr_pattern.search(hostname):
         return None
 
+    # ignore short names and non-FQDNs in lookups, since they will fail anyway:
+    #TODO(vavolkl): The client currently cannot use an IPv6 address for this lookup;
+    # should be supported. Allow it here already in preparation for this
+    if not '.' in hostname and not ':' in hostname:
+        # not an fqdn or IPv4 or IPv6 address
+        return None
+        
     global namelookups
     namelock.acquire()
-    if name in geo_cache:
-        (stamp, gir) = geo_cache[name]
+    if hostname in geo_cache:
+        (stamp, gir) = geo_cache[hostname]
         if now <= stamp + geo_cache_secs:
             # still good, use it
             namelock.release()
             return gir
         # update the timestamp so only one thread needs to wait
         #  when a lookup is slow
-        geo_cache[name] = (now, gir)
+        geo_cache[hostname] = (now, gir)
     elif len(geo_cache) >= geo_cache_max_entries:
         # avoid denial of service by removing one arbitrary entry
         #   before we add one
@@ -154,7 +175,7 @@ def name_geoinfo(now, name):
 
     ai = ()
     try:
-        ai = socket.getaddrinfo(name,80,0,0,socket.IPPROTO_TCP)
+        ai = socket.getaddrinfo(hostname,80,0,0,socket.IPPROTO_TCP)
     except:
         pass
     gir = None
@@ -176,11 +197,11 @@ def name_geoinfo(now, name):
             gir = None
 
     namelock.acquire()
-    if gir == None and name in geo_cache:
+    if gir == None and hostname in geo_cache:
         # reuse expired entry
-        gir = geo_cache[name][1]
+        gir = geo_cache[hostname][1]
 
-    geo_cache[name] = (now, gir)
+    geo_cache[hostname] = (now, gir)
     namelock.release()
 
     return gir
