@@ -6,7 +6,9 @@
 #include "xattr.h"
 
 #include <alloca.h>
+// clang-format off
 #include <sys/xattr.h>
+// clang-format on
 
 #include <cassert>
 #include <cstring>
@@ -31,7 +33,7 @@ XattrList *XattrList::CreateFromFile(const std::string &path) {
   // Parse the \0 separated list of extended attribute keys
   char *list;
   ssize_t sz_list = platform_llistxattr(path.c_str(), NULL, 0);
-  if ((sz_list < 0) || (sz_list > 64*1024)) {
+  if ((sz_list < 0) || (sz_list > 64 * 1024)) {
     return NULL;
   } else if (sz_list == 0) {
     // No extended attributes
@@ -54,8 +56,8 @@ XattrList *XattrList::CreateFromFile(const std::string &path) {
   for (unsigned i = 0; i < keys.size(); ++i) {
     if (keys[i].empty())
       continue;
-    ssize_t sz_value =
-      platform_lgetxattr(path.c_str(), keys[i].c_str(), value, 256);
+    const ssize_t sz_value = platform_lgetxattr(path.c_str(), keys[i].c_str(),
+                                                value, 256);
     if (sz_value < 0)
       continue;
     result->Set(keys[i], string(value, sz_value));
@@ -64,10 +66,8 @@ XattrList *XattrList::CreateFromFile(const std::string &path) {
 }
 
 
-XattrList *XattrList::Deserialize(
-  const unsigned char *inbuf,
-  const unsigned size)
-{
+XattrList *XattrList::Deserialize(const unsigned char *inbuf,
+                                  const unsigned size) {
   if (inbuf == NULL)
     return new XattrList();
 
@@ -81,7 +81,8 @@ XattrList *XattrList::Deserialize(
   unsigned pos = sizeof(header);
   for (unsigned i = 0; i < header.num_xattrs; ++i) {
     XattrEntry entry;
-    unsigned size_preamble = sizeof(entry.len_key) + sizeof(entry.len_value);
+    unsigned size_preamble =  // NOLINT
+        sizeof(entry.len_key) + sizeof(entry.len_value);
     if (size - pos < size_preamble)
       return NULL;
     memcpy(&entry, inbuf + pos, size_preamble);
@@ -92,7 +93,7 @@ XattrList *XattrList::Deserialize(
     pos += size_preamble;
     memcpy(entry.data, inbuf + pos, entry.GetSize() - size_preamble);
     pos += entry.GetSize() - size_preamble;
-    bool retval = result->Set(entry.GetKey(), entry.GetValue());
+    const bool retval = result->Set(entry.GetKey(), entry.GetValue());
     if (!retval)
       return NULL;
   }
@@ -107,7 +108,7 @@ bool XattrList::Has(const string &key) const {
 
 bool XattrList::Get(const string &key, string *value) const {
   assert(value);
-  map<string, string>::const_iterator iter = xattrs_.find(key);
+  const map<string, string>::const_iterator iter = xattrs_.find(key);
   if (iter != xattrs_.end()) {
     *value = iter->second;
     return true;
@@ -119,8 +120,9 @@ bool XattrList::Get(const string &key, string *value) const {
 vector<string> XattrList::ListKeys() const {
   vector<string> result;
   for (map<string, string>::const_iterator i = xattrs_.begin(),
-       iEnd = xattrs_.end(); i != iEnd; ++i)
-  {
+                                           iEnd = xattrs_.end();
+       i != iEnd;
+       ++i) {
     result.push_back(i->first);
   }
   return result;
@@ -148,8 +150,9 @@ string XattrList::ListKeysPosix(const string &merge_with) const {
     }
   }
   for (map<string, string>::const_iterator i = xattrs_.begin(),
-       iEnd = xattrs_.end(); i != iEnd; ++i)
-  {
+                                           iEnd = xattrs_.end();
+       i != iEnd;
+       ++i) {
     result += i->first;
     result.push_back('\0');
   }
@@ -167,7 +170,7 @@ bool XattrList::Set(const string &key, const string &value) {
   if (value.length() > 256)
     return false;
 
-  map<string, string>::iterator iter = xattrs_.find(key);
+  const map<string, string>::iterator iter = xattrs_.find(key);
   if (iter != xattrs_.end()) {
     iter->second = value;
   } else {
@@ -180,7 +183,7 @@ bool XattrList::Set(const string &key, const string &value) {
 
 
 bool XattrList::Remove(const string &key) {
-  map<string, string>::iterator iter = xattrs_.find(key);
+  const map<string, string>::iterator iter = xattrs_.find(key);
   if (iter != xattrs_.end()) {
     xattrs_.erase(iter);
     return true;
@@ -193,11 +196,9 @@ bool XattrList::Remove(const string &key) {
  * If the list of attributes is empty, Serialize returns NULL.  Deserialize
  * can deal with NULL pointers.
  */
-void XattrList::Serialize(
-  unsigned char **outbuf,
-  unsigned *size,
-  const std::vector<std::string> *blacklist) const
-{
+void XattrList::Serialize(unsigned char **outbuf,
+                          unsigned *size,
+                          const std::vector<std::string> *blacklist) const {
   if (xattrs_.empty()) {
     *size = 0;
     *outbuf = NULL;
@@ -209,23 +210,24 @@ void XattrList::Serialize(
 
   // Determine size of the buffer (allocate space for max num of attributes)
   XattrEntry *entries = reinterpret_cast<XattrEntry *>(
-    smalloc(header.num_xattrs * sizeof(XattrEntry)));
+      smalloc(header.num_xattrs * sizeof(XattrEntry)));
   unsigned ientries = 0;
   for (map<string, string>::const_iterator it_att = xattrs_.begin(),
-       it_att_end = xattrs_.end(); it_att != it_att_end; ++it_att)
-  {
+                                           it_att_end = xattrs_.end();
+       it_att != it_att_end;
+       ++it_att) {
     // Only serialize non-blacklist items
     if (blacklist != NULL) {
       bool skip = false;
       for (unsigned i_bl = 0; i_bl < blacklist->size(); ++i_bl) {
         if (HasPrefix(it_att->first, (*blacklist)[i_bl],
-            true /* ignore_case */))
-        {
+                      true /* ignore_case */)) {
           skip = true;
           break;
         }
       }
-      if (skip) continue;
+      if (skip)
+        continue;
     }
     /*entries[ientries] =*/
     new (entries + ientries) XattrEntry(it_att->first, it_att->second);
@@ -267,8 +269,8 @@ string XattrList::XattrEntry::GetKey() const {
 
 
 uint16_t XattrList::XattrEntry::GetSize() const {
-  return sizeof(len_key) + sizeof(len_value) +
-         uint16_t(len_key) + uint16_t(len_value);
+  return sizeof(len_key) + sizeof(len_value) + uint16_t(len_key)
+         + uint16_t(len_value);
 }
 
 
@@ -280,9 +282,7 @@ string XattrList::XattrEntry::GetValue() const {
 
 
 XattrList::XattrEntry::XattrEntry(const string &key, const string &value)
-  : len_key(key.size())
-  , len_value(value.size())
-{
+    : len_key(key.size()), len_value(value.size()) {
   memcpy(data, key.data(), len_key);
-  memcpy(data+len_key, value.data(), len_value);
+  memcpy(data + len_key, value.data(), len_value);
 }
