@@ -22,7 +22,7 @@ import (
 	singularity "github.com/cvmfs/ducc/singularity"
 	temp "github.com/cvmfs/ducc/temp"
 
-	"github.com/docker/docker/api/types"
+	dockerImage "github.com/docker/docker/api/types/image"
 	"github.com/docker/docker/client"
 	log "github.com/sirupsen/logrus"
 )
@@ -49,7 +49,7 @@ func ConvertWishFlat(wish WishFriendly) error {
 		nFlat.Elapsed(tFlat).AddField("action", "end_flat_conversion").Send()
 	}()
 
-	// it may happend at the very first round that this two calls return an error, let it be
+	// it may happen at the very first round that this two calls return an error, let it be
 	if err := cvmfs.CreateCatalogIntoDir(wish.CvmfsRepo, ".chains"); err != nil {
 		l.LogE(err).Error("Error in creating catalog inside `.chains` directory")
 	}
@@ -408,7 +408,7 @@ func convertInputOutput(inputImage *Image, repo string, convertAgain, forceDownl
 	}
 	defer os.RemoveAll(tmpDir)
 
-	// this wil start to feed the above goroutine by writing into layersChanell
+	// this will start to feed the above goroutine by writing into layersChanell
 	err = inputImage.GetLayers(layersChanell, manifestChanell, stopGettingLayers, tmpDir)
 	if err != nil {
 		return err
@@ -494,11 +494,11 @@ func CreateThinImage(manifest da.Manifest, layerLocations map[string]string, inp
 	}
 
 	changes, _ := inputImage.GetChanges()
-	image := types.ImageImportSource{
+	image := dockerImage.ImportSource{
 		Source:     bytes.NewBuffer(imageTar.Bytes()),
 		SourceName: "-",
 	}
-	importOptions := types.ImageImportOptions{
+	importOptions := dockerImage.ImportOptions{
 		Tag:     outputImage.Tag,
 		Message: "",
 		Changes: changes,
@@ -534,7 +534,7 @@ func PushImageToRegistry(outputImage Image) (err error) {
 	}
 	authBytes, _ := json.Marshal(authStruct)
 	authCredential := base64.StdEncoding.EncodeToString(authBytes)
-	pushOptions := types.ImagePushOptions{
+	pushOptions := dockerImage.PushOptions{
 		RegistryAuth: authCredential,
 	}
 	dockerClient, err := client.NewClientWithOpts(client.WithVersion("1.19"))
