@@ -31,7 +31,7 @@ rm -f SnP-interface.h
 ln -s $(cat arch)/SnP-interface.h SnP-interface.h
 
 make clean
-make CVMFS_CASE_C_FLAGS="$CVMFS_BASE_C_FLAGS" ARCH=$(cat arch)
+make CVMFS_CASE_C_FLAGS="$CVMFS_BASE_C_FLAGS" ARCH=$(cat arch) -j  ${CVMFS_BUILD_EXTERNAL_NJOBS}
 strip -S libsha3.a
 
 cp -v *.h $EXTERNALS_INSTALL_LOCATION/include/
