@@ -25,6 +25,8 @@ run_unittests --gtest_shuffle \
 
 # Exclusions
 # 682-enter: missing fuse-overlayfs
+# 066-killall: unresponsive CentOS7 machine (probably buggy fsfreeze support)
+
 
 cd ${SOURCE_DIRECTORY}/test
 echo "running CernVM-FS client test cases..."
@@ -33,6 +35,7 @@ CVMFS_TEST_CLASS_NAME=ClientIntegrationTests                                  \
                               -x src/005-asetup                               \
                                  src/004-davinci                              \
                                  src/007-testjobs                             \
+                                 src/066-killall                              \
                                  src/084-premounted                           \
                                  src/094-attachmount                          \
                                  --                                           \
@@ -55,14 +58,12 @@ CVMFS_TEST_UNIONFS=overlayfs                                                  \
                                  src/686-azureblob_s3                         \
                                  src/687-import_s3                            \
                                  src/691-metalink                             \
+                                 src/692-https_azureblob_s3                   \
                                  src/702-symlink_caching                      \
-                                 src/811-commit-gateway                       \
                                  --                                           \
                                  src/5*                                       \
                                  src/6*                                       \
                                  src/7*                                       \
-                                 src/8*                                       \
-                                 src/9*                                       \
                               || retval=1
 
 
