@@ -2,7 +2,6 @@
  * This file is part of the CernVM File System.
  */
 #include <benchmark/benchmark.h>
-
 #include <inttypes.h>
 
 #include <cstdlib>
@@ -13,11 +12,9 @@
 
 class BM_Compression : public benchmark::Fixture {
  protected:
-  virtual void SetUp(const benchmark::State &st) {
-  }
+  virtual void SetUp(const benchmark::State &st) { }
 
-  virtual void TearDown(const benchmark::State &st) {
-  }
+  virtual void TearDown(const benchmark::State &st) { }
 };
 
 
@@ -32,5 +29,8 @@ BENCHMARK_DEFINE_F(BM_Compression, Zlib)(benchmark::State &st) {
   }
   st.SetItemsProcessed(st.iterations());
 }
-BENCHMARK_REGISTER_F(BM_Compression, Zlib)->Repetitions(3)->
-  Arg(100)->Arg(4096)->Arg(100*1024);
+BENCHMARK_REGISTER_F(BM_Compression, Zlib)
+    ->Repetitions(3)
+    ->Arg(100)
+    ->Arg(4096)
+    ->Arg(100 * 1024);
