@@ -19,8 +19,8 @@ namespace publish {
 
 class MockSyncMediator : public AbstractSyncMediator {
  public:
-  MockSyncMediator() : n_register(0), n_reg(0), n_lnk(0), n_dir(0) {}
-  virtual ~MockSyncMediator() {}
+  MockSyncMediator() : n_register(0), n_reg(0), n_lnk(0), n_dir(0) { }
+  virtual ~MockSyncMediator() { }
 
   virtual void RegisterUnionEngine(SyncUnion * /* engine */) { n_register++; }
 
@@ -34,18 +34,18 @@ class MockSyncMediator : public AbstractSyncMediator {
       n_lnk++;
     }
   }
-  virtual void Touch(SharedPtr<SyncItem> /* entry */) {}
-  virtual void Remove(SharedPtr<SyncItem> /* entry */) {}
-  virtual void Replace(SharedPtr<SyncItem> /* entry */) {}
-  virtual void Clone(const std::string /* from */,
-                     const std::string /* to */) {}
+  virtual void Touch(SharedPtr<SyncItem> /* entry */) { }
+  virtual void Remove(SharedPtr<SyncItem> /* entry */) { }
+  virtual void Replace(SharedPtr<SyncItem> /* entry */) { }
+  virtual void Clone(const std::string /* from */, const std::string /* to */) {
+  }
 
   virtual void AddUnmaterializedDirectory(SharedPtr<SyncItem> /* entry */) {
     n_dir++;
   }
 
-  virtual void EnterDirectory(SharedPtr<SyncItem> /* entry */) {}
-  virtual void LeaveDirectory(SharedPtr<SyncItem> /* entry */) {}
+  virtual void EnterDirectory(SharedPtr<SyncItem> /* entry */) { }
+  virtual void LeaveDirectory(SharedPtr<SyncItem> /* entry */) { }
 
   virtual bool Commit(manifest::Manifest * /* manifest */) { return true; }
 
