@@ -14,8 +14,7 @@ namespace publish {
 
 class T_Repository : public ::testing::Test {
  protected:
-  virtual void SetUp() {
-  }
+  virtual void SetUp() { }
 
  protected:
 };
