@@ -3,17 +3,15 @@
  */
 
 #include <gtest/gtest.h>
-
 #include <signal.h>
 
 #include "util/exception.h"
 #include "util/logging.h"
-
 #include "wpad.h"
 
 using namespace std;  // NOLINT
 
-class T_AssertOrLog : public ::testing::Test {};
+class T_AssertOrLog : public ::testing::Test { };
 
 #ifdef CVMFS_SUPPRESS_ASSERTS
 TEST_F(T_AssertOrLog, LogError) {
@@ -27,6 +25,7 @@ TEST_F(T_AssertOrLog, LogError) {
 TEST_F(T_AssertOrLog, Assert) {
   EXPECT_TRUE(AssertOrLog(1, kLogCvmfs, kLogDebug, ""));
   EXPECT_TRUE(AssertOrLog(2, kLogCvmfs, kLogDebug, ""));
-  EXPECT_DEATH(AssertOrLog(0, kLogCvmfs, kLogDebug, ""), "Assertion");  // NOLINT
+  EXPECT_DEATH(AssertOrLog(0, kLogCvmfs, kLogDebug, ""),
+               "Assertion");  // NOLINT
 }
 #endif
