@@ -2,8 +2,6 @@
  * This file is part of the CernVM File System.
  */
 
-#include "gtest/gtest.h"
-
 #include <unistd.h>
 
 #include <cassert>
@@ -13,6 +11,7 @@
 #include "c_http_server.h"
 #include "compression/compression.h"
 #include "crypto/hash.h"
+#include "gtest/gtest.h"
 #include "interrupt.h"
 #include "network/download.h"
 #include "network/sink.h"
@@ -36,18 +35,14 @@ namespace download {
 
 class T_Download : public FileSandbox {
  public:
-  T_Download() : FileSandbox(string(tmp_path) + "/server_dir"),
-                 download_mgr(8, perf::StatisticsTemplate("test", &statistics))
-                 {}
+  T_Download()
+      : FileSandbox(string(tmp_path) + "/server_dir")
+      , download_mgr(8, perf::StatisticsTemplate("test", &statistics)) { }
 
  protected:
-  virtual void SetUp() {
-    CreateSandbox();
-  }
+  virtual void SetUp() { CreateSandbox(); }
 
-  virtual void TearDown() {
-    RemoveSandbox();
-  }
+  virtual void TearDown() { RemoveSandbox(); }
 
   FILE *CreateTemporaryFile(std::string *path) const {
     return CreateTempFile(GetCurrentWorkingDirectory() + "/cvmfs_ut_download",
@@ -82,13 +77,9 @@ class TestSink : public cvmfs::Sink {
     return 0;
   }
 
-  virtual int Purge() {
-    return Reset();
-  }
+  virtual int Purge() { return Reset(); }
 
-  virtual bool IsValid() {
-    return fd >= 0;
-  }
+  virtual bool IsValid() { return fd >= 0; }
 
   int Flush() { return 0; }
 
@@ -125,8 +116,8 @@ TEST_F(T_Download, LocalFile) {
   string src_url = "file://" + src_path;
 
   cvmfs::FileSink filesink(fdest);
-  JobInfo info(&src_url, false /* compressed */, false /* probe hosts */,
-               NULL, &filesink);
+  JobInfo info(&src_url, false /* compressed */, false /* probe hosts */, NULL,
+               &filesink);
   download_mgr.Fetch(&info);
   EXPECT_EQ(info.error_code(), kFailOk);
   fclose(fdest);
@@ -144,8 +135,8 @@ TEST_F(T_Download, RemoteFile) {
   string src_url = "http://127.0.0.1:8082/" + GetFileName(src_path);
 
   cvmfs::FileSink filesink(fdest);
-  JobInfo info(&src_url, false /* compressed */, false /* probe hosts */,
-               NULL, &filesink);
+  JobInfo info(&src_url, false /* compressed */, false /* probe hosts */, NULL,
+               &filesink);
   download_mgr.Fetch(&info);
   EXPECT_EQ(file_server.num_processed_requests(), 1);
   EXPECT_EQ(info.error_code(), kFailOk);
@@ -154,7 +145,7 @@ TEST_F(T_Download, RemoteFile) {
 
 TEST_F(T_Download, Clone) {
   DownloadManager *download_mgr_cloned = download_mgr.Clone(
-    perf::StatisticsTemplate("x", &statistics), "cloned");
+      perf::StatisticsTemplate("x", &statistics), "cloned");
 
   string dest_path;
   FILE *fdest = CreateTemporaryFile(&dest_path);
@@ -166,8 +157,8 @@ TEST_F(T_Download, Clone) {
 
   string url = "file://" + dest_path;
   cvmfs::MemSink memsink;
-  JobInfo info(&url, false /* compressed */, false /* probe hosts */,
-                   NULL, &memsink);
+  JobInfo info(&url, false /* compressed */, false /* probe hosts */, NULL,
+               &memsink);
   download_mgr_cloned->Fetch(&info);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), 1U);
@@ -175,8 +166,8 @@ TEST_F(T_Download, Clone) {
   delete download_mgr_cloned;
 
   // Don't crash
-  DownloadManager *dm = new DownloadManager(1,
-                                    perf::StatisticsTemplate("h", &statistics));
+  DownloadManager *dm = new DownloadManager(
+      1, perf::StatisticsTemplate("h", &statistics));
   download_mgr_cloned = dm->Clone(perf::StatisticsTemplate("y", &statistics),
                                   "cloned");
   delete dm;
@@ -194,13 +185,13 @@ TEST_F(T_Download, Multiple) {
   string src_url = "file://" + src_path;
 
   DownloadManager second_mgr(8,
-    perf::StatisticsTemplate("second", &statistics));
+                             perf::StatisticsTemplate("second", &statistics));
 
   cvmfs::FileSink filesink(fdest);
-  JobInfo info(&src_url, false /* compressed */, false /* probe hosts */,
-               NULL, &filesink);
-  JobInfo info2(&src_url, false /* compressed */, false /* probe hosts */,
-                NULL, &filesink);
+  JobInfo info(&src_url, false /* compressed */, false /* probe hosts */, NULL,
+               &filesink);
+  JobInfo info2(&src_url, false /* compressed */, false /* probe hosts */, NULL,
+                &filesink);
   download_mgr.Fetch(&info);
   second_mgr.Fetch(&info2);
   EXPECT_EQ(info.error_code(), kFailOk);
@@ -223,7 +214,7 @@ TEST_F(T_Download, RemoteFile2Mem) {
   ASSERT_EQ(file_server.num_processed_requests(), 1);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 
@@ -245,7 +236,7 @@ TEST_F(T_Download, RemoteFileRedirect) {
   ASSERT_EQ(redirect_server.num_processed_requests(), 1);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 TEST_F(T_Download, RemoteFileSimpleProxy) {
@@ -266,7 +257,7 @@ TEST_F(T_Download, RemoteFileSimpleProxy) {
   ASSERT_EQ(file_server.num_processed_requests(), 1);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 TEST_F(T_Download, RemoteFileProxyRedirect) {
@@ -291,7 +282,7 @@ TEST_F(T_Download, RemoteFileProxyRedirect) {
   ASSERT_EQ(info.num_used_hosts(), 1);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 TEST_F(T_Download, LocalFile2Mem) {
@@ -305,7 +296,7 @@ TEST_F(T_Download, LocalFile2Mem) {
   download_mgr.Fetch(&info);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 TEST_F(T_Download, RemoteFileSwitchHosts) {
@@ -323,7 +314,7 @@ TEST_F(T_Download, RemoteFileSwitchHosts) {
   ASSERT_EQ(info.num_used_hosts(), 2);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 TEST_F(T_Download, CancelRequest) {
@@ -361,7 +352,7 @@ TEST_F(T_Download, RemoteFileSwitchHostsAfterRedirect) {
   ASSERT_EQ(info.num_used_hosts(), 2);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 TEST_F(T_Download, RemoteFileSwitchProxies) {
@@ -373,20 +364,20 @@ TEST_F(T_Download, RemoteFileSwitchProxies) {
 
   MockFileServer file_server(8082, sandbox_path_);
   MockProxyServer proxy_server(8083);
-  download_mgr.SetProxyChain("http://127.0.0.1:8084;http://127.0.0.1:8083",
-                             "", DownloadManager::kSetProxyRegular);
+  download_mgr.SetProxyChain("http://127.0.0.1:8084;http://127.0.0.1:8083", "",
+                             DownloadManager::kSetProxyRegular);
 
   string src_url = "http://127.0.0.1:8082/" + GetFileName(src_path);
   cvmfs::MemSink memsink;
   JobInfo info(&src_url, false /* compressed */, false /* probe hosts */, NULL,
-           &memsink);
+               &memsink);
   download_mgr.Fetch(&info);
   ASSERT_EQ(file_server.num_processed_requests(), 1);
   ASSERT_EQ(proxy_server.num_processed_requests(), 1);
   ASSERT_EQ(info.num_used_proxies(), 2);
   ASSERT_EQ(info.error_code(), kFailOk);
   ASSERT_EQ(memsink.pos(), src_content.length());
-  EXPECT_STREQ(reinterpret_cast<char*>(memsink.data()), src_content.c_str());
+  EXPECT_STREQ(reinterpret_cast<char *>(memsink.data()), src_content.c_str());
 }
 
 TEST_F(T_Download, RemoteFileEmpty) {
@@ -397,7 +388,7 @@ TEST_F(T_Download, RemoteFileEmpty) {
   string src_url = "http://127.0.0.1:8082/" + GetFileName(src_path);
   cvmfs::MemSink memsink;
   JobInfo info(&src_url, false /* compressed */, false /* probe hosts */, NULL,
-           &memsink);
+               &memsink);
   download_mgr.Fetch(&info);
   ASSERT_EQ(file_server.num_processed_requests(), 1);
   ASSERT_EQ(info.error_code(), kFailOk);
@@ -425,15 +416,15 @@ TEST_F(T_Download, LocalFile2Sink) {
   rewind(fdest);
   Prng prng;
   prng.InitLocaltime();
-  unsigned N = 16*1024;
-  unsigned size = N*sizeof(uint32_t);
+  unsigned N = 16 * 1024;
+  unsigned size = N * sizeof(uint32_t);
   uint32_t rnd_buf[N];  // 64kB
   for (unsigned i = 0; i < N; ++i)
     rnd_buf[i] = prng.Next(2147483647);
   shash::Any checksum(shash::kMd5);
   EXPECT_TRUE(
-    zlib::CompressMem2File(reinterpret_cast<const unsigned char *>(rnd_buf),
-                           size, fdest, &checksum));
+      zlib::CompressMem2File(reinterpret_cast<const unsigned char *>(rnd_buf),
+                             size, fdest, &checksum));
   fclose(fdest);
 
   TestSink test_sink2;
@@ -444,8 +435,7 @@ TEST_F(T_Download, LocalFile2Sink) {
   EXPECT_EQ(size, GetFileSize(test_sink2.path));
 
   uint32_t validation[N];
-  EXPECT_EQ(static_cast<int>(size),
-    pread(test_sink2.fd, &validation, size, 0));
+  EXPECT_EQ(static_cast<int>(size), pread(test_sink2.fd, &validation, size, 0));
   EXPECT_EQ(0, memcmp(validation, rnd_buf, size));
 }
 
@@ -477,42 +467,40 @@ TEST_F(T_Download, StripDirect) {
 
 TEST_F(T_Download, ValidateGeoReply) {
   vector<uint64_t> geo_order;
-  EXPECT_FALSE(download_mgr.ValidateGeoReply("", geo_order.size(),
-               &geo_order));
+  EXPECT_FALSE(download_mgr.ValidateGeoReply("", geo_order.size(), &geo_order));
 
   geo_order.push_back(0);
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("a", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("a", geo_order.size(), &geo_order));
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("1,1", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("1,1", geo_order.size(), &geo_order));
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("1,3", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("1,3", geo_order.size(), &geo_order));
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("2,3", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("2,3", geo_order.size(), &geo_order));
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("2", geo_order.size(), &geo_order));
-  EXPECT_TRUE(
-    download_mgr.ValidateGeoReply("1", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("2", geo_order.size(), &geo_order));
+  EXPECT_TRUE(download_mgr.ValidateGeoReply("1", geo_order.size(), &geo_order));
   EXPECT_EQ(geo_order.size(), 1U);
   EXPECT_EQ(geo_order[0], 0U);
 
   geo_order.push_back(0);
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply(",", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply(",", geo_order.size(), &geo_order));
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("2,", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("2,", geo_order.size(), &geo_order));
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("1", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("1", geo_order.size(), &geo_order));
   EXPECT_FALSE(
-    download_mgr.ValidateGeoReply("3,2,1", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("3,2,1", geo_order.size(), &geo_order));
   EXPECT_TRUE(
-    download_mgr.ValidateGeoReply("2,1", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("2,1", geo_order.size(), &geo_order));
   EXPECT_EQ(geo_order.size(), 2U);
   EXPECT_EQ(geo_order[0], 1U);
   EXPECT_EQ(geo_order[1], 0U);
 
   EXPECT_TRUE(
-    download_mgr.ValidateGeoReply("2,1\n", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("2,1\n", geo_order.size(), &geo_order));
   EXPECT_EQ(geo_order.size(), 2U);
   EXPECT_EQ(geo_order[0], 1U);
   EXPECT_EQ(geo_order[1], 0U);
@@ -520,7 +508,7 @@ TEST_F(T_Download, ValidateGeoReply) {
   geo_order.push_back(0);
   geo_order.push_back(0);
   EXPECT_TRUE(
-    download_mgr.ValidateGeoReply("4,3,1,2\n", geo_order.size(), &geo_order));
+      download_mgr.ValidateGeoReply("4,3,1,2\n", geo_order.size(), &geo_order));
   EXPECT_EQ(geo_order.size(), 4U);
   EXPECT_EQ(geo_order[0], 3U);
   EXPECT_EQ(geo_order[1], 2U);
@@ -531,20 +519,30 @@ TEST_F(T_Download, ValidateGeoReply) {
 
 TEST_F(T_Download, ParseHttpCode) {
   char digits[3];
-  digits[0] = '0';  digits[1] = '0';  digits[2] = 'a';
+  digits[0] = '0';
+  digits[1] = '0';
+  digits[2] = 'a';
   EXPECT_EQ(-1, DownloadManager::ParseHttpCode(digits));
-  digits[0] = '0';  digits[1] = '0';  digits[2] = '0';
+  digits[0] = '0';
+  digits[1] = '0';
+  digits[2] = '0';
   EXPECT_EQ(0, DownloadManager::ParseHttpCode(digits));
-  digits[0] = '0';  digits[1] = '0';  digits[2] = '1';
+  digits[0] = '0';
+  digits[1] = '0';
+  digits[2] = '1';
   EXPECT_EQ(1, DownloadManager::ParseHttpCode(digits));
-  digits[0] = '1';  digits[1] = '0';  digits[2] = '1';
+  digits[0] = '1';
+  digits[1] = '0';
+  digits[2] = '1';
   EXPECT_EQ(101, DownloadManager::ParseHttpCode(digits));
-  digits[0] = '9';  digits[1] = '9';  digits[2] = '9';
+  digits[0] = '9';
+  digits[1] = '9';
+  digits[2] = '9';
   EXPECT_EQ(999, DownloadManager::ParseHttpCode(digits));
 }
 
 TEST_F(T_Download, EscapeUrl) {
-  const std::string url = "http://ab0341.¡ÿϦ랝"; // c2a1 c3bf cfa6 eb9e9d
+  const std::string url = "http://ab0341.¡ÿϦ랝";  // c2a1 c3bf cfa6 eb9e9d
   const std::string correct = "http://ab0341.%C2%A1%C3%BF%CF%A6%EB%9E%9D";
   const std::string res = download_mgr.EscapeUrl(0, url);
 
