@@ -8,11 +8,9 @@
 
 class T_Fence : public ::testing::Test {
  protected:
-  virtual void SetUp() {
-  }
+  virtual void SetUp() { }
 
-  virtual void TearDown() {
-  }
+  virtual void TearDown() { }
 
   Fence fence_;
 };
