@@ -12,35 +12,36 @@
 
 struct RevisionFlags {
   enum T {
-    kInitialRevision   = 1,
+    kInitialRevision = 1,
     kUpdatableRevision = 2,
-    kUpdatedRevision   = 3,
-    kFailingRevision   = 4,
+    kUpdatedRevision = 3,
+    kFailingRevision = 4,
   };
 };
 
 class DummyDatabase : public sqlite::Database<DummyDatabase> {
  public:
   // not const - needs to be adaptable!
-  static float        kLatestSchema;
+  static float kLatestSchema;
   // not const - needs to be adaptable!
-  static unsigned     kLatestSchemaRevision;
-  static const float  kLatestCompatibleSchema;
+  static unsigned kLatestSchemaRevision;
+  static const float kLatestCompatibleSchema;
 
-  static bool         compacting_fails;
+  static bool compacting_fails;
 
   bool CreateEmptyDatabase() {
     ++create_empty_db_calls;
 
-  return sqlite::Sql(sqlite_db(),
-    "CREATE TABLE foobar (foo TEXT, bar TEXT, "
-    "  CONSTRAINT pk_foo PRIMARY KEY (foo))").Execute();
+    return sqlite::Sql(sqlite_db(),
+                       "CREATE TABLE foobar (foo TEXT, bar TEXT, "
+                       "  CONSTRAINT pk_foo PRIMARY KEY (foo))")
+        .Execute();
   }
 
   bool CheckSchemaCompatibility() {
     ++check_compatibility_calls;
-    return (schema_version() > kLatestCompatibleSchema - 0.1 &&
-            schema_version() < kLatestCompatibleSchema + 0.1);
+    return (schema_version() > kLatestCompatibleSchema - 0.1
+            && schema_version() < kLatestCompatibleSchema + 0.1);
   }
 
   bool LiveSchemaUpgradeIfNecessary() {
@@ -69,37 +70,34 @@ class DummyDatabase : public sqlite::Database<DummyDatabase> {
     return !compacting_fails;
   }
 
-  ~DummyDatabase() {
-    --DummyDatabase::instances;
-  }
+  ~DummyDatabase() { --DummyDatabase::instances; }
 
  protected:
   // TODO(rmeusel): C++11 - constructor inheritance
   friend class sqlite::Database<DummyDatabase>;
-  DummyDatabase(const std::string  &filename,
-                const OpenMode      open_mode) :
-    sqlite::Database<DummyDatabase>(filename, open_mode),
-    create_empty_db_calls(0),  check_compatibility_calls(0),
-    live_upgrade_calls(0), compact_calls(0)
-  {
+  DummyDatabase(const std::string &filename, const OpenMode open_mode)
+      : sqlite::Database<DummyDatabase>(filename, open_mode)
+      , create_empty_db_calls(0)
+      , check_compatibility_calls(0)
+      , live_upgrade_calls(0)
+      , compact_calls(0) {
     ++DummyDatabase::instances;
   }
 
  public:
-  static unsigned int  instances;
+  static unsigned int instances;
 
-  unsigned int         create_empty_db_calls;
-  unsigned int         check_compatibility_calls;
-  unsigned int         live_upgrade_calls;
+  unsigned int create_empty_db_calls;
+  unsigned int check_compatibility_calls;
+  unsigned int live_upgrade_calls;
   mutable unsigned int compact_calls;
 };
 
-const float    DummyDatabase::kLatestCompatibleSchema = 1.0f;
-float          DummyDatabase::kLatestSchema           = 1.0f;
-unsigned       DummyDatabase::kLatestSchemaRevision   =
-  RevisionFlags::kInitialRevision;
-unsigned int   DummyDatabase::instances               = 0;
-bool           DummyDatabase::compacting_fails        = false;
+const float DummyDatabase::kLatestCompatibleSchema = 1.0f;
+float DummyDatabase::kLatestSchema = 1.0f;
+unsigned DummyDatabase::kLatestSchemaRevision = RevisionFlags::kInitialRevision;
+unsigned int DummyDatabase::instances = 0;
+bool DummyDatabase::compacting_fails = false;
 
 
 class T_SQLite_Wrapper : public ::testing::Test {
@@ -108,10 +106,10 @@ class T_SQLite_Wrapper : public ::testing::Test {
 
  protected:
   virtual void SetUp() {
-    DummyDatabase::kLatestSchema         = 1.0f;
+    DummyDatabase::kLatestSchema = 1.0f;
     DummyDatabase::kLatestSchemaRevision = 1;
-    DummyDatabase::instances             = 0;
-    DummyDatabase::compacting_fails      = false;
+    DummyDatabase::instances = 0;
+    DummyDatabase::compacting_fails = false;
 
     const bool retval = MkdirDeep(sandbox, 0700);
     ASSERT_TRUE(retval) << "failed to create sandbox";
@@ -123,37 +121,34 @@ class T_SQLite_Wrapper : public ::testing::Test {
   }
 
   std::string GetDatabaseFilename() const {
-    const std::string path = CreateTempPath(sandbox + "/catalog",
-                                            0600);
+    const std::string path = CreateTempPath(sandbox + "/catalog", 0600);
     CheckEmpty(path);
     return path;
   }
 
  private:
-  void CheckEmpty(const std::string &str) const {
-    ASSERT_FALSE(str.empty());
-  }
+  void CheckEmpty(const std::string &str) const { ASSERT_FALSE(str.empty()); }
 };
 
 const std::string T_SQLite_Wrapper::sandbox = "./cvmfs_ut_sqlite_wrapper";
 
 
-TEST_F(T_SQLite_Wrapper, Initialize) {}
+TEST_F(T_SQLite_Wrapper, Initialize) { }
 
 
 TEST_F(T_SQLite_Wrapper, CreateEmptyDatabase) {
   DummyDatabase *db = DummyDatabase::Create(GetDatabaseFilename());
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(1u, db->create_empty_db_calls);
   EXPECT_EQ(0u, db->check_compatibility_calls);
   EXPECT_EQ(0u, db->live_upgrade_calls);
   EXPECT_EQ(0u, db->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db->schema_revision());
-  EXPECT_TRUE(db->IsEqualSchema(db->schema_version(),
-                                 DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db->IsEqualSchema(db->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db->IsEqualSchema(db->schema_version(),
-                                  DummyDatabase::kLatestSchema + 0.1));
+                                 DummyDatabase::kLatestSchema + 0.1));
   EXPECT_TRUE(db->read_write());
   delete db;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -162,17 +157,17 @@ TEST_F(T_SQLite_Wrapper, CreateEmptyDatabase) {
 
 TEST_F(T_SQLite_Wrapper, CloseDatabase) {
   DummyDatabase *db = DummyDatabase::Create(GetDatabaseFilename());
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(1u, db->create_empty_db_calls);
   EXPECT_EQ(0u, db->check_compatibility_calls);
   EXPECT_EQ(0u, db->live_upgrade_calls);
   EXPECT_EQ(0u, db->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db->schema_revision());
-  EXPECT_TRUE(db->IsEqualSchema(db->schema_version(),
-                                 DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db->IsEqualSchema(db->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db->IsEqualSchema(db->schema_version(),
-                                  DummyDatabase::kLatestSchema + 0.1));
+                                 DummyDatabase::kLatestSchema + 0.1));
   EXPECT_TRUE(db->read_write());
   delete db;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -183,7 +178,7 @@ TEST_F(T_SQLite_Wrapper, OpenDatabase) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(1u, db1->create_empty_db_calls);
   EXPECT_EQ(0u, db1->check_compatibility_calls);
@@ -191,16 +186,16 @@ TEST_F(T_SQLite_Wrapper, OpenDatabase) {
   EXPECT_EQ(0u, db1->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db1->schema_revision());
   EXPECT_EQ(dbp, db1->filename());
-  EXPECT_TRUE(db1->IsEqualSchema(db1->schema_version(),
-                                 DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db1->IsEqualSchema(db1->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db1->IsEqualSchema(db1->schema_version(),
-                                   DummyDatabase::kLatestSchema + 0.1));
+                                  DummyDatabase::kLatestSchema + 0.1));
   EXPECT_TRUE(db1->read_write());
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(0u, db2->create_empty_db_calls);
   EXPECT_EQ(1u, db2->check_compatibility_calls);
@@ -208,10 +203,10 @@ TEST_F(T_SQLite_Wrapper, OpenDatabase) {
   EXPECT_EQ(0u, db2->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db2->schema_revision());
   EXPECT_EQ(dbp, db2->filename());
-  EXPECT_TRUE(db2->IsEqualSchema(db2->schema_version(),
-                                 DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db2->IsEqualSchema(db2->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db2->IsEqualSchema(db2->schema_version(),
-                                   DummyDatabase::kLatestSchema + 0.1));
+                                  DummyDatabase::kLatestSchema + 0.1));
   EXPECT_FALSE(db2->read_write());
 
   delete db2;
@@ -223,7 +218,7 @@ TEST_F(T_SQLite_Wrapper, ReadWriteOpenDatabase) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(1u, db1->create_empty_db_calls);
   EXPECT_EQ(0u, db1->check_compatibility_calls);
@@ -231,16 +226,16 @@ TEST_F(T_SQLite_Wrapper, ReadWriteOpenDatabase) {
   EXPECT_EQ(0u, db1->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db1->schema_revision());
   EXPECT_EQ(dbp, db1->filename());
-  EXPECT_TRUE(db1->IsEqualSchema(db1->schema_version(),
-                                 DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db1->IsEqualSchema(db1->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db1->IsEqualSchema(db1->schema_version(),
-                                   DummyDatabase::kLatestSchema + 0.1));
+                                  DummyDatabase::kLatestSchema + 0.1));
   EXPECT_TRUE(db1->read_write());
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(0u, db2->create_empty_db_calls);
   EXPECT_EQ(1u, db2->check_compatibility_calls);
@@ -248,10 +243,10 @@ TEST_F(T_SQLite_Wrapper, ReadWriteOpenDatabase) {
   EXPECT_EQ(0u, db2->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db2->schema_revision());
   EXPECT_EQ(dbp, db2->filename());
-  EXPECT_TRUE(db2->IsEqualSchema(db2->schema_version(),
-                                  DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db2->IsEqualSchema(db2->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db2->IsEqualSchema(db2->schema_version(),
-                                   DummyDatabase::kLatestSchema + 0.1));
+                                  DummyDatabase::kLatestSchema + 0.1));
   EXPECT_TRUE(db2->read_write());
   delete db2;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -262,7 +257,7 @@ TEST_F(T_SQLite_Wrapper, CompactDatabase) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(1u, db1->create_empty_db_calls);
   EXPECT_EQ(0u, db1->check_compatibility_calls);
@@ -270,16 +265,16 @@ TEST_F(T_SQLite_Wrapper, CompactDatabase) {
   EXPECT_EQ(0u, db1->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db1->schema_revision());
   EXPECT_EQ(dbp, db1->filename());
-  EXPECT_TRUE(db1->IsEqualSchema(db1->schema_version(),
-                                 DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db1->IsEqualSchema(db1->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db1->IsEqualSchema(db1->schema_version(),
-                                   DummyDatabase::kLatestSchema + 0.1));
+                                  DummyDatabase::kLatestSchema + 0.1));
   EXPECT_TRUE(db1->read_write());
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_EQ(0u, db2->create_empty_db_calls);
   EXPECT_EQ(1u, db2->check_compatibility_calls);
@@ -287,10 +282,10 @@ TEST_F(T_SQLite_Wrapper, CompactDatabase) {
   EXPECT_EQ(0u, db2->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db2->schema_revision());
   EXPECT_EQ(dbp, db2->filename());
-  EXPECT_TRUE(db2->IsEqualSchema(db2->schema_version(),
-                                  DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db2->IsEqualSchema(db2->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db2->IsEqualSchema(db2->schema_version(),
-                                   DummyDatabase::kLatestSchema + 0.1));
+                                  DummyDatabase::kLatestSchema + 0.1));
 
   db2->Vacuum();
   EXPECT_EQ(1u, DummyDatabase::instances);
@@ -300,10 +295,10 @@ TEST_F(T_SQLite_Wrapper, CompactDatabase) {
   EXPECT_EQ(1u, db2->compact_calls);
   EXPECT_EQ(DummyDatabase::kLatestSchemaRevision, db2->schema_revision());
   EXPECT_EQ(dbp, db2->filename());
-  EXPECT_TRUE(db2->IsEqualSchema(db2->schema_version(),
-                                 DummyDatabase::kLatestSchema));
+  EXPECT_TRUE(
+      db2->IsEqualSchema(db2->schema_version(), DummyDatabase::kLatestSchema));
   EXPECT_FALSE(db2->IsEqualSchema(db2->schema_version(),
-                                   DummyDatabase::kLatestSchema + 0.1));
+                                  DummyDatabase::kLatestSchema + 0.1));
   EXPECT_TRUE(db2->read_write());
 
   delete db2;
@@ -315,11 +310,11 @@ TEST_F(T_SQLite_Wrapper, PropertyWithoutReopen) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
 
-  EXPECT_TRUE(db1->SetProperty("foo",   std::string("bar")));
-  EXPECT_TRUE(db1->SetProperty("file",  dbp));
-  EXPECT_TRUE(db1->SetProperty("int",   1337));
+  EXPECT_TRUE(db1->SetProperty("foo", std::string("bar")));
+  EXPECT_TRUE(db1->SetProperty("file", dbp));
+  EXPECT_TRUE(db1->SetProperty("int", 1337));
   EXPECT_TRUE(db1->SetProperty("float", 13.37));
 
   EXPECT_TRUE(db1->HasProperty("foo"));
@@ -332,11 +327,11 @@ TEST_F(T_SQLite_Wrapper, PropertyWithoutReopen) {
   EXPECT_FALSE(db1->HasProperty("integer"));
   EXPECT_FALSE(db1->HasProperty("double"));
 
-  EXPECT_EQ("bar",   db1->GetProperty<std::string>("foo"));
-  EXPECT_EQ(dbp,     db1->GetProperty<std::string>("file"));
-  EXPECT_EQ(1337,    db1->GetProperty<int>("int"));
-  EXPECT_LT(13.36,   db1->GetProperty<float>("float"));
-  EXPECT_GT(13.38,   db1->GetProperty<double>("float"));
+  EXPECT_EQ("bar", db1->GetProperty<std::string>("foo"));
+  EXPECT_EQ(dbp, db1->GetProperty<std::string>("file"));
+  EXPECT_EQ(1337, db1->GetProperty<int>("int"));
+  EXPECT_LT(13.36, db1->GetProperty<float>("float"));
+  EXPECT_GT(13.38, db1->GetProperty<double>("float"));
 
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -347,28 +342,28 @@ TEST_F(T_SQLite_Wrapper, GetDefaultPropertyWithoutReopen) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
 
-  EXPECT_TRUE(db1->SetProperty("foo",   std::string("bar")));
-  EXPECT_TRUE(db1->SetProperty("file",  dbp));
-  EXPECT_TRUE(db1->SetProperty("int",   1337));
+  EXPECT_TRUE(db1->SetProperty("foo", std::string("bar")));
+  EXPECT_TRUE(db1->SetProperty("file", dbp));
+  EXPECT_TRUE(db1->SetProperty("int", 1337));
   EXPECT_TRUE(db1->SetProperty("float", 13.37));
 
-  EXPECT_EQ("bar", db1->GetPropertyDefault<std::string>("foo",  "0"));
-  EXPECT_EQ(dbp,   db1->GetPropertyDefault<std::string>("file", "1"));
-  EXPECT_EQ(1337,  db1->GetPropertyDefault<int>("int",           2));
-  EXPECT_LT(13.36, db1->GetPropertyDefault<float>("float",       3));
-  EXPECT_GT(13.38, db1->GetPropertyDefault<double>("float",      4));
-  EXPECT_NE(42,    db1->GetPropertyDefault<int>("int",          42));
+  EXPECT_EQ("bar", db1->GetPropertyDefault<std::string>("foo", "0"));
+  EXPECT_EQ(dbp, db1->GetPropertyDefault<std::string>("file", "1"));
+  EXPECT_EQ(1337, db1->GetPropertyDefault<int>("int", 2));
+  EXPECT_LT(13.36, db1->GetPropertyDefault<float>("float", 3));
+  EXPECT_GT(13.38, db1->GetPropertyDefault<double>("float", 4));
+  EXPECT_NE(42, db1->GetPropertyDefault<int>("int", 42));
 
   EXPECT_FALSE(db1->HasProperty("moep"));
   EXPECT_FALSE(db1->HasProperty("baz"));
 
   EXPECT_EQ("tok!", db1->GetPropertyDefault<std::string>("moep", "tok!"));
-  EXPECT_EQ(1337,   db1->GetPropertyDefault<int>("moep",         1337));
-  EXPECT_LT(13.36,  db1->GetPropertyDefault<double>("moep",      13.37));
-  EXPECT_GT(13.38f, db1->GetPropertyDefault<float>("moep",       13.37f));
-  EXPECT_EQ(0,      db1->GetPropertyDefault<double>("baz",       0));
+  EXPECT_EQ(1337, db1->GetPropertyDefault<int>("moep", 1337));
+  EXPECT_LT(13.36, db1->GetPropertyDefault<double>("moep", 13.37));
+  EXPECT_GT(13.38f, db1->GetPropertyDefault<float>("moep", 13.37f));
+  EXPECT_EQ(0, db1->GetPropertyDefault<double>("baz", 0));
 
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -379,18 +374,18 @@ TEST_F(T_SQLite_Wrapper, PropertyWithReadOnlyReopen) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
 
-  EXPECT_TRUE(db1->SetProperty("foo",   std::string("bar")));
-  EXPECT_TRUE(db1->SetProperty("file",  dbp));
-  EXPECT_TRUE(db1->SetProperty("int",   1337));
+  EXPECT_TRUE(db1->SetProperty("foo", std::string("bar")));
+  EXPECT_TRUE(db1->SetProperty("file", dbp));
+  EXPECT_TRUE(db1->SetProperty("int", 1337));
   EXPECT_TRUE(db1->SetProperty("float", 13.37));
 
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
 
   EXPECT_TRUE(db2->HasProperty("foo"));
   EXPECT_TRUE(db2->HasProperty("file"));
@@ -402,11 +397,11 @@ TEST_F(T_SQLite_Wrapper, PropertyWithReadOnlyReopen) {
   EXPECT_FALSE(db2->HasProperty("integer"));
   EXPECT_FALSE(db2->HasProperty("double"));
 
-  EXPECT_EQ("bar",   db2->GetProperty<std::string>("foo"));
-  EXPECT_EQ(dbp,     db2->GetProperty<std::string>("file"));
-  EXPECT_EQ(1337,    db2->GetProperty<int>("int"));
-  EXPECT_LT(13.36,   db2->GetProperty<float>("float"));
-  EXPECT_GT(13.38,   db2->GetProperty<double>("float"));
+  EXPECT_EQ("bar", db2->GetProperty<std::string>("foo"));
+  EXPECT_EQ(dbp, db2->GetProperty<std::string>("file"));
+  EXPECT_EQ(1337, db2->GetProperty<int>("int"));
+  EXPECT_LT(13.36, db2->GetProperty<float>("float"));
+  EXPECT_GT(13.38, db2->GetProperty<double>("float"));
 
   delete db2;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -417,18 +412,18 @@ TEST_F(T_SQLite_Wrapper, PropertyWithReadWriteReopen) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
 
-  EXPECT_TRUE(db1->SetProperty("foo",   std::string("bar")));
-  EXPECT_TRUE(db1->SetProperty("file",  dbp));
-  EXPECT_TRUE(db1->SetProperty("int",   1337));
+  EXPECT_TRUE(db1->SetProperty("foo", std::string("bar")));
+  EXPECT_TRUE(db1->SetProperty("file", dbp));
+  EXPECT_TRUE(db1->SetProperty("int", 1337));
   EXPECT_TRUE(db1->SetProperty("float", 13.37));
 
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
 
   EXPECT_TRUE(db2->HasProperty("foo"));
   EXPECT_TRUE(db2->HasProperty("file"));
@@ -440,11 +435,11 @@ TEST_F(T_SQLite_Wrapper, PropertyWithReadWriteReopen) {
   EXPECT_FALSE(db2->HasProperty("integer"));
   EXPECT_FALSE(db2->HasProperty("double"));
 
-  EXPECT_EQ("bar",   db2->GetProperty<std::string>("foo"));
-  EXPECT_EQ(dbp,     db2->GetProperty<std::string>("file"));
-  EXPECT_EQ(1337,    db2->GetProperty<int>("int"));
-  EXPECT_LT(13.36,   db2->GetProperty<float>("float"));
-  EXPECT_GT(13.38,   db2->GetProperty<double>("float"));
+  EXPECT_EQ("bar", db2->GetProperty<std::string>("foo"));
+  EXPECT_EQ(dbp, db2->GetProperty<std::string>("file"));
+  EXPECT_EQ(1337, db2->GetProperty<int>("int"));
+  EXPECT_LT(13.36, db2->GetProperty<float>("float"));
+  EXPECT_GT(13.38, db2->GetProperty<double>("float"));
 
   delete db2;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -456,7 +451,7 @@ TEST_F(T_SQLite_Wrapper, IncompatibleSchema) {
 
   DummyDatabase::kLatestSchema = 2.0;
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_LT(1.9, db1->schema_version());
   EXPECT_GT(2.1, db1->schema_version());
   EXPECT_EQ(0u, db1->check_compatibility_calls);
@@ -467,7 +462,7 @@ TEST_F(T_SQLite_Wrapper, IncompatibleSchema) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_EQ(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_EQ(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   delete db2;
@@ -480,9 +475,9 @@ TEST_F(T_SQLite_Wrapper, SuccessfulSchemaUpdate) {
 
   DummyDatabase::kLatestSchemaRevision = RevisionFlags::kUpdatableRevision;
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_EQ(unsigned(RevisionFlags::kUpdatableRevision),
-             db1->schema_revision());
+            db1->schema_revision());
   EXPECT_EQ(0u, db1->check_compatibility_calls);
   EXPECT_EQ(0u, db1->live_upgrade_calls);
   DummyDatabase::kLatestSchemaRevision = RevisionFlags::kInitialRevision;
@@ -491,7 +486,7 @@ TEST_F(T_SQLite_Wrapper, SuccessfulSchemaUpdate) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_EQ(1u, db2->check_compatibility_calls);
   EXPECT_EQ(1u, db2->live_upgrade_calls);
   EXPECT_EQ(unsigned(RevisionFlags::kUpdatedRevision), db2->schema_revision());
@@ -501,7 +496,7 @@ TEST_F(T_SQLite_Wrapper, SuccessfulSchemaUpdate) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db3 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db3);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db3);
   EXPECT_EQ(1u, db3->check_compatibility_calls);
   EXPECT_EQ(0u, db3->live_upgrade_calls);
   EXPECT_EQ(unsigned(RevisionFlags::kUpdatedRevision), db3->schema_revision());
@@ -517,7 +512,7 @@ TEST_F(T_SQLite_Wrapper, FailingSchemaUpdate) {
 
   DummyDatabase::kLatestSchemaRevision = RevisionFlags::kFailingRevision;
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_EQ(unsigned(RevisionFlags::kFailingRevision), db1->schema_revision());
   EXPECT_EQ(0u, db1->check_compatibility_calls);
   EXPECT_EQ(0u, db1->live_upgrade_calls);
@@ -527,7 +522,7 @@ TEST_F(T_SQLite_Wrapper, FailingSchemaUpdate) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_EQ(1u, db2->check_compatibility_calls);
   EXPECT_EQ(0u, db2->live_upgrade_calls);
   EXPECT_EQ(unsigned(RevisionFlags::kFailingRevision), db2->schema_revision());
@@ -537,7 +532,7 @@ TEST_F(T_SQLite_Wrapper, FailingSchemaUpdate) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db3 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_EQ(static_cast<DummyDatabase*>(NULL), db3);
+  ASSERT_EQ(static_cast<DummyDatabase *>(NULL), db3);
   EXPECT_EQ(0u, DummyDatabase::instances);
 }
 
@@ -550,7 +545,7 @@ TEST_F(T_SQLite_Wrapper, DataAccessSlow) {
   const int entry_count = 50000;
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   {
     sqlite::Sql insert(db1->sqlite_db(), "INSERT INTO foobar (foo, bar) "
                                          "VALUES (:f, :b);");
@@ -566,14 +561,14 @@ TEST_F(T_SQLite_Wrapper, DataAccessSlow) {
   }
 
   EXPECT_GT(0.1, db1->GetFreePageRatio());
-  EXPECT_EQ(0u,   db1->compact_calls);
+  EXPECT_EQ(0u, db1->compact_calls);
 
   delete db1;
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   EXPECT_LT(2000000, GetFileSize(dbp));
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   {
     sqlite::Sql count(db2->sqlite_db(), "SELECT count(*) FROM foobar;");
 
@@ -593,7 +588,7 @@ TEST_F(T_SQLite_Wrapper, VacuumDatabaseSlow) {
   const int entry_count = 50000;
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   {
     sqlite::Sql insert(db1->sqlite_db(), "INSERT INTO foobar (foo, bar) "
                                          "VALUES (:f, :b);");
@@ -616,7 +611,7 @@ TEST_F(T_SQLite_Wrapper, VacuumDatabaseSlow) {
 
   EXPECT_LT(2000000, GetFileSize(dbp));
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   {
     sqlite::Sql wipe(db2->sqlite_db(), "DELETE FROM foobar;");
 
@@ -631,7 +626,7 @@ TEST_F(T_SQLite_Wrapper, VacuumDatabaseSlow) {
 
   EXPECT_LT(2000000, GetFileSize(dbp));
   DummyDatabase *db3 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db3);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db3);
   EXPECT_LT(0.9, db3->GetFreePageRatio());
   EXPECT_EQ(0u, db3->compact_calls);
 
@@ -645,7 +640,7 @@ TEST_F(T_SQLite_Wrapper, VacuumDatabaseSlow) {
   EXPECT_GT(150000, GetFileSize(dbp));
 
   DummyDatabase *db4 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db4);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db4);
   EXPECT_GT(0.1, db4->GetFreePageRatio());
   EXPECT_EQ(0u, db4->compact_calls);
 
@@ -670,7 +665,7 @@ TEST_F(T_SQLite_Wrapper, FailingCompaction) {
   const int entry_count = 50000;
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   {
     sqlite::Sql insert(db1->sqlite_db(), "INSERT INTO foobar (foo, bar) "
                                          "VALUES (:f, :b);");
@@ -694,7 +689,7 @@ TEST_F(T_SQLite_Wrapper, FailingCompaction) {
 
   EXPECT_LT(2000000, GetFileSize(dbp));
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   {
     sqlite::Sql wipe(db2->sqlite_db(), "DELETE FROM foobar;");
 
@@ -702,17 +697,17 @@ TEST_F(T_SQLite_Wrapper, FailingCompaction) {
   }
 
   EXPECT_LT(0.9, db2->GetFreePageRatio());
-  EXPECT_EQ(0u,   db2->compact_calls);
+  EXPECT_EQ(0u, db2->compact_calls);
 
   DummyDatabase::compacting_fails = true;
   EXPECT_FALSE(db2->Vacuum());
   EXPECT_LT(0.9, db2->GetFreePageRatio());
-  EXPECT_EQ(1u,   db2->compact_calls);
+  EXPECT_EQ(1u, db2->compact_calls);
 
   DummyDatabase::compacting_fails = false;
   EXPECT_TRUE(db2->Vacuum());
   EXPECT_GT(0.1, db2->GetFreePageRatio());
-  EXPECT_EQ(2u,   db2->compact_calls);
+  EXPECT_EQ(2u, db2->compact_calls);
 
   delete db2;
   EXPECT_EQ(0u, DummyDatabase::instances);
@@ -726,7 +721,7 @@ TEST_F(T_SQLite_Wrapper, TakeFileOwnership) {
   ASSERT_TRUE(FileExists(file_name1));
 
   DummyDatabase *db1 = DummyDatabase::Create(file_name1);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_FALSE(db1->OwnsFile());
   EXPECT_TRUE(FileExists(file_name1));
   delete db1;
@@ -734,9 +729,9 @@ TEST_F(T_SQLite_Wrapper, TakeFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name1));
 
-  DummyDatabase *db2 =
-    DummyDatabase::Open(file_name1, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  DummyDatabase *db2 = DummyDatabase::Open(file_name1,
+                                           DummyDatabase::kOpenReadOnly);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_FALSE(db2->OwnsFile());
   EXPECT_TRUE(FileExists(file_name1));
   delete db2;
@@ -744,9 +739,9 @@ TEST_F(T_SQLite_Wrapper, TakeFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name1));
 
-  DummyDatabase *db3 =
-    DummyDatabase::Open(file_name1, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db3);
+  DummyDatabase *db3 = DummyDatabase::Open(file_name1,
+                                           DummyDatabase::kOpenReadWrite);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db3);
   EXPECT_FALSE(db3->OwnsFile());
   EXPECT_TRUE(FileExists(file_name1));
   delete db3;
@@ -754,9 +749,9 @@ TEST_F(T_SQLite_Wrapper, TakeFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name1));
 
-  DummyDatabase *db4 =
-    DummyDatabase::Open(file_name1, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db4);
+  DummyDatabase *db4 = DummyDatabase::Open(file_name1,
+                                           DummyDatabase::kOpenReadOnly);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db4);
   EXPECT_TRUE(FileExists(file_name1));
   EXPECT_FALSE(db4->OwnsFile());
   db4->TakeFileOwnership();
@@ -770,7 +765,7 @@ TEST_F(T_SQLite_Wrapper, TakeFileOwnership) {
   const std::string file_name2 = GetDatabaseFilename();
   ASSERT_TRUE(FileExists(file_name2));
   DummyDatabase *db5 = DummyDatabase::Create(file_name2);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db5);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db5);
   EXPECT_FALSE(db5->OwnsFile());
   EXPECT_TRUE(FileExists(file_name2));
   db5->TakeFileOwnership();
@@ -783,7 +778,7 @@ TEST_F(T_SQLite_Wrapper, TakeFileOwnership) {
   const std::string file_name3 = GetDatabaseFilename();
   ASSERT_TRUE(FileExists(file_name3));
   DummyDatabase *db6 = DummyDatabase::Create(file_name3);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db6);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db6);
   EXPECT_FALSE(db6->OwnsFile());
   EXPECT_TRUE(FileExists(file_name3));
   delete db6;
@@ -791,9 +786,9 @@ TEST_F(T_SQLite_Wrapper, TakeFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name3));
 
-  DummyDatabase *db7 =
-    DummyDatabase::Open(file_name3, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db7);
+  DummyDatabase *db7 = DummyDatabase::Open(file_name3,
+                                           DummyDatabase::kOpenReadWrite);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db7);
   EXPECT_FALSE(db7->OwnsFile());
   EXPECT_TRUE(FileExists(file_name3));
   db7->TakeFileOwnership();
@@ -811,7 +806,7 @@ TEST_F(T_SQLite_Wrapper, DropFileOwnership) {
   ASSERT_TRUE(FileExists(file_name1));
 
   DummyDatabase *db1 = DummyDatabase::Create(file_name1);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_FALSE(db1->OwnsFile());
   EXPECT_TRUE(FileExists(file_name1));
   delete db1;
@@ -819,9 +814,9 @@ TEST_F(T_SQLite_Wrapper, DropFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name1));
 
-  DummyDatabase *db2 =
-    DummyDatabase::Open(file_name1, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  DummyDatabase *db2 = DummyDatabase::Open(file_name1,
+                                           DummyDatabase::kOpenReadOnly);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_FALSE(db2->OwnsFile());
   EXPECT_TRUE(FileExists(file_name1));
   delete db2;
@@ -829,9 +824,9 @@ TEST_F(T_SQLite_Wrapper, DropFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name1));
 
-  DummyDatabase *db3 =
-    DummyDatabase::Open(file_name1, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db3);
+  DummyDatabase *db3 = DummyDatabase::Open(file_name1,
+                                           DummyDatabase::kOpenReadWrite);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db3);
   EXPECT_FALSE(db3->OwnsFile());
   EXPECT_TRUE(FileExists(file_name1));
   delete db3;
@@ -839,9 +834,9 @@ TEST_F(T_SQLite_Wrapper, DropFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name1));
 
-  DummyDatabase *db4 =
-    DummyDatabase::Open(file_name1, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db4);
+  DummyDatabase *db4 = DummyDatabase::Open(file_name1,
+                                           DummyDatabase::kOpenReadOnly);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db4);
   EXPECT_TRUE(FileExists(file_name1));
   EXPECT_FALSE(db4->OwnsFile());
   db4->TakeFileOwnership();
@@ -857,7 +852,7 @@ TEST_F(T_SQLite_Wrapper, DropFileOwnership) {
   const std::string file_name2 = GetDatabaseFilename();
   ASSERT_TRUE(FileExists(file_name2));
   DummyDatabase *db5 = DummyDatabase::Create(file_name2);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db5);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db5);
   EXPECT_FALSE(db5->OwnsFile());
   EXPECT_TRUE(FileExists(file_name2));
   db5->TakeFileOwnership();
@@ -872,7 +867,7 @@ TEST_F(T_SQLite_Wrapper, DropFileOwnership) {
   const std::string file_name3 = GetDatabaseFilename();
   ASSERT_TRUE(FileExists(file_name3));
   DummyDatabase *db6 = DummyDatabase::Create(file_name3);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db6);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db6);
   EXPECT_FALSE(db6->OwnsFile());
   EXPECT_TRUE(FileExists(file_name3));
   delete db6;
@@ -880,9 +875,9 @@ TEST_F(T_SQLite_Wrapper, DropFileOwnership) {
   EXPECT_EQ(0u, DummyDatabase::instances);
   EXPECT_TRUE(FileExists(file_name3));
 
-  DummyDatabase *db7 =
-    DummyDatabase::Open(file_name3, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db7);
+  DummyDatabase *db7 = DummyDatabase::Open(file_name3,
+                                           DummyDatabase::kOpenReadWrite);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db7);
   EXPECT_FALSE(db7->OwnsFile());
   EXPECT_TRUE(FileExists(file_name3));
   db7->TakeFileOwnership();
@@ -901,7 +896,7 @@ TEST_F(T_SQLite_Wrapper, CountModifiedRows) {
   const std::string dbp = GetDatabaseFilename();
 
   DummyDatabase *db1 = DummyDatabase::Create(dbp);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db1);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db1);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_TRUE(db1->read_write());
   EXPECT_EQ(2u, db1->GetModifiedRowCount());  // creation adds schema revision
@@ -910,7 +905,7 @@ TEST_F(T_SQLite_Wrapper, CountModifiedRows) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db2 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db2);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db2);
   EXPECT_EQ(1u, DummyDatabase::instances);
   EXPECT_TRUE(db2->read_write());
   EXPECT_EQ(0u, db2->GetModifiedRowCount());
@@ -943,7 +938,7 @@ TEST_F(T_SQLite_Wrapper, CountModifiedRows) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db3 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadOnly);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db3);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db3);
   EXPECT_EQ(1u, DummyDatabase::instances);
 
   EXPECT_EQ(0u, db3->GetModifiedRowCount());
@@ -962,7 +957,7 @@ TEST_F(T_SQLite_Wrapper, CountModifiedRows) {
   EXPECT_EQ(0u, DummyDatabase::instances);
 
   DummyDatabase *db4 = DummyDatabase::Open(dbp, DummyDatabase::kOpenReadWrite);
-  ASSERT_NE(static_cast<DummyDatabase*>(NULL), db4);
+  ASSERT_NE(static_cast<DummyDatabase *>(NULL), db4);
   EXPECT_EQ(1u, DummyDatabase::instances);
 
   EXPECT_EQ(0u, db4->GetModifiedRowCount());
