@@ -2,10 +2,9 @@
  * This file is part of the CernVM File System.
  */
 
-#include <gtest/gtest.h>
-
 #include <errno.h>
 #include <fcntl.h>
+#include <gtest/gtest.h>
 #include <unistd.h>
 
 #include <string>
@@ -41,26 +40,25 @@ class UploadCallbacks {
   }
 
   void SimpleUploadClosure(const UploaderResults &results,
-                                 UploaderResults  expected) {
-    EXPECT_EQ(UploaderResults::kFileUpload,   results.type);
-    EXPECT_EQ(expected.return_code,           results.return_code);
-    EXPECT_EQ(expected.local_path,            results.local_path);
+                           UploaderResults expected) {
+    EXPECT_EQ(UploaderResults::kFileUpload, results.type);
+    EXPECT_EQ(expected.return_code, results.return_code);
+    EXPECT_EQ(expected.local_path, results.local_path);
     atomic_inc32(&simple_upload_invocations);
   }
 
-  void StreamedUploadComplete(const UploaderResults &results,
-                                    int              return_code) {
-    EXPECT_EQ(UploaderResults::kChunkCommit,  results.type);
-    EXPECT_EQ("",                             results.local_path);
-    EXPECT_EQ(return_code,                    results.return_code);
+  void StreamedUploadComplete(const UploaderResults &results, int return_code) {
+    EXPECT_EQ(UploaderResults::kChunkCommit, results.type);
+    EXPECT_EQ("", results.local_path);
+    EXPECT_EQ(return_code, results.return_code);
     atomic_inc32(&streamed_upload_complete_invocations);
   }
 
   void BufferUploadComplete(const UploaderResults &results,
-                                  UploaderResults  expected) {
+                            UploaderResults expected) {
     EXPECT_EQ(UploaderResults::kBufferUpload, results.type);
-    EXPECT_EQ("",                             results.local_path);
-    EXPECT_EQ(expected.return_code,           results.return_code);
+    EXPECT_EQ("", results.local_path);
+    EXPECT_EQ(expected.return_code, results.return_code);
     atomic_inc32(&buffer_upload_complete_invocations);
   }
 
@@ -71,7 +69,7 @@ class UploadCallbacks {
 };
 
 
-template <class UploadersT>
+template<class UploadersT>
 class T_Uploaders : public FileSandbox {
  private:
   static const char sandbox_path[];
@@ -79,7 +77,8 @@ class T_Uploaders : public FileSandbox {
   static const std::string tmp_dir;
   std::string repo_alias;
   std::string s3_conf_path;
-  template<typename> struct type {};
+  template<typename>
+  struct type { };
 
  public:
   static const unsigned kTotal429Replies;
@@ -91,19 +90,19 @@ class T_Uploaders : public FileSandbox {
     }
 
     UploadStreamHandle *handle;
-    shash::Any          content_hash;
+    shash::Any content_hash;
   };
 
-  typedef std::vector<std::string *>                     Buffers;
+  typedef std::vector<std::string *> Buffers;
   typedef std::vector<std::pair<Buffers, StreamHandle> > BufferStreams;
 
-  T_Uploaders() : FileSandbox(string(T_Uploaders::sandbox_path)),
-                  uploader_(NULL) {}
+  T_Uploaders()
+      : FileSandbox(string(T_Uploaders::sandbox_path)), uploader_(NULL) { }
 
  protected:
   AbstractUploader *uploader_;
-  UploadCallbacks   delegate_;
-  MockHTTPServer   *http_server_;
+  UploadCallbacks delegate_;
+  MockHTTPServer *http_server_;
 
   virtual void SetUp() {
     CreateSandbox(T_Uploaders::tmp_dir);
@@ -115,7 +114,7 @@ class T_Uploaders : public FileSandbox {
 
     InitializeStorageBackend();
     uploader_ = AbstractUploader::Construct(GetSpoolerDefinition());
-    ASSERT_NE(static_cast<AbstractUploader*>(NULL), uploader_);
+    ASSERT_NE(static_cast<AbstractUploader *>(NULL), uploader_);
   }
 
 
@@ -178,9 +177,9 @@ class T_Uploaders : public FileSandbox {
     const std::string definition = GetSpoolerDefinition(type<UploadersT>());
     const bool generate_legacy_bulk_chunks = true;
     const bool use_file_chunking = true;
-    const size_t min_chunk_size  = 0;   // chunking does not matter here, we are
-    const size_t avg_chunk_size  = 1;   // only testing the upload module.
-    const size_t max_chunk_size  = 2;
+    const size_t min_chunk_size = 0;  // chunking does not matter here, we are
+    const size_t avg_chunk_size = 1;  // only testing the upload module.
+    const size_t max_chunk_size = 2;
 
     SpoolerDefinition sd(definition,
                          shash::kSha1,
@@ -197,9 +196,9 @@ class T_Uploaders : public FileSandbox {
 
   std::string GetSpoolerDefinition(
       const type<upload::LocalUploader> type_specifier) const {
-    const std::string spl_type   = "local";
-    const std::string spl_tmp    = T_Uploaders::tmp_dir;
-    const std::string spl_cfg    = T_Uploaders::dest_dir;
+    const std::string spl_type = "local";
+    const std::string spl_tmp = T_Uploaders::tmp_dir;
+    const std::string spl_cfg = T_Uploaders::dest_dir;
     const std::string definition = spl_type + "," + spl_tmp + "," + spl_cfg;
     return definition;
   }
@@ -207,16 +206,16 @@ class T_Uploaders : public FileSandbox {
 
   std::string GetSpoolerDefinition(
       const type<upload::S3Uploader> type_specifier) const {
-    const std::string spl_type   = "S3";
-    const std::string spl_tmp    = T_Uploaders::tmp_dir;
-    const std::string spl_cfg    = repo_alias + "@" + s3_conf_path;
+    const std::string spl_type = "S3";
+    const std::string spl_tmp = T_Uploaders::tmp_dir;
+    const std::string spl_cfg = repo_alias + "@" + s3_conf_path;
     const std::string definition = spl_type + "," + spl_tmp + "," + spl_cfg;
     return definition;
   }
 
 
   Buffers MakeRandomizedBuffers(const unsigned int buffer_count,
-                                const          int rng_seed) const {
+                                const int rng_seed) const {
     Buffers result;
 
     Prng rng;
@@ -224,8 +223,8 @@ class T_Uploaders : public FileSandbox {
 
     for (unsigned int i = 0; i < buffer_count; ++i) {
       // Was previously used with CharBuffer
-      const size_t buffer_size  = rng.Next(1024 * 1024) + 10;
-      const size_t bytes_to_use = rng.Next(buffer_size) +  5;
+      const size_t buffer_size = rng.Next(1024 * 1024) + 10;
+      const size_t bytes_to_use = rng.Next(buffer_size) + 5;
 
       std::string *buffer = new std::string();
       buffer->reserve(bytes_to_use);
@@ -250,7 +249,7 @@ class T_Uploaders : public FileSandbox {
   BufferStreams MakeRandomizedBufferStreams(
       const unsigned int stream_count,
       const unsigned int max_buffers_per_stream,
-      const          int rng_seed) const {
+      const int rng_seed) const {
     BufferStreams streams;
 
     Prng rng;
@@ -258,9 +257,8 @@ class T_Uploaders : public FileSandbox {
 
     for (unsigned int i = 0; i < stream_count; ++i) {
       const unsigned int buffers = rng.Next(max_buffers_per_stream) + 1;
-      streams.push_back(
-        std::make_pair(MakeRandomizedBuffers(buffers, rng.Next(1234567)),
-                       StreamHandle()));
+      streams.push_back(std::make_pair(
+          MakeRandomizedBuffers(buffers, rng.Next(1234567)), StreamHandle()));
     }
 
     return streams;
@@ -268,7 +266,7 @@ class T_Uploaders : public FileSandbox {
 
 
   void FreeBufferStreams(BufferStreams *streams) const {
-    typename BufferStreams::iterator       i    = streams->begin();
+    typename BufferStreams::iterator i = streams->begin();
     typename BufferStreams::const_iterator iend = streams->end();
     for (; i != iend; ++i) {
       FreeBuffers(&(i->first));
@@ -285,17 +283,17 @@ class T_Uploaders : public FileSandbox {
 
   void CompareFileContents(const std::string &testee_path,
                            const std::string &reference_path) const {
-    const size_t testee_size    = GetFileSize(testee_path);
+    const size_t testee_size = GetFileSize(testee_path);
     const size_t reference_size = GetFileSize(reference_path);
     EXPECT_EQ(reference_size, testee_size);
 
-    shash::Any testee_hash    = HashFile(testee_path);
+    shash::Any testee_hash = HashFile(testee_path);
     shash::Any reference_hash = HashFile(reference_path);
     EXPECT_EQ(reference_hash, testee_hash);
   }
 
 
-  void CompareBuffersAndFileContents(const Buffers     &buffers,
+  void CompareBuffersAndFileContents(const Buffers &buffers,
                                      const std::string &file_path) const {
     size_t buffers_size = 0;
     for (unsigned i = 0; i < buffers.size(); ++i) {
@@ -305,7 +303,7 @@ class T_Uploaders : public FileSandbox {
     EXPECT_EQ(file_size, buffers_size);
 
     shash::Any buffers_hash = HashBuffers(buffers);
-    shash::Any file_hash    = HashFile(file_path);
+    shash::Any file_hash = HashFile(file_path);
     EXPECT_EQ(file_hash, buffers_hash);
   }
 
@@ -332,16 +330,15 @@ class T_Uploaders : public FileSandbox {
     // strip bucket name
     std::string req_file = req.path.substr(req.path.find("/", 1) + 1);
 
-    if ((*n429 > 0) &&
-        (req.path.size() >= 5) &&
-        (req.path.compare(req.path.size() - 5, 5, "RETRY") == 0)) {
+    if ((*n429 > 0) && (req.path.size() >= 5)
+        && (req.path.compare(req.path.size() - 5, 5, "RETRY") == 0)) {
       (*n429)--;
       response.code = 429;
       response.reason = "Too Many Requests";
       response.AddHeader("Retry-After", "1");
     } else if (req.method == "PUT") {
       std::string path = T_Uploaders::dest_dir + "/" + req_file;
-      FILE* file = fopen(path.c_str(), "w");
+      FILE *file = fopen(path.c_str(), "w");
       assert(file != NULL);
       FileGuard file_guard(file);
       int fid = fileno(file);
@@ -374,29 +371,29 @@ class T_Uploaders : public FileSandbox {
   void CreateTempS3ConfigFile(int accounts, int parallel_connections) {
     ASSERT_GE(accounts, 1);
     ASSERT_GE(parallel_connections, 1);
-    FILE *s3_conf = CreateTempFile(T_Uploaders::tmp_dir + "/s3.conf",
-                                   0660, "w", &s3_conf_path);
+    FILE *s3_conf = CreateTempFile(T_Uploaders::tmp_dir + "/s3.conf", 0660, "w",
+                                   &s3_conf_path);
     ASSERT_TRUE(s3_conf != NULL);
-    std::string conf_str =
-        "CVMFS_S3_ACCOUNTS=" + StringifyInt(accounts) + "\n"
-        "CVMFS_S3_ACCESS_KEY=";
-    for (int i = 0; accounts-1 > i; i++)
-      conf_str += "ABCDEFGHIJKLMNOPQRST" +
-                  StringifyInt(i) + ":";
+    std::string conf_str = "CVMFS_S3_ACCOUNTS=" + StringifyInt(accounts)
+                           + "\n"
+                             "CVMFS_S3_ACCESS_KEY=";
+    for (int i = 0; accounts - 1 > i; i++)
+      conf_str += "ABCDEFGHIJKLMNOPQRST" + StringifyInt(i) + ":";
     conf_str += "ABCDEFGHIJKLMNOPQRST\n"
                 "CVMFS_S3_SECRET_KEY=";
-    for (int i = 0; accounts-1 > i; i++)
-      conf_str += "ABCDEFGHIJKLMNOPQRSTUABCDEFGHIJKLMNOPQR" +
-                  StringifyInt(i) + ":";
-    conf_str +=
-        "ABCDEFGHIJKLMNOPQRSTUABCDEFGHIJKLMNOPQR1\n"
-        "CVMFS_S3_BUCKETS_PER_ACCOUNT=100\n"
-        "CVMFS_S3_BUCKET=testbucket\n"
-        "CVMFS_S3_MAX_NUMBER_OF_PARALLEL_CONNECTIONS=" +
-        StringifyInt(parallel_connections) + "\n"
-        "CVMFS_S3_HOST=127.0.0.1\n"
-        "CVMFS_S3_DNS_BUCKETS=false\n"
-        "CVMFS_S3_PORT=" + StringifyInt(CVMFS_S3_TEST_MOCKUP_SERVER_PORT);
+    for (int i = 0; accounts - 1 > i; i++)
+      conf_str += "ABCDEFGHIJKLMNOPQRSTUABCDEFGHIJKLMNOPQR" + StringifyInt(i)
+                  + ":";
+    conf_str += "ABCDEFGHIJKLMNOPQRSTUABCDEFGHIJKLMNOPQR1\n"
+                "CVMFS_S3_BUCKETS_PER_ACCOUNT=100\n"
+                "CVMFS_S3_BUCKET=testbucket\n"
+                "CVMFS_S3_MAX_NUMBER_OF_PARALLEL_CONNECTIONS="
+                + StringifyInt(parallel_connections)
+                + "\n"
+                  "CVMFS_S3_HOST=127.0.0.1\n"
+                  "CVMFS_S3_DNS_BUCKETS=false\n"
+                  "CVMFS_S3_PORT="
+                + StringifyInt(CVMFS_S3_TEST_MOCKUP_SERVER_PORT);
 
     fprintf(s3_conf, "%s\n", conf_str.c_str());
     fclose(s3_conf);
@@ -446,36 +443,38 @@ class T_Uploaders : public FileSandbox {
   }
 };
 
-template <typename T>
+template<typename T>
 bool T_Uploaders<T>::IsS3() const {
   return false;
 }
 
-template <>
+template<>
 bool T_Uploaders<S3Uploader>::IsS3() const {
   return true;
 }
 
-template <class UploadersT>
+template<class UploadersT>
 atomic_int64 T_Uploaders<UploadersT>::gSeed = 0;
 
 // Shold be larger than the number of regular retries
-template <class UploadersT>
+template<class UploadersT>
 const unsigned T_Uploaders<UploadersT>::kTotal429Replies = 4;
 
-template <class UploadersT>
+template<class UploadersT>
 const unsigned T_Uploaders<UploadersT>::k429ThrottleSec = 1;
 
-template <class UploadersT>
+template<class UploadersT>
 const char T_Uploaders<UploadersT>::sandbox_path[] = "./cvmfs_ut_uploader";
 
-template <class UploadersT>
-const std::string T_Uploaders<UploadersT>::tmp_dir =
-    string(T_Uploaders::sandbox_path) + "/tmp";
+template<class UploadersT>
+const std::string
+    T_Uploaders<UploadersT>::tmp_dir = string(T_Uploaders::sandbox_path)
+                                       + "/tmp";
 
-template <class UploadersT>
-const std::string T_Uploaders<UploadersT>::dest_dir =
-    string(T_Uploaders::sandbox_path) + "/dest";
+template<class UploadersT>
+const std::string
+    T_Uploaders<UploadersT>::dest_dir = string(T_Uploaders::sandbox_path)
+                                        + "/dest";
 
 typedef testing::Types<S3Uploader, LocalUploader> UploadTypes;
 TYPED_TEST_CASE(T_Uploaders, UploadTypes);
@@ -483,9 +482,8 @@ TYPED_TEST_CASE(T_Uploaders, UploadTypes);
 
 //------------------------------------------------------------------------------
 
-static void LogSupress(const LogSource source, const int mask, const char *msg)
-{
-}
+static void LogSupress(const LogSource source, const int mask,
+                       const char *msg) { }
 
 TYPED_TEST(T_Uploaders, RetrySlow) {
   if (!TestFixture::IsS3()) {
@@ -494,25 +492,24 @@ TYPED_TEST(T_Uploaders, RetrySlow) {
   }
 
   const std::string small_file_path = TestFixture::GetSmallFile();
-  const std::string dest_name       = "RETRY";
+  const std::string dest_name = "RETRY";
 
-  upload::S3Uploader *s3uploader =
-    static_cast<upload::S3Uploader *>(this->uploader_);
+  upload::S3Uploader *s3uploader = static_cast<upload::S3Uploader *>(
+      this->uploader_);
   SetAltLogFunc(LogSupress);
   EXPECT_EQ(0U, s3uploader->GetS3FanoutManager()->GetStatistics().num_retries);
-  this->uploader_->UploadFile(small_file_path, dest_name,
-                              AbstractUploader::MakeClosure(
-                              &UploadCallbacks::SimpleUploadClosure,
-                              &this->delegate_,
-                              UploaderResults(0, small_file_path)));
+  this->uploader_->UploadFile(
+      small_file_path, dest_name,
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, small_file_path)));
   this->uploader_->WaitForUpload();
   SetAltLogFunc(NULL);
 
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
   EXPECT_EQ(1, atomic_read32(&(this->delegate_.simple_upload_invocations)));
-  TestFixture::CompareFileContents(small_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      small_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
 
   EXPECT_EQ(this->kTotal429Replies,
             s3uploader->GetS3FanoutManager()->GetStatistics().num_retries);
@@ -534,21 +531,20 @@ TYPED_TEST(T_Uploaders, Initialize) {
 
 TYPED_TEST(T_Uploaders, SimpleFileUpload) {
   const std::string big_file_path = TestFixture::GetBigFile();
-  const std::string dest_name     = "big_file";
+  const std::string dest_name = "big_file";
 
-  this->uploader_->UploadFile(big_file_path,
-                              dest_name,
-                              AbstractUploader::MakeClosure(
-                              &UploadCallbacks::SimpleUploadClosure,
-                              &this->delegate_,
-                              UploaderResults(0, big_file_path)));
+  this->uploader_->UploadFile(
+      big_file_path,
+      dest_name,
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, big_file_path)));
 
   this->uploader_->WaitForUpload();
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
   EXPECT_EQ(1, atomic_read32(&(this->delegate_.simple_upload_invocations)));
-  TestFixture::CompareFileContents(big_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      big_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
 }
 
 //------------------------------------------------------------------------------
@@ -564,19 +560,18 @@ TYPED_TEST(T_Uploaders, IngestionSource) {
   const std::string dest_name = "string";
 
   this->uploader_->UploadIngestionSource(
-    dest_name,
-    new StringIngestionSource(content),
-    AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
-                                  &this->delegate_,
-                                  UploaderResults(0, "MEM")));
+      dest_name,
+      new StringIngestionSource(content),
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, "MEM")));
   this->uploader_->WaitForUpload();
 
   const bool file_exists = this->uploader_->Peek(dest_name);
   EXPECT_TRUE(file_exists);
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
-  TestFixture::CompareFileContents(small_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      small_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
 }
 
 
@@ -585,20 +580,19 @@ TYPED_TEST(T_Uploaders, IngestionSource) {
 
 TYPED_TEST(T_Uploaders, PeekIntoStorage) {
   const std::string small_file_path = TestFixture::GetSmallFile();
-  const std::string dest_name       = "small_file";
+  const std::string dest_name = "small_file";
 
-  this->uploader_->UploadFile(small_file_path, dest_name,
-                              AbstractUploader::MakeClosure(
-                              &UploadCallbacks::SimpleUploadClosure,
-                              &this->delegate_,
-                              UploaderResults(0, small_file_path)));
+  this->uploader_->UploadFile(
+      small_file_path, dest_name,
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, small_file_path)));
   this->uploader_->WaitForUpload();
 
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
   EXPECT_EQ(1, atomic_read32(&(this->delegate_.simple_upload_invocations)));
-  TestFixture::CompareFileContents(small_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      small_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
 
   const bool file_exists = this->uploader_->Peek(dest_name);
   EXPECT_TRUE(file_exists);
@@ -613,20 +607,19 @@ TYPED_TEST(T_Uploaders, PeekIntoStorage) {
 
 TYPED_TEST(T_Uploaders, RemoveFromStorage) {
   const std::string small_file_path = TestFixture::GetSmallFile();
-  const std::string dest_name       = "also_small_file";
+  const std::string dest_name = "also_small_file";
 
-  this->uploader_->UploadFile(small_file_path, dest_name,
-                              AbstractUploader::MakeClosure(
-                              &UploadCallbacks::SimpleUploadClosure,
-                              &this->delegate_,
-                              UploaderResults(0, small_file_path)));
+  this->uploader_->UploadFile(
+      small_file_path, dest_name,
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, small_file_path)));
   this->uploader_->WaitForUpload();
 
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
   EXPECT_EQ(1, atomic_read32(&(this->delegate_.simple_upload_invocations)));
-  TestFixture::CompareFileContents(small_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      small_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
 
   const bool file_exists = this->uploader_->Peek(dest_name);
   EXPECT_TRUE(file_exists);
@@ -648,20 +641,19 @@ TYPED_TEST(T_Uploaders, RemoveFromStorage) {
 
 TYPED_TEST(T_Uploaders, UploadEmptyFile) {
   const std::string empty_file_path = TestFixture::GetEmptyFile();
-  const std::string dest_name       = "empty_file";
+  const std::string dest_name = "empty_file";
 
-  this->uploader_->UploadFile(empty_file_path, dest_name,
-                              AbstractUploader::MakeClosure(
-                              &UploadCallbacks::SimpleUploadClosure,
-                              &this->delegate_,
-                              UploaderResults(0, empty_file_path)));
+  this->uploader_->UploadFile(
+      empty_file_path, dest_name,
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, empty_file_path)));
   this->uploader_->WaitForUpload();
 
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
   EXPECT_EQ(1, atomic_read32(&(this->delegate_.simple_upload_invocations)));
-  TestFixture::CompareFileContents(empty_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      empty_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
   EXPECT_EQ(0, GetFileSize(TestFixture::AbsoluteDestinationPath(dest_name)));
 }
 
@@ -671,20 +663,19 @@ TYPED_TEST(T_Uploaders, UploadEmptyFile) {
 
 TYPED_TEST(T_Uploaders, UploadHugeFileSlow) {
   const std::string huge_file_path = TestFixture::GetHugeFile();
-  const std::string dest_name     = "huge_file";
+  const std::string dest_name = "huge_file";
 
-  this->uploader_->UploadFile(huge_file_path, dest_name,
-                              AbstractUploader::MakeClosure(
-                              &UploadCallbacks::SimpleUploadClosure,
-                              &this->delegate_,
-                              UploaderResults(0, huge_file_path)));
+  this->uploader_->UploadFile(
+      huge_file_path, dest_name,
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, huge_file_path)));
   this->uploader_->WaitForUpload();
 
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
   EXPECT_EQ(1, atomic_read32(&(this->delegate_.simple_upload_invocations)));
-  TestFixture::CompareFileContents(huge_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      huge_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
 }
 
 
@@ -716,14 +707,14 @@ TYPED_TEST(T_Uploaders, UploadManyFilesSlow) {
     files.push_back(std::make_pair(file, dest_name));
   }
 
-  Files::const_iterator i    = files.begin();
+  Files::const_iterator i = files.begin();
   Files::const_iterator iend = files.end();
   for (; i != iend; ++i) {
-    this->uploader_->UploadFile(i->first, i->second,
-                                AbstractUploader::MakeClosure(
-                                &UploadCallbacks::SimpleUploadClosure,
-                                &this->delegate_,
-                                UploaderResults(0, i->first)));
+    this->uploader_->UploadFile(
+        i->first, i->second,
+        AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                      &this->delegate_,
+                                      UploaderResults(0, i->first)));
   }
   this->uploader_->WaitForUpload();
 
@@ -731,9 +722,8 @@ TYPED_TEST(T_Uploaders, UploadManyFilesSlow) {
             atomic_read32(&(this->delegate_.simple_upload_invocations)));
   for (i = files.begin(); i != iend; ++i) {
     EXPECT_TRUE(TestFixture::CheckFile(i->second));
-    TestFixture::CompareFileContents(i->first,
-                                     TestFixture::AbsoluteDestinationPath(
-                                         i->second));
+    TestFixture::CompareFileContents(
+        i->first, TestFixture::AbsoluteDestinationPath(i->second));
   }
 }
 
@@ -743,59 +733,63 @@ TYPED_TEST(T_Uploaders, UploadManyFilesSlow) {
 
 TYPED_TEST(T_Uploaders, SingleStreamedUpload) {
   const int number_of_buffers = 10;
-  typename TestFixture::Buffers buffers =
-      TestFixture::MakeRandomizedBuffers(number_of_buffers, 1337);
+  typename TestFixture::Buffers buffers = TestFixture::MakeRandomizedBuffers(
+      number_of_buffers, 1337);
 
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
+  EXPECT_EQ(
+      0, atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
+  EXPECT_EQ(
+      0,
+      atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
 
   UploadStreamHandle *handle = this->uploader_->InitStreamedUpload(
-      AbstractUploader::MakeClosure(&UploadCallbacks::StreamedUploadComplete,
-                                    &this->delegate_,
-                                    0));
-  ASSERT_NE(static_cast<UploadStreamHandle*>(NULL), handle);
+      AbstractUploader::MakeClosure(
+          &UploadCallbacks::StreamedUploadComplete, &this->delegate_, 0));
+  ASSERT_NE(static_cast<UploadStreamHandle *>(NULL), handle);
 
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
+  EXPECT_EQ(
+      0, atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
+  EXPECT_EQ(
+      0,
+      atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
 
-  typename TestFixture::Buffers::const_iterator i    = buffers.begin();
+  typename TestFixture::Buffers::const_iterator i = buffers.begin();
   typename TestFixture::Buffers::const_iterator iend = buffers.end();
   for (; i != iend; ++i) {
     this->uploader_->ScheduleUpload(
-      handle,
-      AbstractUploader::UploadBuffer((*i)->length(),
-                                     const_cast<char *>((*i)->data())),
-      AbstractUploader::MakeClosure(
-        &UploadCallbacks::BufferUploadComplete,
-        &this->delegate_,
-        UploaderResults(UploaderResults::kBufferUpload, 0)));
+        handle,
+        AbstractUploader::UploadBuffer((*i)->length(),
+                                       const_cast<char *>((*i)->data())),
+        AbstractUploader::MakeClosure(
+            &UploadCallbacks::BufferUploadComplete,
+            &this->delegate_,
+            UploaderResults(UploaderResults::kBufferUpload, 0)));
   }
   this->uploader_->WaitForUpload();
 
-  EXPECT_EQ(number_of_buffers,
-    atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
+  EXPECT_EQ(
+      number_of_buffers,
+      atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
+  EXPECT_EQ(
+      0,
+      atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
 
   shash::Any content_hash(shash::kSha1, 'A');
   content_hash.Randomize(42);
   this->uploader_->ScheduleCommit(handle, content_hash);
   this->uploader_->WaitForUpload();
 
-  EXPECT_EQ(number_of_buffers,
-    atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
-  EXPECT_EQ(1,
-    atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
+  EXPECT_EQ(
+      number_of_buffers,
+      atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
+  EXPECT_EQ(
+      1,
+      atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
 
   const std::string dest = "data/" + content_hash.MakePath();
   EXPECT_TRUE(TestFixture::CheckFile(dest));
   TestFixture::CompareBuffersAndFileContents(
-      buffers,
-      TestFixture::AbsoluteDestinationPath(dest));
+      buffers, TestFixture::AbsoluteDestinationPath(dest));
 
   TestFixture::FreeBuffers(&buffers);
 }
@@ -805,42 +799,42 @@ TYPED_TEST(T_Uploaders, SingleStreamedUpload) {
 
 
 TYPED_TEST(T_Uploaders, MultipleStreamedUploadSlow) {
-  const int  number_of_files        = 100;
-  const int  max_buffers_per_stream = 15;
-  typename TestFixture::BufferStreams streams =
-      TestFixture::MakeRandomizedBufferStreams(number_of_files,
-                                               max_buffers_per_stream,
-                                               42);
+  const int number_of_files = 100;
+  const int max_buffers_per_stream = 15;
+  typename TestFixture::BufferStreams
+      streams = TestFixture::MakeRandomizedBufferStreams(
+          number_of_files, max_buffers_per_stream, 42);
 
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
+  EXPECT_EQ(
+      0, atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
+  EXPECT_EQ(
+      0,
+      atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
 
-  typename TestFixture::BufferStreams::iterator       i    = streams.begin();
+  typename TestFixture::BufferStreams::iterator i = streams.begin();
   typename TestFixture::BufferStreams::const_iterator iend = streams.end();
   for (; i != iend; ++i) {
     UploadStreamHandle *handle = this->uploader_->InitStreamedUpload(
-        AbstractUploader::MakeClosure(&UploadCallbacks::StreamedUploadComplete,
-                                      &this->delegate_,
-                                      0));
-    ASSERT_NE(static_cast<UploadStreamHandle*>(NULL), handle);
+        AbstractUploader::MakeClosure(
+            &UploadCallbacks::StreamedUploadComplete, &this->delegate_, 0));
+    ASSERT_NE(static_cast<UploadStreamHandle *>(NULL), handle);
     i->second.handle = handle;
   }
 
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
-  EXPECT_EQ(0,
-    atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
+  EXPECT_EQ(
+      0, atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
+  EXPECT_EQ(
+      0,
+      atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
 
   // go through the handles and schedule buffers for them in a round robin
   // fashion --> we want to test concurrent streamed upload behaviour
   typename TestFixture::BufferStreams active_streams = streams;
-  typename TestFixture::BufferStreams::iterator j    = active_streams.begin();
-  int number_of_buffers                              = 0;
+  typename TestFixture::BufferStreams::iterator j = active_streams.begin();
+  int number_of_buffers = 0;
   while (!active_streams.empty()) {
-    typename TestFixture::Buffers             &buffers        = j->first;
-    const typename TestFixture::StreamHandle  &current_handle = j->second;
+    typename TestFixture::Buffers &buffers = j->first;
+    const typename TestFixture::StreamHandle &current_handle = j->second;
 
     if (!buffers.empty()) {
       std::string *current_buffer = buffers.front();
@@ -849,12 +843,12 @@ TYPED_TEST(T_Uploaders, MultipleStreamedUploadSlow) {
       this->uploader_->ScheduleUpload(
           current_handle.handle,
           AbstractUploader::UploadBuffer(
-            current_buffer->length(),
-            const_cast<char *>(current_buffer->data())),
+              current_buffer->length(),
+              const_cast<char *>(current_buffer->data())),
           AbstractUploader::MakeClosure(
-            &UploadCallbacks::BufferUploadComplete,
-            &this->delegate_,
-            UploaderResults(UploaderResults::kBufferUpload, 0)));
+              &UploadCallbacks::BufferUploadComplete,
+              &this->delegate_,
+              UploaderResults(UploaderResults::kBufferUpload, 0)));
       buffers.erase(buffers.begin());
     } else {
       this->uploader_->ScheduleCommit(current_handle.handle,
@@ -865,20 +859,21 @@ TYPED_TEST(T_Uploaders, MultipleStreamedUploadSlow) {
 
   this->uploader_->WaitForUpload();
 
-  EXPECT_EQ(number_of_buffers,
-    atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
-  EXPECT_EQ(number_of_files,
-    atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
+  EXPECT_EQ(
+      number_of_buffers,
+      atomic_read32(&(this->delegate_.buffer_upload_complete_invocations)));
+  EXPECT_EQ(
+      number_of_files,
+      atomic_read32(&(this->delegate_.streamed_upload_complete_invocations)));
 
-  typename TestFixture::BufferStreams::const_iterator k    = streams.begin();
+  typename TestFixture::BufferStreams::const_iterator k = streams.begin();
   typename TestFixture::BufferStreams::const_iterator kend = streams.end();
   for (; k != kend; ++k) {
     const shash::Any &content_hash = k->second.content_hash;
     const std::string dest = "data/" + content_hash.MakePath();
     EXPECT_TRUE(TestFixture::CheckFile(dest));
     TestFixture::CompareBuffersAndFileContents(
-        k->first,
-        TestFixture::AbsoluteDestinationPath(dest));
+        k->first, TestFixture::AbsoluteDestinationPath(dest));
   }
 
   TestFixture::FreeBufferStreams(&streams);
@@ -901,25 +896,24 @@ TYPED_TEST(T_Uploaders, PlaceBootstrappingShortcut) {
 
   const std::string dest_name = "data/" + digest.MakePath();
 
-  this->uploader_->UploadFile(big_file_path,
-                              dest_name,
-                              AbstractUploader::MakeClosure(
-                              &UploadCallbacks::SimpleUploadClosure,
-                              &this->delegate_,
-                              UploaderResults(0, big_file_path)));
+  this->uploader_->UploadFile(
+      big_file_path,
+      dest_name,
+      AbstractUploader::MakeClosure(&UploadCallbacks::SimpleUploadClosure,
+                                    &this->delegate_,
+                                    UploaderResults(0, big_file_path)));
 
   this->uploader_->WaitForUpload();
   EXPECT_TRUE(TestFixture::CheckFile(dest_name));
 
   EXPECT_EQ(1, atomic_read32(&(this->delegate_.simple_upload_invocations)));
-  TestFixture::CompareFileContents(big_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       dest_name));
+  TestFixture::CompareFileContents(
+      big_file_path, TestFixture::AbsoluteDestinationPath(dest_name));
 
   ASSERT_TRUE(this->uploader_->PlaceBootstrappingShortcut(digest));
-  TestFixture::CompareFileContents(big_file_path,
-                                   TestFixture::AbsoluteDestinationPath(
-                                       digest.MakeAlternativePath()));
+  TestFixture::CompareFileContents(
+      big_file_path,
+      TestFixture::AbsoluteDestinationPath(digest.MakeAlternativePath()));
 }
 
 }  // namespace upload
